<?php
// 确保用户已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 引入配置文件和函数库
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 使用全局变量$conn

// 初始化消息数组
$messages = [];
$errors = [];

// 获取参数
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$report_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$user_id = $_SESSION['user_id'];

// 处理报表表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_report'])) {
    $reportName = isset($_POST['report_name']) ? trim($_POST['report_name']) : '';
    $reportType = isset($_POST['report_type']) ? trim($_POST['report_type']) : '';
    $isPublic = isset($_POST['is_public']) ? 1 : 0;

    // 获取表单中的查询配置
    $tableName = isset($_POST['table_name']) ? trim($_POST['table_name']) : '';
    $selectedFields = isset($_POST['fields']) ? $_POST['fields'] : [];
    $filters = isset($_POST['filters']) ? $_POST['filters'] : [];
    $sortField = isset($_POST['sort_field']) ? trim($_POST['sort_field']) : '';
    $sortOrder = isset($_POST['sort_order']) ? trim($_POST['sort_order']) : 'ASC';
    $groupBy = isset($_POST['group_by']) ? trim($_POST['group_by']) : '';
    $limit = isset($_POST['limit']) ? intval($_POST['limit']) : 100;

    // 获取表单中的显示配置
    $chartType = isset($_POST['chart_type']) ? trim($_POST['chart_type']) : 'table';
    $chartTitle = isset($_POST['chart_title']) ? trim($_POST['chart_title']) : $reportName;
    $xAxis = isset($_POST['x_axis']) ? trim($_POST['x_axis']) : '';
    $yAxis = isset($_POST['y_axis']) ? trim($_POST['y_axis']) : '';

    // 验证必填字段
    $errors = [];
    if (empty($reportName)) {
        $errors[] = '报表名称不能为空';
    }
    if (empty($reportType)) {
        $errors[] = '报表类型不能为空';
    }
    if (empty($tableName)) {
        $errors[] = '数据表不能为空';
    }
    if (empty($selectedFields)) {
        $errors[] = '至少需要选择一个字段';
    }

    // 如果没有错误，保存报表配置
    if (empty($errors)) {
        // 构建查询配置JSON
        $queryConfig = [
            'table' => $tableName,
            'fields' => $selectedFields,
            'filters' => $filters,
            'sort_field' => $sortField,
            'sort_order' => $sortOrder,
            'group_by' => $groupBy,
            'limit' => $limit
        ];

        // 构建显示配置JSON
        $displayConfig = [
            'chart_type' => $chartType,
            'chart_title' => $chartTitle,
            'x_axis' => $xAxis,
            'y_axis' => $yAxis
        ];

        // 将配置转换为JSON
        $queryConfigJson = json_encode($queryConfig, JSON_UNESCAPED_UNICODE);
        $displayConfigJson = json_encode($displayConfig, JSON_UNESCAPED_UNICODE);

        // 准备SQL语句
        if ($report_id > 0) {
            // 更新现有报表
            $sql = "UPDATE custom_reports SET 
                    report_name = ?, 
                    report_type = ?, 
                    query_config = ?, 
                    display_config = ?, 
                    is_public = ?, 
                    updated_at = NOW() 
                    WHERE custom_report_id = ? AND user_id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param('ssssiis', $reportName, $reportType, $queryConfigJson, $displayConfigJson, $isPublic, $report_id, $user_id);
        } else {
            // 创建新报表
            $sql = "INSERT INTO custom_reports 
                    (report_name, report_type, user_id, query_config, display_config, is_public, created_at) 
                    VALUES (?, ?, ?, ?, ?, ?, NOW())";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param('ssissi', $reportName, $reportType, $user_id, $queryConfigJson, $displayConfigJson, $isPublic);
        }

        // 执行SQL
        if ($stmt->execute()) {
            if ($report_id == 0) {
                $report_id = $stmt->insert_id;
            }
            $messages[] = '报表已成功保存';
            // 重定向到报表列表页
            header('Location: index.php?page=custom&action=view&id=' . $report_id);
            exit;
        } else {
            $errors[] = '保存报表时出错: ' . $stmt->error;
        }

        $stmt->close();
    }
}

// 删除报表
if ($action === 'delete' && $report_id > 0) {
    $sql = "DELETE FROM custom_reports WHERE custom_report_id = ? AND user_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param('ii', $report_id, $user_id);

    if ($stmt->execute()) {
        $messages[] = '报表已成功删除';
        header('Location: index.php?page=custom');
        exit;
    } else {
        $errors[] = '删除报表时出错: ' . $stmt->error;
    }

    $stmt->close();
}

// 获取可用的数据表列表
$tables = [];
$tablesResult = $conn->query("SHOW TABLES");
while ($row = $tablesResult->fetch_row()) {
    $tables[] = $row[0];
}

// 获取指定表的列信息
function getTableColumns($conn, $tableName)
{
    $columns = [];
    if (!empty($tableName)) {
        $result = $conn->query("SHOW COLUMNS FROM `$tableName`");
        if ($result) {
            while ($row = $result->fetch_assoc()) {
                $columns[] = [
                    'name' => $row['Field'],
                    'type' => $row['Type'],
                    'key' => $row['Key']
                ];
            }
        }
    }
    return $columns;
}

// 加载特定报表的数据
$reportData = null;
$reportConfig = null;
$displayConfig = null;
$reportColumns = [];
$reportResult = null;
$tableName = '';

if (($action === 'edit' || $action === 'view') && $report_id > 0) {
    // 获取报表信息
    $sql = "SELECT * FROM custom_reports WHERE custom_report_id = ?";
    if ($action === 'edit') {
        $sql .= " AND user_id = ?";
    } else {
        $sql .= " AND (user_id = ? OR is_public = 1)";
    }

    $stmt = $conn->prepare($sql);
    $stmt->bind_param('ii', $report_id, $user_id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $reportData = $result->fetch_assoc();
        $reportConfig = json_decode($reportData['query_config'], true);
        $displayConfig = json_decode($reportData['display_config'], true);

        // 获取表结构
        $tableName = $reportConfig['table'] ?? '';
        if (!empty($tableName)) {
            $reportColumns = getTableColumns($conn, $tableName);
        }
    } else {
        $errors[] = '找不到指定的报表或您没有权限访问';
        $action = 'list';
    }

    $stmt->close();
}

// 执行自定义查询并获取结果
if ($action === 'view' && !empty($reportConfig) && !empty($tableName)) {
    try {
        // 构建SQL查询
        $fields = implode(', ', array_map(function ($field) {
            return "`" . $field . "`";
        }, $reportConfig['fields']));

        $sql = "SELECT $fields FROM `$tableName`";

        // 添加筛选条件
        if (!empty($reportConfig['filters'])) {
            $whereConditions = [];
            foreach ($reportConfig['filters'] as $filter) {
                if (!empty($filter['field']) && !empty($filter['operator']) && isset($filter['value'])) {
                    $field = $filter['field'];
                    $operator = $filter['operator'];
                    $value = $filter['value'];

                    switch ($operator) {
                        case 'equals':
                            $whereConditions[] = "`$field` = '$value'";
                            break;
                        case 'not_equals':
                            $whereConditions[] = "`$field` != '$value'";
                            break;
                        case 'greater_than':
                            $whereConditions[] = "`$field` > '$value'";
                            break;
                        case 'less_than':
                            $whereConditions[] = "`$field` < '$value'";
                            break;
                        case 'contains':
                            $whereConditions[] = "`$field` LIKE '%$value%'";
                            break;
                        case 'starts_with':
                            $whereConditions[] = "`$field` LIKE '$value%'";
                            break;
                        case 'ends_with':
                            $whereConditions[] = "`$field` LIKE '%$value'";
                            break;
                        case 'in':
                            $values = explode(',', $value);
                            $values = array_map(function ($v) {
                                return "'" . trim($v) . "'";
                            }, $values);
                            $whereConditions[] = "`$field` IN (" . implode(', ', $values) . ")";
                            break;
                        case 'not_in':
                            $values = explode(',', $value);
                            $values = array_map(function ($v) {
                                return "'" . trim($v) . "'";
                            }, $values);
                            $whereConditions[] = "`$field` NOT IN (" . implode(', ', $values) . ")";
                            break;
                    }
                }
            }

            if (!empty($whereConditions)) {
                $sql .= " WHERE " . implode(' AND ', $whereConditions);
            }
        }

        // 添加分组
        if (!empty($reportConfig['group_by'])) {
            $sql .= " GROUP BY `" . $reportConfig['group_by'] . "`";
        }

        // 添加排序
        if (!empty($reportConfig['sort_field'])) {
            $sql .= " ORDER BY `" . $reportConfig['sort_field'] . "` " . $reportConfig['sort_order'];
        }

        // 添加限制
        if (!empty($reportConfig['limit'])) {
            $sql .= " LIMIT " . intval($reportConfig['limit']);
        }

        // 执行查询
        $reportResult = $conn->query($sql);
        if (!$reportResult) {
            $errors[] = '执行查询时出错: ' . $conn->error;
        }
    } catch (Exception $e) {
        $errors[] = '执行查询时出错: ' . $e->getMessage();
    }
}

// 获取用户的所有报表
$userReports = [];
$publicReports = [];

if ($action === 'list') {
    // 获取用户自己的报表
    $sql = "SELECT * FROM custom_reports WHERE user_id = ? ORDER BY created_at DESC";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param('i', $user_id);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($row = $result->fetch_assoc()) {
        $userReports[] = $row;
    }

    $stmt->close();

    // 获取公开的报表
    $sql = "SELECT * FROM custom_reports 
            WHERE is_public = 1 AND user_id != ? 
            ORDER BY created_at DESC";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param('i', $user_id);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($row = $result->fetch_assoc()) {
        $publicReports[] = $row;
    }

    $stmt->close();
}

// 关闭数据库连接
$conn->close();
?>

<div class="custom-reports-container">
    <!-- 显示消息和错误 -->
    <?php if (!empty($messages)): ?>
        <?php foreach ($messages as $message): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($message); ?></div>
        <?php endforeach; ?>
    <?php endif; ?>

    <?php if (!empty($errors)): ?>
        <?php foreach ($errors as $error): ?>
            <div class="alert alert-error"><?php echo htmlspecialchars($error); ?></div>
        <?php endforeach; ?>
    <?php endif; ?>

    <!-- 根据不同的操作显示不同的内容 -->
    <?php if ($action === 'list'): ?>
        <!-- 报表列表 -->
        <div class="reports-header">
            <h3>自定义报表列表</h3>
            <a href="index.php?page=custom&action=create" class="btn btn-primary">创建新报表</a>
        </div>

        <div class="reports-section">
            <h4>我的报表</h4>
            <?php if (empty($userReports)): ?>
                <p class="empty-message">您还没有创建任何报表。</p>
            <?php else: ?>
                <div class="reports-list">
                    <?php foreach ($userReports as $report): ?>
                        <div class="report-card">
                            <div class="report-header">
                                <h5><?php echo htmlspecialchars($report['report_name']); ?></h5>
                                <span class="report-type"><?php echo htmlspecialchars($report['report_type']); ?></span>
                            </div>
                            <div class="report-info">
                                <span class="report-date">创建于: <?php echo date('Y-m-d H:i', strtotime($report['created_at'])); ?></span>
                                <?php if ($report['is_public']): ?>
                                    <span class="report-public">公开</span>
                                <?php else: ?>
                                    <span class="report-private">私有</span>
                                <?php endif; ?>
                            </div>
                            <div class="report-actions">
                                <a href="index.php?page=custom&action=view&id=<?php echo $report['custom_report_id']; ?>" class="btn btn-sm btn-success">查看</a>
                                <a href="index.php?page=custom&action=edit&id=<?php echo $report['custom_report_id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                <a href="index.php?page=custom&action=delete&id=<?php echo $report['custom_report_id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除这个报表吗？');">删除</a>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>

        <?php if (!empty($publicReports)): ?>
            <div class="reports-section">
                <h4>公开报表</h4>
                <div class="reports-list">
                    <?php foreach ($publicReports as $report): ?>
                        <div class="report-card">
                            <div class="report-header">
                                <h5><?php echo htmlspecialchars($report['report_name']); ?></h5>
                                <span class="report-type"><?php echo htmlspecialchars($report['report_type']); ?></span>
                            </div>
                            <div class="report-info">
                                <span class="report-date">创建于: <?php echo date('Y-m-d H:i', strtotime($report['created_at'])); ?></span>
                                <span class="report-public">公开</span>
                            </div>
                            <div class="report-actions">
                                <a href="index.php?page=custom&action=view&id=<?php echo $report['custom_report_id']; ?>" class="btn btn-sm btn-success">查看</a>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
    <?php endif; ?>

    <?php if ($action === 'create' || $action === 'edit'): ?>
        <!-- 创建/编辑报表表单 -->
        <div class="report-form-container">
            <h3><?php echo $action === 'create' ? '创建新报表' : '编辑报表'; ?></h3>
            <a href="index.php?page=custom" class="btn btn-secondary back-btn">返回报表列表</a>

            <form id="reportForm" method="POST" action="index.php?page=custom<?php echo $report_id > 0 ? '&action=edit&id=' . $report_id : '&action=create'; ?>">
                <div class="form-section">
                    <h4>基本信息</h4>
                    <div class="form-group">
                        <label for="report_name">报表名称<span class="required">*</span></label>
                        <input type="text" id="report_name" name="report_name" class="form-control" required
                            value="<?php echo htmlspecialchars($reportData['report_name'] ?? ''); ?>">
                    </div>

                    <div class="form-group">
                        <label for="report_type">报表类型<span class="required">*</span></label>
                        <select id="report_type" name="report_type" class="form-control" required>
                            <option value="">-- 选择报表类型 --</option>
                            <option value="sales" <?php echo isset($reportData['report_type']) && $reportData['report_type'] === 'sales' ? 'selected' : ''; ?>>销售报表</option>
                            <option value="inventory" <?php echo isset($reportData['report_type']) && $reportData['report_type'] === 'inventory' ? 'selected' : ''; ?>>库存报表</option>
                            <option value="financial" <?php echo isset($reportData['report_type']) && $reportData['report_type'] === 'financial' ? 'selected' : ''; ?>>财务报表</option>
                            <option value="customer" <?php echo isset($reportData['report_type']) && $reportData['report_type'] === 'customer' ? 'selected' : ''; ?>>客户报表</option>
                            <option value="other" <?php echo isset($reportData['report_type']) && $reportData['report_type'] === 'other' ? 'selected' : ''; ?>>其他</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="is_public">
                            <input type="checkbox" id="is_public" name="is_public" value="1"
                                <?php echo isset($reportData['is_public']) && $reportData['is_public'] ? 'checked' : ''; ?>>
                            公开此报表
                        </label>
                        <small class="form-text">如果选择公开，其他用户将可以查看此报表。</small>
                    </div>
                </div>

                <div class="form-section">
                    <h4>数据源配置</h4>
                    <div class="form-group">
                        <label for="table_name">数据表<span class="required">*</span></label>
                        <select id="table_name" name="table_name" class="form-control" required>
                            <option value="">-- 选择数据表 --</option>
                            <?php foreach ($tables as $table): ?>
                                <option value="<?php echo htmlspecialchars($table); ?>"
                                    <?php echo isset($reportConfig['table']) && $reportConfig['table'] === $table ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($table); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group" id="fields-container">
                        <label>选择字段<span class="required">*</span></label>
                        <div class="fields-list">
                            <?php if (!empty($reportColumns)): ?>
                                <?php foreach ($reportColumns as $column): ?>
                                    <div class="field-item">
                                        <label>
                                            <input type="checkbox" name="fields[]" value="<?php echo htmlspecialchars($column['name']); ?>"
                                                <?php echo in_array($column['name'], $reportConfig['fields'] ?? []) ? 'checked' : ''; ?>>
                                            <?php echo htmlspecialchars($column['name']); ?> (<?php echo htmlspecialchars($column['type']); ?>)
                                        </label>
                                    </div>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <p class="empty-message">请先选择数据表以显示可用字段。</p>
                            <?php endif; ?>
                        </div>
                    </div>

                    <div class="form-group">
                        <label for="sort_field">排序字段</label>
                        <select id="sort_field" name="sort_field" class="form-control">
                            <option value="">-- 不排序 --</option>
                            <?php if (!empty($reportColumns)): ?>
                                <?php foreach ($reportColumns as $column): ?>
                                    <option value="<?php echo htmlspecialchars($column['name']); ?>"
                                        <?php echo isset($reportConfig['sort_field']) && $reportConfig['sort_field'] === $column['name'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($column['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="sort_order">排序方式</label>
                        <select id="sort_order" name="sort_order" class="form-control">
                            <option value="ASC" <?php echo isset($reportConfig['sort_order']) && $reportConfig['sort_order'] === 'ASC' ? 'selected' : ''; ?>>升序 (ASC)</option>
                            <option value="DESC" <?php echo isset($reportConfig['sort_order']) && $reportConfig['sort_order'] === 'DESC' ? 'selected' : ''; ?>>降序 (DESC)</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="group_by">分组字段</label>
                        <select id="group_by" name="group_by" class="form-control">
                            <option value="">-- 不分组 --</option>
                            <?php if (!empty($reportColumns)): ?>
                                <?php foreach ($reportColumns as $column): ?>
                                    <option value="<?php echo htmlspecialchars($column['name']); ?>"
                                        <?php echo isset($reportConfig['group_by']) && $reportConfig['group_by'] === $column['name'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($column['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="limit">限制记录数</label>
                        <input type="number" id="limit" name="limit" class="form-control" min="1" max="1000"
                            value="<?php echo htmlspecialchars($reportConfig['limit'] ?? 100); ?>">
                    </div>
                </div>

                <div class="form-section">
                    <h4>筛选条件</h4>
                    <div id="filters-container">
                        <?php if (!empty($reportConfig['filters'])): ?>
                            <?php foreach ($reportConfig['filters'] as $index => $filter): ?>
                                <div class="filter-row">
                                    <div class="filter-field">
                                        <label>字段</label>
                                        <select name="filters[<?php echo $index; ?>][field]" class="form-control filter-field-select">
                                            <option value="">-- 选择字段 --</option>
                                            <?php foreach ($reportColumns as $column): ?>
                                                <option value="<?php echo htmlspecialchars($column['name']); ?>"
                                                    <?php echo $filter['field'] === $column['name'] ? 'selected' : ''; ?>>
                                                    <?php echo htmlspecialchars($column['name']); ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </div>

                                    <div class="filter-operator">
                                        <label>操作符</label>
                                        <select name="filters[<?php echo $index; ?>][operator]" class="form-control">
                                            <option value="equals" <?php echo $filter['operator'] === 'equals' ? 'selected' : ''; ?>>等于</option>
                                            <option value="not_equals" <?php echo $filter['operator'] === 'not_equals' ? 'selected' : ''; ?>>不等于</option>
                                            <option value="greater_than" <?php echo $filter['operator'] === 'greater_than' ? 'selected' : ''; ?>>大于</option>
                                            <option value="less_than" <?php echo $filter['operator'] === 'less_than' ? 'selected' : ''; ?>>小于</option>
                                            <option value="contains" <?php echo $filter['operator'] === 'contains' ? 'selected' : ''; ?>>包含</option>
                                            <option value="starts_with" <?php echo $filter['operator'] === 'starts_with' ? 'selected' : ''; ?>>开头是</option>
                                            <option value="ends_with" <?php echo $filter['operator'] === 'ends_with' ? 'selected' : ''; ?>>结尾是</option>
                                            <option value="in" <?php echo $filter['operator'] === 'in' ? 'selected' : ''; ?>>在列表中</option>
                                            <option value="not_in" <?php echo $filter['operator'] === 'not_in' ? 'selected' : ''; ?>>不在列表中</option>
                                        </select>
                                    </div>

                                    <div class="filter-value">
                                        <label>值</label>
                                        <input type="text" name="filters[<?php echo $index; ?>][value]" class="form-control"
                                            value="<?php echo htmlspecialchars($filter['value']); ?>">
                                    </div>

                                    <div class="filter-actions">
                                        <button type="button" class="btn btn-sm btn-danger remove-filter">删除</button>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </div>

                    <button type="button" id="add-filter" class="btn btn-sm btn-secondary">添加筛选条件</button>
                </div>

                <div class="form-section">
                    <h4>显示配置</h4>
                    <div class="form-group">
                        <label for="chart_type">图表类型</label>
                        <select id="chart_type" name="chart_type" class="form-control">
                            <option value="table" <?php echo isset($displayConfig['chart_type']) && $displayConfig['chart_type'] === 'table' ? 'selected' : ''; ?>>表格</option>
                            <option value="bar" <?php echo isset($displayConfig['chart_type']) && $displayConfig['chart_type'] === 'bar' ? 'selected' : ''; ?>>柱状图</option>
                            <option value="line" <?php echo isset($displayConfig['chart_type']) && $displayConfig['chart_type'] === 'line' ? 'selected' : ''; ?>>折线图</option>
                            <option value="pie" <?php echo isset($displayConfig['chart_type']) && $displayConfig['chart_type'] === 'pie' ? 'selected' : ''; ?>>饼图</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="chart_title">图表标题</label>
                        <input type="text" id="chart_title" name="chart_title" class="form-control"
                            value="<?php echo htmlspecialchars($displayConfig['chart_title'] ?? ''); ?>">
                    </div>

                    <div class="form-group">
                        <label for="x_axis">X轴字段</label>
                        <select id="x_axis" name="x_axis" class="form-control">
                            <option value="">-- 选择字段 --</option>
                            <?php if (!empty($reportColumns)): ?>
                                <?php foreach ($reportColumns as $column): ?>
                                    <option value="<?php echo htmlspecialchars($column['name']); ?>"
                                        <?php echo isset($displayConfig['x_axis']) && $displayConfig['x_axis'] === $column['name'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($column['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="y_axis">Y轴字段</label>
                        <select id="y_axis" name="y_axis" class="form-control">
                            <option value="">-- 选择字段 --</option>
                            <?php if (!empty($reportColumns)): ?>
                                <?php foreach ($reportColumns as $column): ?>
                                    <option value="<?php echo htmlspecialchars($column['name']); ?>"
                                        <?php echo isset($displayConfig['y_axis']) && $displayConfig['y_axis'] === $column['name'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($column['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </select>
                    </div>
                </div>

                <div class="form-actions">
                    <button type="submit" name="save_report" class="btn btn-primary">保存报表</button>
                    <a href="index.php?page=custom" class="btn btn-secondary">取消</a>
                </div>
            </form>
        </div>
    <?php endif; ?>

    <?php if ($action === 'view' && !empty($reportData)): ?>
        <!-- 查看报表 -->
        <div class="report-view-container">
            <div class="report-header">
                <h3><?php echo htmlspecialchars($reportData['report_name']); ?></h3>
                <div class="report-meta">
                    <span class="report-type"><?php echo htmlspecialchars($reportData['report_type']); ?></span>
                    <span class="report-date">创建于: <?php echo date('Y-m-d H:i', strtotime($reportData['created_at'])); ?></span>
                    <?php if ($reportData['user_id'] === $user_id): ?>
                        <a href="index.php?page=custom&action=edit&id=<?php echo $reportData['custom_report_id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                    <?php endif; ?>
                    <a href="index.php?page=custom" class="btn btn-sm btn-secondary">返回列表</a>
                </div>
            </div>

            <?php if (isset($errors) && !empty($errors)): ?>
                <?php foreach ($errors as $error): ?>
                    <div class="alert alert-error"><?php echo htmlspecialchars($error); ?></div>
                <?php endforeach; ?>
            <?php else: ?>
                <?php if ($reportResult && $reportResult->num_rows > 0): ?>
                    <div class="report-content">
                        <?php if ($displayConfig['chart_type'] === 'table' || empty($displayConfig['chart_type'])): ?>
                            <!-- 表格显示 -->
                            <div class="table-responsive">
                                <table class="data-table">
                                    <thead>
                                        <tr>
                                            <?php
                                            $fields = $reportConfig['fields'] ?? [];
                                            foreach ($fields as $field):
                                            ?>
                                                <th><?php echo htmlspecialchars($field); ?></th>
                                            <?php endforeach; ?>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php while ($row = $reportResult->fetch_assoc()): ?>
                                            <tr>
                                                <?php foreach ($fields as $field): ?>
                                                    <td><?php echo htmlspecialchars($row[$field] ?? ''); ?></td>
                                                <?php endforeach; ?>
                                            </tr>
                                        <?php endwhile; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php else: ?>
                            <!-- 图表显示 -->
                            <div class="chart-container">
                                <div id="report-chart" style="width:100%; height:400px;"></div>
                            </div>

                            <script>
                                // 将PHP数据转换为JavaScript数据
                                const chartData = <?php
                                                    $chartData = [];
                                                    $reportResult->data_seek(0); // 重置结果集指针
                                                    while ($row = $reportResult->fetch_assoc()) {
                                                        $chartData[] = $row;
                                                    }
                                                    echo json_encode($chartData);
                                                    ?>;

                                const chartType = "<?php echo $displayConfig['chart_type']; ?>";
                                const chartTitle = "<?php echo addslashes($displayConfig['chart_title'] ?? $reportData['report_name']); ?>";
                                const xAxis = "<?php echo $displayConfig['x_axis'] ?? ''; ?>";
                                const yAxis = "<?php echo $displayConfig['y_axis'] ?? ''; ?>";

                                // 在页面加载完成后初始化图表
                                document.addEventListener('DOMContentLoaded', function() {
                                    initChart(chartData, chartType, chartTitle, xAxis, yAxis);
                                });

                                function initChart(data, type, title, xAxis, yAxis) {
                                    if (!data || data.length === 0 || !xAxis || !yAxis) {
                                        document.getElementById('report-chart').innerHTML = '<div class="alert alert-info">没有足够的数据或配置来显示图表</div>';
                                        return;
                                    }

                                    // 这里应该引入一个图表库，如Chart.js或ECharts
                                    // 以下是一个简单的示意，实际项目中应该使用图表库来实现
                                    const chartContainer = document.getElementById('report-chart');
                                    chartContainer.innerHTML = '<div class="alert alert-info">这里将显示' + type + '图表，标题为"' + title + '"，X轴为"' + xAxis + '"，Y轴为"' + yAxis + '"</div>';
                                    chartContainer.innerHTML += '<div class="alert alert-warning">要显示实际图表，请引入Chart.js或ECharts等图表库</div>';

                                    // 以下是一个示例数据表格，显示将用于图表的数据
                                    let tableHtml = '<table class="data-table"><thead><tr><th>' + xAxis + '</th><th>' + yAxis + '</th></tr></thead><tbody>';

                                    data.forEach(function(item) {
                                        tableHtml += '<tr><td>' + (item[xAxis] || '') + '</td><td>' + (item[yAxis] || '') + '</td></tr>';
                                    });

                                    tableHtml += '</tbody></table>';
                                    chartContainer.innerHTML += tableHtml;
                                }
                            </script>
                        <?php endif; ?>
                    </div>
                <?php else: ?>
                    <div class="alert alert-info">没有找到符合条件的数据</div>
                <?php endif; ?>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</div>

<style>
    .custom-reports-container {
        padding: 20px;
    }

    .reports-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 20px;
    }

    .reports-section {
        margin-bottom: 30px;
    }

    .reports-list {
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
        gap: 20px;
        margin-top: 15px;
    }

    .report-card {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        padding: 15px;
        display: flex;
        flex-direction: column;
    }

    .report-header {
        margin-bottom: 10px;
    }

    .report-header h5 {
        margin: 0;
        font-size: 16px;
        margin-bottom: 5px;
    }

    .report-type {
        font-size: 12px;
        color: #666;
        background-color: #f0f0f0;
        padding: 3px 8px;
        border-radius: 10px;
        display: inline-block;
    }

    .report-info {
        margin-bottom: 15px;
        font-size: 12px;
        color: #666;
    }

    .report-date {
        margin-right: 10px;
    }

    .report-public {
        color: #28a745;
    }

    .report-private {
        color: #dc3545;
    }

    .report-actions {
        margin-top: auto;
        display: flex;
        gap: 10px;
    }

    .empty-message {
        color: #666;
        font-style: italic;
    }

    /* 表单样式 */
    .report-form-container {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        padding: 20px;
    }

    .back-btn {
        margin-bottom: 20px;
    }

    .form-section {
        margin-bottom: 30px;
        padding-bottom: 20px;
        border-bottom: 1px solid #eee;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: 500;
    }

    .required {
        color: #dc3545;
        margin-left: 3px;
    }

    .form-control {
        width: 100%;
        padding: 8px 12px;
        border: 1px solid #ddd;
        border-radius: 4px;
        font-size: 14px;
    }

    .form-text {
        font-size: 12px;
        color: #666;
        margin-top: 5px;
    }

    .fields-list {
        max-height: 200px;
        overflow-y: auto;
        border: 1px solid #ddd;
        border-radius: 4px;
        padding: 10px;
        margin-top: 5px;
    }

    .field-item {
        margin-bottom: 5px;
    }

    .filter-row {
        display: flex;
        gap: 10px;
        margin-bottom: 10px;
        align-items: flex-end;
    }

    .filter-field,
    .filter-operator,
    .filter-value {
        flex: 1;
    }

    .filter-actions {
        flex: 0 0 auto;
        padding-bottom: 8px;
    }

    .form-actions {
        margin-top: 20px;
        display: flex;
        gap: 10px;
    }

    /* 查看报表样式 */
    .report-view-container {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        padding: 20px;
    }

    .report-view-container .report-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 20px;
        padding-bottom: 15px;
        border-bottom: 1px solid #eee;
    }

    .report-meta {
        display: flex;
        align-items: center;
        gap: 15px;
    }

    .report-content {
        margin-top: 20px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f5f5f5;
        font-weight: 500;
    }

    .table-responsive {
        overflow-x: auto;
    }

    .chart-container {
        margin-top: 20px;
    }

    @media (max-width: 768px) {
        .reports-list {
            grid-template-columns: 1fr;
        }

        .filter-row {
            flex-direction: column;
            gap: 15px;
        }

        .filter-field,
        .filter-operator,
        .filter-value {
            width: 100%;
        }

        .report-view-container .report-header {
            flex-direction: column;
            align-items: flex-start;
        }

        .report-meta {
            margin-top: 10px;
            flex-wrap: wrap;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 表格选择更改时加载字段
        const tableSelect = document.getElementById('table_name');
        if (tableSelect) {
            tableSelect.addEventListener('change', function() {
                const tableName = this.value;
                if (tableName) {
                    window.location.href = 'index.php?page=custom&action=<?php echo $action; ?><?php echo $report_id > 0 ? '&id=' . $report_id : ''; ?>&table=' + tableName;
                }
            });
        }

        // 添加筛选条件按钮
        const addFilterBtn = document.getElementById('add-filter');
        if (addFilterBtn) {
            addFilterBtn.addEventListener('click', function() {
                const filtersContainer = document.getElementById('filters-container');
                const filterCount = filtersContainer.querySelectorAll('.filter-row').length;

                const filterRow = document.createElement('div');
                filterRow.className = 'filter-row';

                // 生成字段选择器
                let fieldsOptions = '<option value="">-- 选择字段 --</option>';
                <?php if (!empty($reportColumns)): ?>
                    <?php foreach ($reportColumns as $column): ?>
                        fieldsOptions += '<option value="<?php echo htmlspecialchars($column['name']); ?>"><?php echo htmlspecialchars($column['name']); ?></option>';
                    <?php endforeach; ?>
                <?php endif; ?>

                // 生成运算符选择器
                const operatorsOptions = `
                <option value="equals">等于</option>
                <option value="not_equals">不等于</option>
                <option value="greater_than">大于</option>
                <option value="less_than">小于</option>
                <option value="contains">包含</option>
                <option value="starts_with">开头是</option>
                <option value="ends_with">结尾是</option>
                <option value="in">在列表中</option>
                <option value="not_in">不在列表中</option>
            `;

                filterRow.innerHTML = `
                <div class="filter-field">
                    <label>字段</label>
                    <select name="filters[${filterCount}][field]" class="form-control filter-field-select">
                        ${fieldsOptions}
                    </select>
                </div>
                
                <div class="filter-operator">
                    <label>操作符</label>
                    <select name="filters[${filterCount}][operator]" class="form-control">
                        ${operatorsOptions}
                    </select>
                </div>
                
                <div class="filter-value">
                    <label>值</label>
                    <input type="text" name="filters[${filterCount}][value]" class="form-control">
                </div>
                
                <div class="filter-actions">
                    <button type="button" class="btn btn-sm btn-danger remove-filter">删除</button>
                </div>
            `;

                filtersContainer.appendChild(filterRow);

                // 为新添加的删除按钮绑定事件
                filterRow.querySelector('.remove-filter').addEventListener('click', function() {
                    filterRow.remove();
                });
            });
        }

        // 为现有的删除按钮绑定事件
        document.querySelectorAll('.remove-filter').forEach(function(button) {
            button.addEventListener('click', function() {
                this.closest('.filter-row').remove();
            });
        });
    });
</script>