<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';

// 获取排序和分页参数
$sortBy = isset($_GET['sort_by']) ? sanitize($_GET['sort_by']) : 'sales_count'; // 默认按销量排序
$sortOrder = isset($_GET['order']) ? sanitize($_GET['order']) : 'desc'; // 默认降序排列
$page = isset($_GET['p']) ? intval($_GET['p']) : 1;
$limit = 20; // 每页显示商品数量
$offset = ($page - 1) * $limit;

// 时间周期筛选
$periodType = isset($_GET['period']) ? sanitize($_GET['period']) : 'month'; // 默认显示月度数据
$periodDate = isset($_GET['date']) ? sanitize($_GET['date']) : date('Y-m-01'); // 默认显示当月

// 验证排序字段是否有效
$validSortFields = ['sales_count', 'sales_amount', 'profit', 'profit_rate'];
if (!in_array($sortBy, $validSortFields)) {
    $sortBy = 'sales_count';
}

// 验证排序顺序是否有效
$validSortOrders = ['asc', 'desc'];
if (!in_array($sortOrder, $validSortOrders)) {
    $sortOrder = 'desc';
}

// 验证周期类型是否有效
$validPeriodTypes = ['day', 'week', 'month', 'year'];
if (!in_array($periodType, $validPeriodTypes)) {
    $periodType = 'month';
}

// 验证日期格式是否有效
if (!preg_match('/^\d{4}-\d{2}-\d{2}$/', $periodDate)) {
    $periodDate = date('Y-m-01');
}

// 构建排序字段
$sortField = '';
switch ($sortBy) {
    case 'sales_count':
        $sortField = 'pp.sales_count';
        break;
    case 'sales_amount':
        $sortField = 'pp.sales_amount';
        break;
    case 'profit':
        $sortField = 'pp.profit';
        break;
    case 'profit_rate':
        $sortField = 'pp.profit_rate';
        break;
    default:
        $sortField = 'pp.sales_count';
}

// 查询统计数据
$sql = "SELECT pp.*, p.product_name, p.barcode, p.unit, p.unit_price, p.brand, p.manufacturer
        FROM product_popularity pp
        JOIN products p ON pp.product_id = p.product_id
        WHERE pp.period_type = ? AND pp.stat_date = ?
        ORDER BY $sortField $sortOrder
        LIMIT ?, ?";

$result = executeQuery($conn, $sql, 'ssii', [$periodType, $periodDate, $offset, $limit]);

// 统计总记录数用于分页
$countSql = "SELECT COUNT(*) as total 
             FROM product_popularity 
             WHERE period_type = ? AND stat_date = ?";
$countResult = executeQuery($conn, $countSql, 'ss', [$periodType, $periodDate]);
$totalRecords = ($countResult['success'] && !empty($countResult['data'])) ? $countResult['data'][0]['total'] : 0;
$totalPages = ceil($totalRecords / $limit);

// 如果没有数据，生成一条提示信息
if (!$result['success'] || empty($result['data'])) {
    $message = '当前时间周期内没有商品销售数据，请选择其他时间周期或检查数据统计状态。';
    $messageType = 'info';
}

// 构建页面URL的函数
function buildPageUrl($page, $sortBy, $sortOrder, $periodType, $periodDate)
{
    return "index.php?page=popular&sort_by=$sortBy&order=$sortOrder&period=$periodType&date=$periodDate&p=$page";
}

// 获取排序链接
function getSortLink($field, $currentSortBy, $currentSortOrder, $periodType, $periodDate)
{
    $newOrder = ($currentSortBy == $field && $currentSortOrder == 'desc') ? 'asc' : 'desc';
    $sortIcon = '';

    if ($currentSortBy == $field) {
        $sortIcon = ($currentSortOrder == 'desc') ? '▼' : '▲';
    }

    return "index.php?page=popular&sort_by=$field&order=$newOrder&period=$periodType&date=$periodDate" . $sortIcon;
}

// 格式化数字的函数
function formatNumber($number, $decimals = 2)
{
    return number_format($number, $decimals, '.', ',');
}
?>

<div class="page-header">
    <h3>热门商品排行榜</h3>
    <p class="page-description">按销量、销售额、利润展示热门商品数据，帮助您了解产品销售情况</p>
</div>

<!-- 筛选表单 -->
<div class="filter-container">
    <form action="index.php" method="get" class="filter-form">
        <input type="hidden" name="page" value="popular">

        <div class="form-group">
            <label for="period">统计周期:</label>
            <select id="period" name="period" class="form-control">
                <option value="day" <?php echo $periodType == 'day' ? 'selected' : ''; ?>>日</option>
                <option value="week" <?php echo $periodType == 'week' ? 'selected' : ''; ?>>周</option>
                <option value="month" <?php echo $periodType == 'month' ? 'selected' : ''; ?>>月</option>
                <option value="year" <?php echo $periodType == 'year' ? 'selected' : ''; ?>>年</option>
            </select>
        </div>

        <div class="form-group">
            <label for="date">日期:</label>
            <input type="date" id="date" name="date" class="form-control" value="<?php echo $periodDate; ?>">
        </div>

        <div class="form-actions">
            <button type="submit" class="btn btn-primary">查询</button>
        </div>
    </form>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 商品排行表格 -->
<?php if ($result['success'] && !empty($result['data'])): ?>
    <div class="data-container">
        <div class="data-header">
            <div class="total-info">
                共找到 <strong><?php echo $totalRecords; ?></strong> 条记录
            </div>
        </div>

        <table class="data-table">
            <thead>
                <tr>
                    <th>排名</th>
                    <th>商品名称</th>
                    <th>条码</th>
                    <th>品牌</th>
                    <th>单位</th>
                    <th>单价(¥)</th>
                    <th>
                        <a href="<?php echo getSortLink('sales_count', $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="sort-link">
                            销量 <?php echo ($sortBy == 'sales_count') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                        </a>
                    </th>
                    <th>
                        <a href="<?php echo getSortLink('sales_amount', $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="sort-link">
                            销售额(¥) <?php echo ($sortBy == 'sales_amount') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                        </a>
                    </th>
                    <th>
                        <a href="<?php echo getSortLink('profit', $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="sort-link">
                            利润(¥) <?php echo ($sortBy == 'profit') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                        </a>
                    </th>
                    <th>
                        <a href="<?php echo getSortLink('profit_rate', $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="sort-link">
                            利润率(%) <?php echo ($sortBy == 'profit_rate') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                        </a>
                    </th>
                </tr>
            </thead>
            <tbody>
                <?php
                $rowNumber = $offset + 1;
                foreach ($result['data'] as $row):
                ?>
                    <tr>
                        <td class="text-center"><?php echo $rowNumber++; ?></td>
                        <td><?php echo htmlspecialchars($row['product_name']); ?></td>
                        <td><?php echo htmlspecialchars($row['barcode']); ?></td>
                        <td><?php echo htmlspecialchars($row['brand'] ?: '-'); ?></td>
                        <td><?php echo htmlspecialchars($row['unit']); ?></td>
                        <td class="text-right"><?php echo formatNumber($row['unit_price']); ?></td>
                        <td class="text-right"><?php echo formatNumber($row['sales_count'], 0); ?></td>
                        <td class="text-right"><?php echo formatNumber($row['sales_amount']); ?></td>
                        <td class="text-right"><?php echo formatNumber($row['profit']); ?></td>
                        <td class="text-right"><?php echo formatNumber($row['profit_rate']); ?>%</td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <!-- 分页 -->
        <?php if ($totalPages > 1): ?>
            <div class="pagination">
                <?php if ($page > 1): ?>
                    <a href="<?php echo buildPageUrl(1, $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="page-link">首页</a>
                    <a href="<?php echo buildPageUrl($page - 1, $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="page-link">上一页</a>
                <?php endif; ?>

                <?php
                $startPage = max(1, $page - 2);
                $endPage = min($totalPages, $startPage + 4);

                if ($endPage - $startPage < 4) {
                    $startPage = max(1, $endPage - 4);
                }

                for ($i = $startPage; $i <= $endPage; $i++):
                ?>
                    <a href="<?php echo buildPageUrl($i, $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="page-link <?php echo ($i == $page) ? 'active' : ''; ?>"><?php echo $i; ?></a>
                <?php endfor; ?>

                <?php if ($page < $totalPages): ?>
                    <a href="<?php echo buildPageUrl($page + 1, $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="page-link">下一页</a>
                    <a href="<?php echo buildPageUrl($totalPages, $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="page-link">末页</a>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>
<?php endif; ?>

<style>
    .page-header {
        margin-bottom: 20px;
    }

    .page-description {
        color: #666;
        margin-top: 5px;
    }

    .filter-container {
        background-color: #f9f9f9;
        padding: 15px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        align-items: flex-end;
    }

    .form-group {
        margin-bottom: 0;
    }

    .data-container {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    .data-header {
        padding: 10px 15px;
        border-bottom: 1px solid #eee;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .total-info {
        color: #666;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px 15px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f9f9f9;
        font-weight: bold;
    }

    .data-table tbody tr:hover {
        background-color: #f5f5f5;
    }

    .text-center {
        text-align: center;
    }

    .text-right {
        text-align: right;
    }

    .sort-link {
        color: inherit;
        text-decoration: none;
        display: flex;
        align-items: center;
        justify-content: space-between;
    }

    .sort-link:hover {
        color: #007bff;
    }

    .pagination {
        display: flex;
        justify-content: center;
        padding: 20px 0;
        gap: 5px;
    }

    .page-link {
        display: inline-block;
        padding: 5px 10px;
        background-color: #f9f9f9;
        border: 1px solid #ddd;
        color: #333;
        text-decoration: none;
        border-radius: 3px;
    }

    .page-link.active {
        background-color: #007bff;
        color: white;
        border-color: #007bff;
    }

    .page-link:hover:not(.active) {
        background-color: #e9e9e9;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 根据选择的周期类型，修改日期输入的类型
        const periodSelect = document.getElementById('period');
        const dateInput = document.getElementById('date');

        periodSelect.addEventListener('change', function() {
            const periodType = this.value;

            if (periodType === 'year') {
                dateInput.type = 'text';
                dateInput.pattern = '\\d{4}';
                dateInput.placeholder = 'YYYY';
                // 只保留年份
                if (dateInput.value) {
                    dateInput.value = dateInput.value.substr(0, 4);
                }
            } else {
                dateInput.type = 'date';
            }
        });

        // 初始化时也要调用一次
        if (periodSelect.value === 'year') {
            dateInput.type = 'text';
            dateInput.pattern = '\\d{4}';
            dateInput.placeholder = 'YYYY';
            if (dateInput.value) {
                dateInput.value = dateInput.value.substr(0, 4);
            }
        }
    });
</script>