<?php
// 确保用户已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取筛选参数
$periodType = isset($_GET['period']) ? sanitize($_GET['period']) : 'month'; // 默认月度数据
$periodDate = isset($_GET['date']) ? sanitize($_GET['date']) : date('Y-m-01'); // 默认当月
$sortBy = isset($_GET['sort_by']) ? sanitize($_GET['sort_by']) : 'sales_amount'; // 默认按销售额排序
$sortOrder = isset($_GET['order']) ? sanitize($_GET['order']) : 'desc'; // 默认降序
$dimensionType = isset($_GET['dimension']) ? sanitize($_GET['dimension']) : 'all'; // 默认不筛选维度
$page = isset($_GET['p']) ? intval($_GET['p']) : 1;
$limit = 10; // 每页显示10条记录
$offset = ($page - 1) * $limit;

// 构建查询条件
$whereConditions = [
    "period_type = '$periodType'",
    "stat_date = '$periodDate'"
];

if ($dimensionType != 'all' && in_array($dimensionType, ['product', 'customer'])) {
    $whereConditions[] = "dimension_type = '$dimensionType'";
}

$whereClause = implode(' AND ', $whereConditions);

// 获取销售分析数据 - 客户维度
$clientSql = "SELECT * FROM custom_sales_analysis 
             WHERE dimension_type = 'customer' AND $whereClause
             ORDER BY $sortBy $sortOrder
             LIMIT $limit";
$clientResult = $conn->query($clientSql);

// 获取销售分析数据 - 商品维度
$productSql = "SELECT * FROM custom_sales_analysis 
               WHERE dimension_type = 'product' AND $whereClause
               ORDER BY $sortBy $sortOrder
               LIMIT $limit";
$productResult = $conn->query($productSql);

// 获取汇总数据
$summarySql = "SELECT 
                SUM(order_count) as total_orders,
                SUM(customer_count) as total_customers,
                SUM(sales_quantity) as total_quantity,
                SUM(sales_amount) as total_amount,
                AVG(avg_order_value) as avg_order
              FROM custom_sales_analysis
              WHERE dimension_type = 'product' AND $whereClause";
$summaryResult = $conn->query($summarySql);
$summaryData = $summaryResult ? $summaryResult->fetch_assoc() : ['total_orders' => 0, 'total_customers' => 0, 'total_quantity' => 0, 'total_amount' => 0, 'avg_order' => 0];

// 获取上月数据进行比较
// 根据当前选择的周期计算上一周期日期
$previousPeriodDate = '';
if ($periodType == 'month') {
    $previousPeriodDate = date('Y-m-01', strtotime("$periodDate -1 month"));
} elseif ($periodType == 'year') {
    $previousPeriodDate = date('Y-01-01', strtotime("$periodDate -1 year"));
} else {
    $previousPeriodDate = date('Y-m-d', strtotime("$periodDate -7 days"));
}

$lastPeriodSql = "SELECT 
                   SUM(sales_amount) as last_period_amount
                 FROM custom_sales_analysis
                 WHERE dimension_type = 'product' 
                 AND period_type = '$periodType'
                 AND stat_date = '$previousPeriodDate'";
$lastPeriodResult = $conn->query($lastPeriodSql);
$lastPeriodData = $lastPeriodResult ? $lastPeriodResult->fetch_assoc() : ['last_period_amount' => 0];

// 计算环比增长
$growthRate = 0;
if ($lastPeriodData && $lastPeriodData['last_period_amount'] > 0) {
    $growthRate = ($summaryData['total_amount'] - $lastPeriodData['last_period_amount']) / $lastPeriodData['last_period_amount'] * 100;
}

// 获取可用的时间周期
$periodsSql = "SELECT DISTINCT stat_date FROM custom_sales_analysis WHERE period_type = '$periodType' ORDER BY stat_date DESC LIMIT 12";
$periodsResult = $conn->query($periodsSql);
$availablePeriods = [];
if ($periodsResult && $periodsResult->num_rows > 0) {
    while ($row = $periodsResult->fetch_assoc()) {
        $availablePeriods[] = $row['stat_date'];
    }
}

// 格式化周期显示
function formatPeriodDate($date, $periodType)
{
    if ($periodType == 'month') {
        return date('Y年m月', strtotime($date));
    } elseif ($periodType == 'year') {
        return date('Y年', strtotime($date));
    } else {
        return date('Y年m月d日', strtotime($date));
    }
}

// 构建分页URL
function buildPageUrl($page, $periodType, $periodDate, $sortBy, $sortOrder, $dimensionType)
{
    return "index.php?page=sales&period=$periodType&date=$periodDate&sort_by=$sortBy&order=$sortOrder&dimension=$dimensionType&p=$page";
}

// 构建排序链接
function getSortLink($field, $currentSortBy, $currentSortOrder, $periodType, $periodDate, $dimensionType)
{
    $newOrder = ($currentSortBy == $field && $currentSortOrder == 'desc') ? 'asc' : 'desc';
    return "index.php?page=sales&period=$periodType&date=$periodDate&sort_by=$field&order=$newOrder&dimension=$dimensionType";
}
?>

<div class="analysis-filter">
    <form method="get" class="filter-form">
        <input type="hidden" name="page" value="sales">

        <div class="form-group">
            <label for="period">统计周期</label>
            <select name="period" id="period" class="form-control" onchange="this.form.submit()">
                <option value="month" <?php echo $periodType == 'month' ? 'selected' : ''; ?>>月度</option>
                <option value="year" <?php echo $periodType == 'year' ? 'selected' : ''; ?>>年度</option>
                <option value="week" <?php echo $periodType == 'week' ? 'selected' : ''; ?>>周度</option>
                <option value="day" <?php echo $periodType == 'day' ? 'selected' : ''; ?>>日度</option>
            </select>
        </div>

        <div class="form-group">
            <label for="date">统计日期</label>
            <select name="date" id="date" class="form-control" onchange="this.form.submit()">
                <?php foreach ($availablePeriods as $period): ?>
                    <option value="<?php echo $period; ?>" <?php echo $periodDate == $period ? 'selected' : ''; ?>>
                        <?php echo formatPeriodDate($period, $periodType); ?>
                    </option>
                <?php endforeach; ?>
                <?php if (empty($availablePeriods)): ?>
                    <option value="<?php echo date('Y-m-01'); ?>"><?php echo formatPeriodDate(date('Y-m-01'), 'month'); ?></option>
                <?php endif; ?>
            </select>
        </div>

        <div class="form-group">
            <label for="dimension">显示维度</label>
            <select name="dimension" id="dimension" class="form-control" onchange="this.form.submit()">
                <option value="all" <?php echo $dimensionType == 'all' ? 'selected' : ''; ?>>全部</option>
                <option value="product" <?php echo $dimensionType == 'product' ? 'selected' : ''; ?>>仅商品</option>
                <option value="customer" <?php echo $dimensionType == 'customer' ? 'selected' : ''; ?>>仅客户</option>
            </select>
        </div>

        <div class="form-group">
            <label for="sort_by">排序方式</label>
            <select name="sort_by" id="sort_by" class="form-control" onchange="this.form.submit()">
                <option value="sales_amount" <?php echo $sortBy == 'sales_amount' ? 'selected' : ''; ?>>按销售额</option>
                <option value="order_count" <?php echo $sortBy == 'order_count' ? 'selected' : ''; ?>>按订单数</option>
                <option value="sales_quantity" <?php echo $sortBy == 'sales_quantity' ? 'selected' : ''; ?>>按销售数量</option>
                <option value="avg_order_value" <?php echo $sortBy == 'avg_order_value' ? 'selected' : ''; ?>>按平均客单价</option>
            </select>
        </div>

        <div class="form-group">
            <label for="order">排序顺序</label>
            <select name="order" id="order" class="form-control" onchange="this.form.submit()">
                <option value="desc" <?php echo $sortOrder == 'desc' ? 'selected' : ''; ?>>降序</option>
                <option value="asc" <?php echo $sortOrder == 'asc' ? 'selected' : ''; ?>>升序</option>
            </select>
        </div>
    </form>
</div>

<div class="analysis-dashboard">
    <!-- 销售概览 -->
    <div class="analysis-overview">
        <div class="stat-card">
            <div class="stat-title"><?php echo formatPeriodDate($periodDate, $periodType); ?> 销售额</div>
            <div class="stat-value"><?php echo isset($summaryData['total_amount']) ? '¥' . number_format($summaryData['total_amount'], 2) : '¥0.00'; ?></div>
            <div class="stat-change <?php echo $growthRate >= 0 ? 'positive' : 'negative'; ?>">
                <span class="change-icon"><?php echo $growthRate >= 0 ? '↑' : '↓'; ?></span>
                <span class="change-value"><?php echo abs(round($growthRate, 1)); ?>%</span>
                <span class="change-label">环比上期</span>
            </div>
        </div>

        <div class="stat-card">
            <div class="stat-title">订单数量</div>
            <div class="stat-value"><?php echo isset($summaryData['total_orders']) ? number_format($summaryData['total_orders']) : '0'; ?></div>
        </div>

        <div class="stat-card">
            <div class="stat-title">客户数量</div>
            <div class="stat-value"><?php echo isset($summaryData['total_customers']) ? number_format($summaryData['total_customers']) : '0'; ?></div>
        </div>

        <div class="stat-card">
            <div class="stat-title">平均客单价</div>
            <div class="stat-value"><?php echo isset($summaryData['avg_order']) ? '¥' . number_format($summaryData['avg_order'], 2) : '¥0.00'; ?></div>
        </div>
    </div>

    <?php if ($dimensionType == 'all' || $dimensionType == 'customer'): ?>
        <!-- 客户销售TOP10 -->
        <div class="analysis-section">
            <h3>客户销售TOP10</h3>
            <div class="data-table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>客户名称</th>
                            <th>
                                <a href="<?php echo getSortLink('order_count', $sortBy, $sortOrder, $periodType, $periodDate, $dimensionType); ?>" class="sort-link">
                                    订单数 <?php echo ($sortBy == 'order_count') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                                </a>
                            </th>
                            <th>
                                <a href="<?php echo getSortLink('sales_quantity', $sortBy, $sortOrder, $periodType, $periodDate, $dimensionType); ?>" class="sort-link">
                                    销售数量 <?php echo ($sortBy == 'sales_quantity') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                                </a>
                            </th>
                            <th>
                                <a href="<?php echo getSortLink('sales_amount', $sortBy, $sortOrder, $periodType, $periodDate, $dimensionType); ?>" class="sort-link">
                                    销售金额 <?php echo ($sortBy == 'sales_amount') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                                </a>
                            </th>
                            <th>
                                <a href="<?php echo getSortLink('avg_order_value', $sortBy, $sortOrder, $periodType, $periodDate, $dimensionType); ?>" class="sort-link">
                                    平均客单价 <?php echo ($sortBy == 'avg_order_value') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                                </a>
                            </th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if ($clientResult && $clientResult->num_rows > 0): ?>
                            <?php while ($row = $clientResult->fetch_assoc()): ?>
                                <tr>
                                    <td><?php echo $row['rank_by_amount']; ?></td>
                                    <td><?php echo $row['dimension_name']; ?></td>
                                    <td><?php echo number_format($row['order_count']); ?></td>
                                    <td><?php echo number_format($row['sales_quantity']); ?></td>
                                    <td><?php echo '¥' . number_format($row['sales_amount'], 2); ?></td>
                                    <td><?php echo '¥' . number_format($row['avg_order_value'], 2); ?></td>
                                </tr>
                            <?php endwhile; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="6" class="no-data">暂无数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    <?php endif; ?>

    <?php if ($dimensionType == 'all' || $dimensionType == 'product'): ?>
        <!-- 商品销售TOP10 -->
        <div class="analysis-section">
            <h3>商品销售TOP10</h3>
            <div class="data-table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>商品名称</th>
                            <th>
                                <a href="<?php echo getSortLink('order_count', $sortBy, $sortOrder, $periodType, $periodDate, $dimensionType); ?>" class="sort-link">
                                    订单数 <?php echo ($sortBy == 'order_count') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                                </a>
                            </th>
                            <th>
                                <a href="<?php echo getSortLink('customer_count', $sortBy, $sortOrder, $periodType, $periodDate, $dimensionType); ?>" class="sort-link">
                                    客户数 <?php echo ($sortBy == 'customer_count') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                                </a>
                            </th>
                            <th>
                                <a href="<?php echo getSortLink('sales_quantity', $sortBy, $sortOrder, $periodType, $periodDate, $dimensionType); ?>" class="sort-link">
                                    销售数量 <?php echo ($sortBy == 'sales_quantity') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                                </a>
                            </th>
                            <th>
                                <a href="<?php echo getSortLink('sales_amount', $sortBy, $sortOrder, $periodType, $periodDate, $dimensionType); ?>" class="sort-link">
                                    销售金额 <?php echo ($sortBy == 'sales_amount') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                                </a>
                            </th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if ($productResult && $productResult->num_rows > 0): ?>
                            <?php while ($row = $productResult->fetch_assoc()): ?>
                                <tr>
                                    <td><?php echo $row['rank_by_amount']; ?></td>
                                    <td><?php echo $row['dimension_name']; ?></td>
                                    <td><?php echo number_format($row['order_count']); ?></td>
                                    <td><?php echo number_format($row['customer_count']); ?></td>
                                    <td><?php echo number_format($row['sales_quantity']); ?></td>
                                    <td><?php echo '¥' . number_format($row['sales_amount'], 2); ?></td>
                                </tr>
                            <?php endwhile; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="6" class="no-data">暂无数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    <?php endif; ?>

    <div class="analysis-tips">
        <p>提示：数据每日更新一次。如需查看最新数据，请点击左侧菜单的"更新统计数据"。</p>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        console.log('销售分析页面加载完成');
    });
</script>

<style>
    .analysis-dashboard {
        margin: 20px 0;
    }

    .analysis-filter {
        background-color: #fff;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        align-items: flex-end;
    }

    .filter-form .form-group {
        margin-bottom: 0;
        flex: 1;
        min-width: 160px;
    }

    .analysis-overview {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 30px;
    }

    .stat-card {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        padding: 20px;
        flex: 1;
        min-width: 200px;
    }

    .stat-title {
        font-size: 0.9rem;
        color: #666;
        margin-bottom: 10px;
    }

    .stat-value {
        font-size: 1.8rem;
        font-weight: bold;
        margin-bottom: 10px;
        color: #0066cc;
    }

    .stat-change {
        display: flex;
        align-items: center;
        font-size: 0.9rem;
    }

    .stat-change.positive {
        color: #28a745;
    }

    .stat-change.negative {
        color: #dc3545;
    }

    .change-icon {
        margin-right: 5px;
        font-weight: bold;
    }

    .change-value {
        font-weight: bold;
        margin-right: 5px;
    }

    .analysis-section {
        background-color: #fff;
        border-radius: 5px;
        padding: 20px;
        margin-bottom: 30px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .analysis-section h3 {
        margin-top: 0;
        margin-bottom: 20px;
        padding-bottom: 10px;
        border-bottom: 1px solid #eee;
        color: #333;
    }

    .analysis-tips {
        background-color: #f8f9fa;
        border-radius: 5px;
        padding: 15px;
        margin-top: 20px;
        border-left: 4px solid #17a2b8;
        font-size: 0.9rem;
        color: #5a6268;
    }

    .analysis-note {
        margin-top: 10px;
        color: #856404;
    }

    .no-data {
        text-align: center;
        padding: 30px;
        color: #6c757d;
    }

    .sort-link {
        color: inherit;
        text-decoration: none;
        display: flex;
        align-items: center;
        justify-content: space-between;
    }

    .sort-link:hover {
        color: #007bff;
    }

    @media (max-width: 768px) {
        .analysis-overview {
            flex-direction: column;
        }

        .stat-card {
            min-width: 100%;
        }
    }
</style>