<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 确保用户已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 设置页面执行时间，统计可能需要较长时间
set_time_limit(300); // 5分钟

// 初始化消息数组
$successMessages = [];
$errorMessages = [];

// 包含统计脚本
require_once 'db_stats.php';

// 初始化消息变量
$message = '';
$messageType = '';
$messages = []; // 初始化消息数组

// 辅助函数：确保返回数组格式的结果
function ensureArrayResult($result)
{
    if (is_bool($result)) {
        // 如果是布尔值，则转换为标准格式 [bool, []]
        return [$result, []];
    } elseif (is_array($result) && count($result) >= 2) {
        // 如果已经是数组格式，则直接返回
        return $result;
    } else {
        // 其他情况，返回默认的成功状态
        return [false, ['处理结果格式错误']];
    }
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['update_popular'])) {
        // 更新热门商品分析
        $result = ensureArrayResult(generatePopularProductStats());
        if ($result[0]) {
            $resultMessages = isset($result[1]) && is_array($result[1]) ? $result[1] : ['热门商品分析已更新'];
            $successMessages = array_merge($successMessages, $resultMessages);
        } else {
            $resultMessages = isset($result[1]) && is_array($result[1]) ? $result[1] : ['更新热门商品分析失败'];
            $errorMessages = array_merge($errorMessages, $resultMessages);
        }
    }

    if (isset($_POST['update_inventory'])) {
        // 更新库存分析
        $result = ensureArrayResult(generateInventoryAnalysisStats());
        if ($result[0]) {
            $resultMessages = isset($result[1]) && is_array($result[1]) ? $result[1] : ['库存分析已更新'];
            $successMessages = array_merge($successMessages, $resultMessages);
        } else {
            $resultMessages = isset($result[1]) && is_array($result[1]) ? $result[1] : ['更新库存分析失败'];
            $errorMessages = array_merge($errorMessages, $resultMessages);
        }
    }

    if (isset($_POST['update_sales'])) {
        // 更新销售分析
        $result = ensureArrayResult(generateSalesAnalysisStats());
        if ($result[0]) {
            $resultMessages = isset($result[1]) && is_array($result[1]) ? $result[1] : ['销售分析已更新'];
            $successMessages = array_merge($successMessages, $resultMessages);
        } else {
            $resultMessages = isset($result[1]) && is_array($result[1]) ? $result[1] : ['更新销售分析失败'];
            $errorMessages = array_merge($errorMessages, $resultMessages);
        }
    }

    if (isset($_POST['update_profit'])) {
        // 更新利润分析
        $result = ensureArrayResult(generateProfitAnalysisStats());
        if ($result[0]) {
            $resultMessages = isset($result[1]) && is_array($result[1]) ? $result[1] : ['利润分析已更新'];
            $successMessages = array_merge($successMessages, $resultMessages);
        } else {
            $resultMessages = isset($result[1]) && is_array($result[1]) ? $result[1] : ['更新利润分析失败'];
            $errorMessages = array_merge($errorMessages, $resultMessages);
        }
    }

    if (isset($_POST['update_financial'])) {
        // 更新财务报表
        $result = ensureArrayResult(generateFinancialReportStats());
        if ($result[0]) {
            $resultMessages = isset($result[1]) && is_array($result[1]) ? $result[1] : ['财务报表已更新'];
            $successMessages = array_merge($successMessages, $resultMessages);
        } else {
            $resultMessages = isset($result[1]) && is_array($result[1]) ? $result[1] : ['更新财务报表失败'];
            $errorMessages = array_merge($errorMessages, $resultMessages);
        }
    }

    if (isset($_POST['update_all'])) {
        // 更新所有统计数据
        $popularResult = ensureArrayResult(generatePopularProductStats());
        $inventoryResult = ensureArrayResult(generateInventoryAnalysisStats());
        $salesResult = ensureArrayResult(generateSalesAnalysisStats());
        $profitResult = ensureArrayResult(generateProfitAnalysisStats());
        $financialResult = ensureArrayResult(generateFinancialReportStats());

        if ($popularResult[0]) {
            $resultMessages = isset($popularResult[1]) && is_array($popularResult[1]) ? $popularResult[1] : ['热门商品分析已更新'];
            $successMessages = array_merge($successMessages, $resultMessages);
        } else {
            $resultMessages = isset($popularResult[1]) && is_array($popularResult[1]) ? $popularResult[1] : ['更新热门商品分析失败'];
            $errorMessages = array_merge($errorMessages, $resultMessages);
        }

        if ($inventoryResult[0]) {
            $resultMessages = isset($inventoryResult[1]) && is_array($inventoryResult[1]) ? $inventoryResult[1] : ['库存分析已更新'];
            $successMessages = array_merge($successMessages, $resultMessages);
        } else {
            $resultMessages = isset($inventoryResult[1]) && is_array($inventoryResult[1]) ? $inventoryResult[1] : ['更新库存分析失败'];
            $errorMessages = array_merge($errorMessages, $resultMessages);
        }

        if ($salesResult[0]) {
            $resultMessages = isset($salesResult[1]) && is_array($salesResult[1]) ? $salesResult[1] : ['销售分析已更新'];
            $successMessages = array_merge($successMessages, $resultMessages);
        } else {
            $resultMessages = isset($salesResult[1]) && is_array($salesResult[1]) ? $salesResult[1] : ['更新销售分析失败'];
            $errorMessages = array_merge($errorMessages, $resultMessages);
        }

        if ($profitResult[0]) {
            $resultMessages = isset($profitResult[1]) && is_array($profitResult[1]) ? $profitResult[1] : ['利润分析已更新'];
            $successMessages = array_merge($successMessages, $resultMessages);
        } else {
            $resultMessages = isset($profitResult[1]) && is_array($profitResult[1]) ? $profitResult[1] : ['更新利润分析失败'];
            $errorMessages = array_merge($errorMessages, $resultMessages);
        }

        if ($financialResult[0]) {
            $resultMessages = isset($financialResult[1]) && is_array($financialResult[1]) ? $financialResult[1] : ['财务报表已更新'];
            $successMessages = array_merge($successMessages, $resultMessages);
        } else {
            $resultMessages = isset($financialResult[1]) && is_array($financialResult[1]) ? $financialResult[1] : ['更新财务报表失败'];
            $errorMessages = array_merge($errorMessages, $resultMessages);
        }
    }
}
?>

<div class="update-stats-container">
    <div class="page-header">
        <h3>更新统计数据</h3>
    </div>

    <!-- 显示消息 -->
    <?php if (!empty($successMessages)): ?>
        <?php foreach ($successMessages as $message): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($message); ?></div>
        <?php endforeach; ?>
    <?php endif; ?>

    <?php if (!empty($errorMessages)): ?>
        <?php foreach ($errorMessages as $message): ?>
            <div class="alert alert-error"><?php echo htmlspecialchars($message); ?></div>
        <?php endforeach; ?>
    <?php endif; ?>

    <div class="update-options">
        <div class="alert alert-info">
            <p><strong>注意：</strong> 更新统计数据可能需要一些时间，特别是数据量大的情况下。请耐心等待，不要刷新页面。</p>
        </div>

        <form method="post" action="">
            <div class="update-card">
                <div class="update-icon">
                    <i class="icon-stats"></i>
                </div>
                <div class="update-content">
                    <h4>热门商品分析</h4>
                    <p>更新热门商品销售排行，包括按销量、销售额和利润排名。</p>
                    <button type="submit" name="update_popular" class="btn">更新热门商品分析</button>
                </div>
            </div>

            <div class="update-card">
                <div class="update-icon">
                    <i class="icon-inventory"></i>
                </div>
                <div class="update-content">
                    <h4>库存分析</h4>
                    <p>更新库存周转率、滞销品和库存价值分析。</p>
                    <button type="submit" name="update_inventory" class="btn">更新库存分析</button>
                </div>
            </div>

            <div class="update-card">
                <div class="update-icon">
                    <i class="icon-sales"></i>
                </div>
                <div class="update-content">
                    <h4>销售分析</h4>
                    <p>更新销售趋势、客户维度和产品维度的销售数据分析。</p>
                    <button type="submit" name="update_sales" class="btn">更新销售分析</button>
                </div>
            </div>

            <div class="update-card">
                <div class="update-icon">
                    <i class="icon-profit"></i>
                </div>
                <div class="update-content">
                    <h4>利润分析</h4>
                    <p>更新利润率、品牌和产品利润分析。</p>
                    <button type="submit" name="update_profit" class="btn">更新利润分析</button>
                </div>
            </div>

            <div class="update-card">
                <div class="update-icon">
                    <i class="icon-financial"></i>
                </div>
                <div class="update-content">
                    <h4>财务报表</h4>
                    <p>更新财务报表数据，包括销售额、成本、毛利、净利润等。</p>
                    <button type="submit" name="update_financial" class="btn">更新财务报表</button>
                </div>
            </div>

            <div class="update-all">
                <button type="submit" name="update_all" class="btn btn-primary">更新所有统计数据</button>
            </div>
        </form>
    </div>
</div>

<style>
    .stats-update-wrapper {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .stats-update-card,
    .stats-info-card {
        flex: 1;
        min-width: 300px;
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 5px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .stats-update-card h4,
    .stats-info-card h4 {
        margin-top: 0;
        margin-bottom: 15px;
        color: #333;
        border-bottom: 1px solid #ddd;
        padding-bottom: 10px;
    }

    .stats-form {
        margin-top: 20px;
    }

    .stats-messages {
        margin-top: 10px;
        max-height: 300px;
        overflow-y: auto;
        background-color: #f5f5f5;
        padding: 10px;
        border-radius: 4px;
        border: 1px solid #ddd;
    }

    .stats-messages li {
        margin-bottom: 5px;
        padding-bottom: 5px;
        border-bottom: 1px dashed #eee;
    }

    .stats-warning {
        margin-top: 20px;
        background-color: #fff8e1;
        padding: 15px;
        border-radius: 4px;
        border-left: 4px solid #ffb300;
    }

    .stats-warning h4 {
        margin-top: 0;
        color: #f57c00;
        border-bottom: 1px solid #ffe0b2;
    }

    @media (max-width: 768px) {
        .stats-update-wrapper {
            flex-direction: column;
        }
    }

    .icon-financial:before {
        content: "📊";
    }
</style>