<?php
// 防止直接访问
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 确保$conn变量存在
if (!isset($conn) || $conn === null) {
    die("数据库连接失败");
}

// 处理删除批次操作
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $batch_id = (int)$_GET['id'];

    try {
        // 检查批次是否存在
        $checkSql = "SELECT b.*, p.product_name FROM product_batches b
                    JOIN products p ON b.product_id = p.product_id
                    WHERE b.batch_id = ?";
        $checkStmt = $conn->prepare($checkSql);
        $checkStmt->bind_param("i", $batch_id);
        $checkStmt->execute();
        $checkResult = $checkStmt->get_result();

        if ($checkResult->num_rows > 0) {
            $batchData = $checkResult->fetch_assoc();

            // 检查批次是否有关联的库存记录
            // TODO: 如果有库存表中有batch_id字段，需要检查关联

            // 删除批次
            $deleteSql = "DELETE FROM product_batches WHERE batch_id = ?";
            $deleteStmt = $conn->prepare($deleteSql);
            $deleteStmt->bind_param("i", $batch_id);

            if ($deleteStmt->execute()) {
                // 记录操作日志
                $operationDetails = "删除批次: 产品[{$batchData['product_name']}] 批次号[{$batchData['batch_number']}]";
                log_operation($_SESSION['user_id'], '删除批次', $operationDetails);

                header("Location: index.php?page=batch&message=批次删除成功&type=success");
            } else {
                header("Location: index.php?page=batch&message=批次删除失败: " . $conn->error . "&type=error");
            }
            $deleteStmt->close();
        } else {
            header("Location: index.php?page=batch&message=批次不存在&type=error");
        }
        $checkStmt->close();
    } catch (Exception $e) {
        header("Location: index.php?page=batch&message=操作失败: " . $e->getMessage() . "&type=error");
    }
    exit;
}

// 处理添加/编辑批次表单提交
$message = '';
$messageType = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $batch_id = isset($_POST['batch_id']) ? (int)$_POST['batch_id'] : 0;
    $product_id = (int)$_POST['product_id'];
    $batch_number = trim($_POST['batch_number']);
    $production_date = $_POST['production_date'];
    $expiration_date = $_POST['expiration_date'];
    $batch_remark = isset($_POST['batch_remark']) ? trim($_POST['batch_remark']) : '';
    $warehouse_id = isset($_POST['warehouse_id']) ? (int)$_POST['warehouse_id'] : 0;
    $batch_quantity = isset($_POST['batch_quantity']) ? (int)$_POST['batch_quantity'] : 0;

    // 验证表单数据
    if (empty($product_id)) {
        $error = '请选择商品';
    } elseif (empty($batch_number)) {
        $error = '批次号不能为空';
    } elseif (empty($production_date)) {
        $error = '生产日期不能为空';
    } elseif (empty($expiration_date)) {
        $error = '过期日期不能为空';
    } elseif (strtotime($expiration_date) <= strtotime($production_date)) {
        $error = '过期日期必须晚于生产日期';
    } else {
        try {
            if ($batch_id > 0) {
                // 更新批次
                $sql = "UPDATE product_batches SET 
                        product_id = ?, 
                        batch_number = ?, 
                        production_date = ?, 
                        expiration_date = ?, 
                        batch_remark = ?, 
                        updated_at = NOW() 
                        WHERE batch_id = ?";
                $stmt = $conn->prepare($sql);
                if ($stmt === false) {
                    $error = '批次更新失败: 准备SQL语句时出错: ' . $conn->error;
                } else {
                    $stmt->bind_param("issssi", $product_id, $batch_number, $production_date, $expiration_date, $batch_remark, $batch_id);

                    if ($stmt->execute()) {
                        // 记录操作日志
                        $operationDetails = "更新批次: 批次ID[$batch_id], 产品ID[$product_id], 批次号[$batch_number]";
                        log_operation($_SESSION['user_id'], '更新批次', $operationDetails);

                        // 更新库存记录，如果需要
                        if ($warehouse_id > 0 && $batch_quantity > 0) {
                            try {
                                // 检查该仓库是否已有该商品批次的库存记录
                                $checkSql = "SELECT inventory_id FROM inventory 
                                             WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
                                $checkStmt = $conn->prepare($checkSql);
                                if (!$checkStmt) {
                                    throw new Exception("检查库存记录失败: " . $conn->error);
                                }

                                $checkStmt->bind_param("iii", $warehouse_id, $product_id, $batch_id);
                                $checkStmt->execute();
                                $checkResult = $checkStmt->get_result();

                                if ($checkResult->num_rows > 0) {
                                    // 已存在记录，更新库存数量
                                    $inventoryId = $checkResult->fetch_assoc()['inventory_id'];
                                    $updateSql = "UPDATE inventory SET quantity = quantity + ?, updated_at = NOW() 
                                                  WHERE inventory_id = ?";
                                    $updateStmt = $conn->prepare($updateSql);
                                    if (!$updateStmt) {
                                        throw new Exception("更新库存记录失败: " . $conn->error);
                                    }

                                    $updateStmt->bind_param("ii", $batch_quantity, $inventoryId);
                                    if (!$updateStmt->execute()) {
                                        throw new Exception("更新库存数量失败: " . $updateStmt->error);
                                    }
                                    $updateStmt->close();
                                } else {
                                    // 不存在记录，创建新库存记录
                                    $insertSql = "INSERT INTO inventory 
                                                  (warehouse_id, product_id, batch_id, quantity, min_stock_level, created_at, updated_at) 
                                                  VALUES (?, ?, ?, ?, 0, NOW(), NOW())";
                                    $insertStmt = $conn->prepare($insertSql);
                                    if (!$insertStmt) {
                                        throw new Exception("创建库存记录失败: " . $conn->error);
                                    }

                                    $insertStmt->bind_param("iiii", $warehouse_id, $product_id, $batch_id, $batch_quantity);
                                    if (!$insertStmt->execute()) {
                                        throw new Exception("插入库存记录失败: " . $insertStmt->error);
                                    }
                                    $insertStmt->close();
                                }

                                $checkStmt->close();

                                // 记录库存更新操作日志
                                $operationDetails = "更新库存: 批次ID[$batch_id], 产品ID[$product_id], 仓库ID[$warehouse_id], 数量[$batch_quantity]";
                                log_operation($_SESSION['user_id'], '更新库存', $operationDetails);

                                $message .= "，并已更新库存";
                            } catch (Exception $e) {
                                // 记录错误但不影响批次更新
                                error_log("更新库存失败: " . $e->getMessage());
                                $message .= "，但更新库存失败: " . $e->getMessage();
                                $messageType = "warning";
                            }
                        }

                        $message = "批次更新成功" . $message;
                        $messageType = "success";

                        // 重定向到批次列表页面
                        header("Location: index.php?page=batch&message=" . urlencode($message) . "&type=" . $messageType);
                        exit;
                    } else {
                        $error = '批次更新失败: ' . $conn->error;
                    }
                }
            } else {
                // 添加批次
                $sql = "INSERT INTO product_batches (product_id, batch_number, production_date, expiration_date, batch_remark, created_at, updated_at) 
                        VALUES (?, ?, ?, ?, ?, NOW(), NOW())";
                $stmt = $conn->prepare($sql);
                if ($stmt === false) {
                    $error = '批次添加失败: 准备SQL语句时出错: ' . $conn->error;
                } else {
                    $stmt->bind_param("issss", $product_id, $batch_number, $production_date, $expiration_date, $batch_remark);

                    if ($stmt->execute()) {
                        $new_batch_id = $conn->insert_id;

                        // 记录操作日志
                        $operationDetails = "添加批次: 批次ID[$new_batch_id], 产品ID[$product_id], 批次号[$batch_number]";
                        log_operation($_SESSION['user_id'], '添加批次', $operationDetails);

                        // 创建库存记录，如果需要
                        if ($warehouse_id > 0 && $batch_quantity > 0) {
                            try {
                                // 检查该仓库是否已有该商品批次的库存记录
                                $checkSql = "SELECT inventory_id FROM inventory 
                                             WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
                                $checkStmt = $conn->prepare($checkSql);
                                if (!$checkStmt) {
                                    throw new Exception("检查库存记录失败: " . $conn->error);
                                }

                                $checkStmt->bind_param("iii", $warehouse_id, $product_id, $new_batch_id);
                                $checkStmt->execute();
                                $checkResult = $checkStmt->get_result();

                                if ($checkResult->num_rows > 0) {
                                    // 已存在记录，更新库存数量
                                    $inventoryId = $checkResult->fetch_assoc()['inventory_id'];
                                    $updateSql = "UPDATE inventory SET quantity = quantity + ?, updated_at = NOW() 
                                                  WHERE inventory_id = ?";
                                    $updateStmt = $conn->prepare($updateSql);
                                    if (!$updateStmt) {
                                        throw new Exception("更新库存记录失败: " . $conn->error);
                                    }

                                    $updateStmt->bind_param("ii", $batch_quantity, $inventoryId);
                                    if (!$updateStmt->execute()) {
                                        throw new Exception("更新库存数量失败: " . $updateStmt->error);
                                    }
                                    $updateStmt->close();
                                } else {
                                    // 不存在记录，创建新库存记录
                                    $insertSql = "INSERT INTO inventory 
                                                  (warehouse_id, product_id, batch_id, quantity, min_stock_level, created_at, updated_at) 
                                                  VALUES (?, ?, ?, ?, 0, NOW(), NOW())";
                                    $insertStmt = $conn->prepare($insertSql);
                                    if (!$insertStmt) {
                                        throw new Exception("创建库存记录失败: " . $conn->error);
                                    }

                                    $insertStmt->bind_param("iiii", $warehouse_id, $product_id, $new_batch_id, $batch_quantity);
                                    if (!$insertStmt->execute()) {
                                        throw new Exception("插入库存记录失败: " . $insertStmt->error);
                                    }
                                    $insertStmt->close();
                                }

                                $checkStmt->close();

                                // 记录库存添加操作日志
                                $operationDetails = "添加库存: 批次ID[$new_batch_id], 产品ID[$product_id], 仓库ID[$warehouse_id], 数量[$batch_quantity]";
                                log_operation($_SESSION['user_id'], '添加库存', $operationDetails);

                                $message .= "，并已添加到库存";
                            } catch (Exception $e) {
                                // 记录错误但不影响批次创建
                                error_log("添加库存失败: " . $e->getMessage());
                                $message .= "，但添加到库存失败: " . $e->getMessage();
                                $messageType = "warning";
                            }
                        }

                        $message = "批次添加成功" . $message;
                        $messageType = "success";

                        // 重定向到批次列表页面
                        header("Location: index.php?page=batch&message=" . urlencode($message) . "&type=" . $messageType);
                        exit;
                    } else {
                        $error = '批次添加失败: ' . $conn->error;
                    }
                }
            }
        } catch (Exception $e) {
            $error = '操作失败: ' . $e->getMessage();
        }
    }
}

// 获取当前操作
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 处理URL中传递的消息参数
if (isset($_GET['message']) && isset($_GET['type'])) {
    $message = $_GET['message'];
    $messageType = $_GET['type'];
}

// 获取批次信息（用于编辑）
$batch = null;
if (($action == 'edit' || $action == 'view') && isset($_GET['id'])) {
    $batch_id = (int)$_GET['id'];
    $sql = "SELECT b.*, p.product_name, p.barcode 
            FROM product_batches b
            JOIN products p ON b.product_id = p.product_id
            WHERE b.batch_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $batch_id);
    $stmt->execute();
    $result = $stmt->get_result();
    if ($result->num_rows > 0) {
        $batch = $result->fetch_assoc();
    }
    $stmt->close();
}

// 获取批次的库存记录（用于查看和编辑）
$batchInventory = [];
if (($action == 'view' || $action == 'edit') && isset($_GET['id'])) {
    $batch_id = (int)$_GET['id'];
    $sql = "SELECT i.*, w.warehouse_name, w.type as warehouse_type
            FROM inventory i
            JOIN warehouses w ON i.warehouse_id = w.warehouse_id
            WHERE i.batch_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $batch_id);
    $stmt->execute();
    $result = $stmt->get_result();
    while ($row = $result->fetch_assoc()) {
        $batchInventory[] = $row;
    }
    $stmt->close();
}

// 获取查询参数
$product_id = isset($_GET['product_id']) ? (int)$_GET['product_id'] : (isset($_POST['product_id']) ? (int)$_POST['product_id'] : 0);
$warehouse_id = isset($_GET['warehouse_id']) ? (int)$_GET['warehouse_id'] : 0;
$search_keyword = isset($_GET['keyword']) ? trim($_GET['keyword']) : '';
$expiry_days = isset($_GET['expiry_days']) ? (int)$_GET['expiry_days'] : 0;

// 构建查询条件
$whereClause = "";
$params = [];
$types = "";

if ($product_id > 0) {
    $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "b.product_id = ?";
    $params[] = $product_id;
    $types .= "i";
}

if (!empty($search_keyword)) {
    $search_keyword = "%" . $search_keyword . "%";
    $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "(b.batch_number LIKE ? OR p.product_name LIKE ? OR p.barcode LIKE ?)";
    $params[] = $search_keyword;
    $params[] = $search_keyword;
    $params[] = $search_keyword;
    $types .= "sss";
}

if ($expiry_days > 0) {
    $today = date('Y-m-d');
    $futureDate = date('Y-m-d', strtotime("+$expiry_days days"));
    $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "b.expiration_date BETWEEN ? AND ?";
    $params[] = $today;
    $params[] = $futureDate;
    $types .= "ss";
}

// 获取所有商品
$products = [];
$productSql = "SELECT product_id, product_name, barcode FROM products ORDER BY product_name";
$productStmt = $conn->prepare($productSql);
if ($productStmt) {
    $productStmt->execute();
    $productResult = $productStmt->get_result();
    while ($row = $productResult->fetch_assoc()) {
        $products[] = $row;
    }
    $productStmt->close();
} else {
    echo '<div class="alert alert-error">获取商品列表失败: ' . $conn->error . '</div>';
}

// 获取所有仓库
$warehouses = [];
$warehouseSql = "SELECT warehouse_id, warehouse_name, type as warehouse_type FROM warehouses ORDER BY warehouse_name";
$warehouseStmt = $conn->prepare($warehouseSql);
if ($warehouseStmt) {
    $warehouseStmt->execute();
    $warehouseResult = $warehouseStmt->get_result();
    while ($row = $warehouseResult->fetch_assoc()) {
        $warehouses[] = $row;
    }
    $warehouseStmt->close();
} else {
    echo '<div class="alert alert-error">获取仓库列表失败: ' . $conn->error . '</div>';
}

// 获取批次列表
$batches = [];
if ($action == 'list') {
    $sql = "SELECT b.*, p.product_name, p.barcode, p.unit 
            FROM product_batches b
            JOIN products p ON b.product_id = p.product_id
            $whereClause
            ORDER BY b.expiration_date, b.production_date";

    $stmt = $conn->prepare($sql);

    if ($stmt) {
        if (!empty($params)) {
            $stmt->bind_param($types, ...$params);
        }

        $stmt->execute();
        $result = $stmt->get_result();
        $today = date('Y-m-d');

        while ($row = $result->fetch_assoc()) {
            // 计算距离过期的天数
            $expiry_date = new DateTime($row['expiration_date']);
            $current_date = new DateTime($today);
            $interval = $current_date->diff($expiry_date);
            $days_left = $interval->invert ? -$interval->days : $interval->days;

            $row['days_left'] = $days_left;
            $row['is_expired'] = $days_left <= 0;

            // 获取批次在所有仓库的库存数量之和
            $inventorySql = "SELECT SUM(quantity) as total_quantity, 
                                    GROUP_CONCAT(w.warehouse_name SEPARATOR ', ') as warehouse_names
                            FROM inventory i
                            JOIN warehouses w ON i.warehouse_id = w.warehouse_id
                            WHERE i.batch_id = ?
                            GROUP BY i.batch_id";
            $inventoryStmt = $conn->prepare($inventorySql);
            $inventoryStmt->bind_param("i", $row['batch_id']);
            $inventoryStmt->execute();
            $inventoryResult = $inventoryStmt->get_result();

            if ($inventoryResult->num_rows > 0) {
                $inventoryData = $inventoryResult->fetch_assoc();
                $row['total_quantity'] = $inventoryData['total_quantity'];
                $row['warehouse_names'] = $inventoryData['warehouse_names'];
            } else {
                $row['total_quantity'] = 0;
                $row['warehouse_names'] = '';
            }

            $inventoryStmt->close();

            $batches[] = $row;
        }
        $stmt->close();
    } else {
        // 处理prepare失败的情况
        echo '<div class="alert alert-error">数据库查询准备失败: ' . $conn->error . '</div>';
    }
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 显示错误信息 -->
<?php if (!empty($error)): ?>
    <div class="alert alert-error"><?php echo $error; ?></div>
<?php endif; ?>

<!-- jQuery库必须在Select2之前引入 -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- 引入Select2库 -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<!-- 添加/编辑批次表单 -->
<?php if ($action == 'add' || $action == 'edit'): ?>
    <div class="form-container">
        <h3><?php echo $action == 'add' ? '添加批次' : '编辑批次'; ?></h3>
        <form method="post" action="">
            <?php if ($action == 'edit' && $batch): ?>
                <input type="hidden" name="batch_id" value="<?php echo $batch['batch_id']; ?>">
            <?php endif; ?>

            <div class="form-group">
                <label for="product_id">商品 <span class="required">*</span></label>
                <select name="product_id" id="product_id" class="select2-product" required>
                    <option value="">请选择商品</option>
                    <?php foreach ($products as $product): ?>
                        <option value="<?php echo $product['product_id']; ?>"
                            <?php echo (($action == 'edit' && $batch && $batch['product_id'] == $product['product_id']) ||
                                ($action == 'add' && $product_id == $product['product_id'])) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($product['product_name'] . ' (' . $product['barcode'] . ')'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label for="batch_number">批次号 <span class="required">*</span></label>
                <input type="text" id="batch_number" name="batch_number" required
                    value="<?php echo $action == 'edit' && $batch ? htmlspecialchars($batch['batch_number']) : generateBatchNumber(); ?>">
            </div>

            <div class="form-group">
                <label for="production_date">生产日期 <span class="required">*</span></label>
                <input type="date" id="production_date" name="production_date" required
                    value="<?php echo $action == 'edit' && $batch ? $batch['production_date'] : date('Y-m-d'); ?>">
            </div>

            <div class="form-group">
                <label for="expiration_date">过期日期 <span class="required">*</span></label>
                <input type="date" id="expiration_date" name="expiration_date" required
                    value="<?php echo $action == 'edit' && $batch ? $batch['expiration_date'] : date('Y-m-d', strtotime('+1 year')); ?>">
            </div>

            <div class="form-group">
                <label for="batch_remark">备注</label>
                <textarea id="batch_remark" name="batch_remark" rows="3"><?php echo isset($batch['batch_remark']) ? htmlspecialchars($batch['batch_remark']) : ''; ?></textarea>
            </div>

            <!-- 添加和编辑表单都显示入库选项 -->
            <div class="form-group">
                <label for="warehouse_id">入库到仓库</label>
                <select name="warehouse_id" id="warehouse_id" class="select2-warehouse">
                    <option value="">不入库</option>
                    <?php foreach ($warehouses as $warehouse): ?>
                        <option value="<?php echo $warehouse['warehouse_id']; ?>" <?php echo $warehouse_id == $warehouse['warehouse_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($warehouse['warehouse_name'] . ' (' . getWarehouseTypeChinese($warehouse['warehouse_type']) . ')'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label for="batch_quantity">入库数量</label>
                <input type="number" id="batch_quantity" name="batch_quantity" min="0" value="0">
            </div>

            <div class="form-actions">
                <button type="submit" class="btn btn-primary">保存</button>
                <a href="index.php?page=batch" class="btn btn-secondary">取消</a>
            </div>
        </form>
    </div>
    <!-- 查看批次详情 -->
<?php elseif ($action == 'view' && $batch): ?>
    <div class="detail-container">
        <h3>批次详情</h3>
        <div class="detail-content">
            <div class="detail-group">
                <label>批次ID:</label>
                <span><?php echo $batch['batch_id']; ?></span>
            </div>
            <div class="detail-group">
                <label>商品:</label>
                <span><?php echo htmlspecialchars($batch['product_name'] . ' (' . $batch['barcode'] . ')'); ?></span>
            </div>
            <div class="detail-group">
                <label>批次号:</label>
                <span><?php echo htmlspecialchars($batch['batch_number']); ?></span>
            </div>
            <div class="detail-group">
                <label>生产日期:</label>
                <span><?php echo $batch['production_date']; ?></span>
            </div>
            <div class="detail-group">
                <label>到期日期:</label>
                <span><?php echo $batch['expiration_date']; ?></span>
            </div>
            <div class="detail-group">
                <label>备注:</label>
                <span><?php echo isset($batch['batch_remark']) ? htmlspecialchars($batch['batch_remark']) : '无'; ?></span>
            </div>
            <?php
            // 计算剩余天数
            $expiry_date = new DateTime($batch['expiration_date']);
            $current_date = new DateTime(date('Y-m-d'));
            $interval = $current_date->diff($expiry_date);
            $days_left = $interval->invert ? -$interval->days : $interval->days;
            $is_expired = $days_left <= 0;
            ?>
            <div class="detail-group">
                <label>状态:</label>
                <span>
                    <?php if ($is_expired): ?>
                        <span class="badge badge-danger">已过期</span>
                    <?php else: ?>
                        <span class="badge badge-success">有效</span> (剩余 <?php echo $days_left; ?> 天)
                    <?php endif; ?>
                </span>
            </div>
            <div class="detail-group">
                <label>创建时间:</label>
                <span><?php echo $batch['created_at']; ?></span>
            </div>
            <div class="detail-group">
                <label>更新时间:</label>
                <span><?php echo $batch['updated_at']; ?></span>
            </div>
        </div>

        <!-- 显示该批次的库存记录 -->
        <h4 style="margin-top: 20px;">库存记录</h4>
        <?php if (count($batchInventory) > 0): ?>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>仓库</th>
                        <th>库存数量</th>
                        <th>最低库存</th>
                        <th>更新时间</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($batchInventory as $inventory): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($inventory['warehouse_name'] . ' (' . getWarehouseTypeChinese($inventory['warehouse_type']) . ')'); ?></td>
                            <td><?php echo $inventory['quantity']; ?></td>
                            <td><?php echo $inventory['min_stock_level']; ?></td>
                            <td><?php echo $inventory['updated_at']; ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <div class="alert alert-info">该批次暂无库存记录</div>
        <?php endif; ?>

        <div class="detail-actions">
            <a href="index.php?page=batch&action=edit&id=<?php echo $batch['batch_id']; ?>" class="btn btn-primary">编辑</a>
            <a href="index.php?page=batch" class="btn btn-secondary">返回</a>
        </div>
    </div>
    <!-- 批次列表 -->
<?php else: ?>
    <div class="module-tools">
        <div class="tool-left">
            <a href="index.php?page=batch&action=add<?php echo $product_id ? '&product_id=' . $product_id : ''; ?>" class="btn btn-primary">添加批次</a>
        </div>
        <div class="tool-right">
            <form action="index.php" method="get" class="search-form">
                <input type="hidden" name="page" value="batch">

                <div class="search-group">
                    <select name="product_id" class="search-input select2-product">
                        <option value="">所有商品</option>
                        <?php foreach ($products as $product): ?>
                            <option value="<?php echo $product['product_id']; ?>" <?php echo $product_id == $product['product_id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($product['product_name'] . ' (' . $product['barcode'] . ')'); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="search-group">
                    <input type="text" name="keyword" class="search-input" placeholder="批次号/商品名称/条码" value="<?php echo htmlspecialchars($search_keyword); ?>">
                </div>

                <div class="search-group">
                    <select name="expiry_days" class="search-input">
                        <option value="">所有批次</option>
                        <option value="30" <?php echo $expiry_days == 30 ? 'selected' : ''; ?>>30天内到期</option>
                        <option value="60" <?php echo $expiry_days == 60 ? 'selected' : ''; ?>>60天内到期</option>
                        <option value="90" <?php echo $expiry_days == 90 ? 'selected' : ''; ?>>90天内到期</option>
                    </select>
                </div>

                <button type="submit" class="btn btn-secondary">搜索</button>
                <a href="index.php?page=batch" class="btn btn-secondary">重置</a>
            </form>
        </div>
    </div>

    <div class="data-wrapper">
        <table class="data-table">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>商品名称</th>
                    <th>条码</th>
                    <th>批次号</th>
                    <th>生产日期</th>
                    <th>过期日期</th>
                    <th>库存数量</th>
                    <th>仓库分布</th>
                    <th>状态</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($batches) > 0): ?>
                    <?php foreach ($batches as $batch): ?>
                        <tr class="<?php echo $batch['is_expired'] ? 'expired-row' : ($batch['days_left'] <= 30 ? 'expiring-soon-row' : ''); ?>">
                            <td><?php echo $batch['batch_id']; ?></td>
                            <td><?php echo htmlspecialchars($batch['product_name']); ?></td>
                            <td><?php echo htmlspecialchars($batch['barcode']); ?></td>
                            <td><?php echo htmlspecialchars($batch['batch_number']); ?></td>
                            <td><?php echo $batch['production_date']; ?></td>
                            <td><?php echo $batch['expiration_date']; ?></td>
                            <td><?php echo $batch['total_quantity']; ?></td>
                            <td><?php echo htmlspecialchars($batch['warehouse_names']); ?></td>
                            <td>
                                <?php if ($batch['is_expired']): ?>
                                    <span class="badge badge-danger">已过期</span>
                                <?php elseif ($batch['days_left'] <= 30): ?>
                                    <span class="badge badge-warning">即将过期 (<?php echo $batch['days_left']; ?>天)</span>
                                <?php else: ?>
                                    <span class="badge badge-success">有效 (<?php echo $batch['days_left']; ?>天)</span>
                                <?php endif; ?>
                            </td>
                            <td class="actions">
                                <a href="index.php?page=batch&action=view&id=<?php echo $batch['batch_id']; ?>" class="btn btn-secondary btn-sm">查看</a>
                                <a href="index.php?page=batch&action=edit&id=<?php echo $batch['batch_id']; ?>" class="btn btn-primary btn-sm">编辑</a>
                                <a href="index.php?page=batch&action=delete&id=<?php echo $batch['batch_id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除此批次吗？')">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="10" class="text-center">暂无批次数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
<?php endif; ?>

<style>
    .expired-row td {
        background-color: #f8d7da;
    }

    .expiring-soon-row td {
        background-color: #fff3cd;
    }

    /* Select2样式修正 */
    .select2-container {
        width: 100% !important;
        margin-bottom: 10px;
    }

    .select2-container .select2-selection--single {
        height: 38px;
        padding: 5px;
    }

    .select2-container--default .select2-selection--single .select2-selection__rendered {
        line-height: 28px;
    }

    .select2-container--default .select2-selection--single .select2-selection__arrow {
        height: 36px;
    }
</style>

<script>
    // 初始化Select2
    $(document).ready(function() {
        $('.select2-product').select2({
            placeholder: "请选择商品",
            allowClear: true,
            width: '100%'
        });

        $('.select2-warehouse').select2({
            placeholder: "请选择仓库",
            allowClear: true,
            width: '100%'
        });
    });
</script>

<?php
/**
 * 生成批次号
 * @return string
 */
function generateBatchNumber()
{
    // 生成格式：B + 年月日 + 随机4位数字
    return 'B' . date('Ymd') . substr(microtime(true), -4);
}
?>