<?php
session_start();
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前页面
$page = isset($_GET['page']) ? $_GET['page'] : 'warehouse';

// 页面标题
$pageTitle = '库存管理';
$subTitle = '';

// 获取子页面内容
$contentFile = '';
switch ($page) {
    case 'warehouse':
        $contentFile = 'warehouse.php';
        $subTitle = '多仓库管理';
        break;
    case 'query':
        $contentFile = 'query.php';
        $subTitle = '库存查询';
        break;
    case 'warning':
        $contentFile = 'warning.php';
        $subTitle = '库存预警';
        break;
    case 'batch':
        $contentFile = 'batch.php';
        $subTitle = '批次管理';
        break;
    case 'transfer':
        $contentFile = 'transfer.php';
        $subTitle = '库存调拨';
        break;
    case 'stocktaking':
        $contentFile = 'stocktaking.php';
        $subTitle = '盘点管理';
        break;
    default:
        $contentFile = 'warehouse.php';
        $subTitle = '多仓库管理';
}

// 检查文件是否存在
if (!file_exists($contentFile)) {
    $contentFile = 'warehouse.php';
    $subTitle = '多仓库管理';
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $subTitle; ?> - <?php echo $pageTitle; ?> - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="../../css/style.css">
</head>

<body>
    <header class="main-header">
        <div class="user-info">
            <span class="user-name"><?php echo isset($_SESSION['full_name']) ? $_SESSION['full_name'] : '用户'; ?></span>
            <span class="user-role"><?php echo $_SESSION['user_role']; ?></span>
        </div>

        <div class="site-title">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <div class="header-actions">
            <a href="../../logout.php" class="btn btn-logout">退出登录</a>
        </div>
    </header>

    <div class="module-layout">
        <aside class="module-sidebar">
            <div class="module-sidebar-header">
                <h2><?php echo $pageTitle; ?></h2>
            </div>

            <nav class="module-nav">
                <a href="../../home.php" class="module-nav-item">返回首页</a>
                <a href="index.php?page=warehouse" class="module-nav-item <?php echo $page == 'warehouse' ? 'active' : ''; ?>">多仓库管理</a>
                <a href="index.php?page=query" class="module-nav-item <?php echo $page == 'query' ? 'active' : ''; ?>">库存查询</a>
                <a href="index.php?page=warning" class="module-nav-item <?php echo $page == 'warning' ? 'active' : ''; ?>">库存预警</a>
                <a href="index.php?page=batch" class="module-nav-item <?php echo $page == 'batch' ? 'active' : ''; ?>">批次管理</a>
                <a href="index.php?page=transfer" class="module-nav-item <?php echo $page == 'transfer' ? 'active' : ''; ?>">库存调拨</a>
                <a href="index.php?page=stocktaking" class="module-nav-item <?php echo $page == 'stocktaking' ? 'active' : ''; ?>">盘点管理</a>
            </nav>
        </aside>

        <main class="module-content">
            <div class="module-content-header">
                <h2><?php echo $subTitle; ?></h2>
            </div>
            <?php
            // 包含子页面内容
            if (file_exists($contentFile)) {
                include $contentFile;
            } else {
                echo "<div class='alert alert-error'>找不到页面文件: {$contentFile}</div>";
            }
            ?>
        </main>
    </div>

    <footer class="main-footer">
        <p>&copy; <?php echo date('Y'); ?> <?php echo SITE_NAME; ?> - 版权所有</p>
    </footer>
</body>

</html>