<?php
// 防止直接访问
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';
$error = '';

// 获取当前操作
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 处理删除盘点记录操作
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $check_id = (int)$_GET['id'];

    try {
        // 检查盘点记录是否存在
        $checkSql = "SELECT check_id FROM inventory_checks WHERE check_id = ?";
        $checkStmt = $conn->prepare($checkSql);
        if ($checkStmt) {
            $checkStmt->bind_param("i", $check_id);
            $checkStmt->execute();
            $checkResult = $checkStmt->get_result();

            if ($checkResult->num_rows > 0) {
                // 删除盘点记录
                $deleteSql = "DELETE FROM inventory_checks WHERE check_id = ?";
                $deleteStmt = $conn->prepare($deleteSql);
                $deleteStmt->bind_param("i", $check_id);
                if ($deleteStmt->execute()) {
                    // 记录操作日志
                    $operationDetails = "删除盘点记录: ID[$check_id]";
                    log_operation($_SESSION['user_id'], '删除盘点记录', $operationDetails);

                    $message = "盘点记录删除成功";
                    $messageType = "success";
                } else {
                    $error = "盘点记录删除失败: " . $conn->error;
                }
                $deleteStmt->close();
            } else {
                $error = "盘点记录不存在";
            }
            $checkStmt->close();
        }
    } catch (Exception $e) {
        $error = "操作失败: " . $e->getMessage();
    }
}

// 处理盘点表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'stocktaking') {
    $warehouse_id = isset($_POST['warehouse_id']) ? (int)$_POST['warehouse_id'] : 0;
    $product_id = isset($_POST['product_id']) ? (int)$_POST['product_id'] : 0;
    $batch_id = isset($_POST['batch_id']) ? (int)$_POST['batch_id'] : 0;
    $actual_quantity = isset($_POST['actual_quantity']) ? (int)$_POST['actual_quantity'] : 0;
    $check_date = isset($_POST['check_date']) ? $_POST['check_date'] : date('Y-m-d');
    $remarks = isset($_POST['remarks']) ? trim($_POST['remarks']) : '';

    // 验证表单数据
    if ($warehouse_id <= 0) {
        $error = '请选择仓库';
    } elseif ($product_id <= 0) {
        $error = '请选择商品';
    } elseif ($batch_id <= 0) {
        $error = '请选择批次';
    } elseif ($actual_quantity < 0) {
        $error = '实际数量不能为负数';
    } else {
        try {
            // 开始事务
            $conn->begin_transaction();

            // 获取系统中的库存数量
            $inventorySql = "SELECT quantity FROM inventory WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
            $inventoryStmt = $conn->prepare($inventorySql);
            if (!$inventoryStmt) {
                throw new Exception("准备获取库存数量查询失败: " . $conn->error);
            }

            $inventoryStmt->bind_param("iii", $warehouse_id, $product_id, $batch_id);
            $inventoryStmt->execute();
            $inventoryResult = $inventoryStmt->get_result();

            if ($inventoryResult->num_rows == 0) {
                throw new Exception("系统中没有该商品批次的库存记录");
            }

            $expectedQuantity = $inventoryResult->fetch_assoc()['quantity'];
            $inventoryStmt->close();

            // 计算差异数量
            $difference = $actual_quantity - $expectedQuantity;

            // 插入盘点记录
            $insertSql = "INSERT INTO inventory_checks (warehouse_id, product_id, batch_id, expected_quantity, actual_quantity, difference, check_date, status, created_at, updated_at) 
                          VALUES (?, ?, ?, ?, ?, ?, ?, 'completed', NOW(), NOW())";
            $insertStmt = $conn->prepare($insertSql);
            if (!$insertStmt) {
                throw new Exception("准备创建盘点记录失败: " . $conn->error);
            }

            $status = 'completed';
            $insertStmt->bind_param("iiiiiss", $warehouse_id, $product_id, $batch_id, $expectedQuantity, $actual_quantity, $difference, $check_date);
            if (!$insertStmt->execute()) {
                throw new Exception("创建盘点记录失败: " . $insertStmt->error);
            }
            $check_id = $conn->insert_id;
            $insertStmt->close();

            // 更新库存记录
            $updateSql = "UPDATE inventory SET quantity = ?, updated_at = NOW() WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
            $updateStmt = $conn->prepare($updateSql);
            if (!$updateStmt) {
                throw new Exception("准备更新库存记录失败: " . $conn->error);
            }

            $updateStmt->bind_param("iiii", $actual_quantity, $warehouse_id, $product_id, $batch_id);
            if (!$updateStmt->execute()) {
                throw new Exception("更新库存记录失败: " . $updateStmt->error);
            }
            $updateStmt->close();

            // 提交事务
            $conn->commit();

            // 记录操作日志
            $operationDetails = "盘点: 仓库[$warehouse_id]的商品[$product_id]批次[$batch_id], 预期[$expectedQuantity], 实际[$actual_quantity], 差异[$difference]";
            log_operation($_SESSION['user_id'], '库存盘点', $operationDetails);

            $message = "盘点成功，盘点ID: $check_id";
            $messageType = "success";
            
            // 添加重定向到列表页面
            header("Location: index.php?page=stocktaking&message=" . urlencode($message) . "&type=" . $messageType);
            exit;
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            $error = '盘点失败: ' . $e->getMessage();
        }
    }
}

// 获取查询参数
$warehouse_id = isset($_GET['warehouse_id']) ? (int)$_GET['warehouse_id'] : 0;
$product_id = isset($_GET['product_id']) ? (int)$_GET['product_id'] : 0;
$batch_id = isset($_GET['batch_id']) ? (int)$_GET['batch_id'] : 0;
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : '';
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : '';

// 获取所有仓库
$warehouses = [];
$warehouseSql = "SELECT warehouse_id, warehouse_name, type as warehouse_type FROM warehouses ORDER BY warehouse_name";
$warehouseStmt = $conn->prepare($warehouseSql);
if ($warehouseStmt) {
    $warehouseStmt->execute();
    $warehouseResult = $warehouseStmt->get_result();
    while ($row = $warehouseResult->fetch_assoc()) {
        $warehouses[] = $row;
    }
    $warehouseStmt->close();
} else {
    echo '<div class="alert alert-error">获取仓库列表失败: ' . $conn->error . '</div>';
}

// 获取所有商品
$products = [];
$productSql = "SELECT p.product_id, p.product_name, p.barcode, p.unit FROM products p ORDER BY p.product_name";
$productStmt = $conn->prepare($productSql);
if ($productStmt) {
    $productStmt->execute();
    $productResult = $productStmt->get_result();
    while ($row = $productResult->fetch_assoc()) {
        $products[] = $row;
    }
    $productStmt->close();
} else {
    echo '<div class="alert alert-error">获取商品列表失败: ' . $conn->error . '</div>';
}

// 获取选定商品的库存信息
$currentInventory = null;
if ($warehouse_id > 0 && $product_id > 0) {
    $inventorySql = "SELECT i.inventory_id, i.quantity, p.product_name, p.barcode, p.unit, w.warehouse_name 
                     FROM inventory i
                     JOIN products p ON i.product_id = p.product_id
                     JOIN warehouses w ON i.warehouse_id = w.warehouse_id
                     WHERE i.warehouse_id = ? AND i.product_id = ?";
    $inventoryStmt = $conn->prepare($inventorySql);
    if ($inventoryStmt) {
        $inventoryStmt->bind_param("ii", $warehouse_id, $product_id);
        $inventoryStmt->execute();
        $inventoryResult = $inventoryStmt->get_result();
        if ($inventoryResult->num_rows > 0) {
            $currentInventory = $inventoryResult->fetch_assoc();
        }
        $inventoryStmt->close();
    } else {
        echo '<div class="alert alert-error">获取商品库存失败: ' . $conn->error . '</div>';
    }
}

// 直接在PHP中获取批次数据，不使用AJAX
$batches = [];
if ($warehouse_id > 0 && $product_id > 0) {
    $batchSql = "SELECT i.batch_id, pb.batch_number, pb.production_date, pb.expiration_date, i.quantity 
                FROM inventory i
                JOIN product_batches pb ON i.batch_id = pb.batch_id
                WHERE i.warehouse_id = ? AND i.product_id = ? AND i.quantity > 0
                ORDER BY pb.expiration_date";

    // 记录SQL查询以便调试
    error_log("盘点批次查询SQL: " . $batchSql . " [warehouse_id=$warehouse_id, product_id=$product_id]");

    $batchStmt = $conn->prepare($batchSql);
    if ($batchStmt) {
        $batchStmt->bind_param("ii", $warehouse_id, $product_id);
        $batchStmt->execute();
        $batchResult = $batchStmt->get_result();

        // 记录结果数量用于调试
        error_log("盘点批次查询结果数量: " . $batchResult->num_rows);

        while ($row = $batchResult->fetch_assoc()) {
            $batches[] = $row;
        }
        $batchStmt->close();
    } else {
        echo '<div class="alert alert-error">获取批次列表失败: ' . $conn->error . '</div>';
    }
}

// 获取盘点记录
$checks = [];
if ($action == 'list') {
    // 构建查询条件
    $whereClause = "";
    $params = [];
    $types = "";

    if ($warehouse_id > 0) {
        $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "c.warehouse_id = ?";
        $params[] = $warehouse_id;
        $types .= "i";
    }

    if ($product_id > 0) {
        $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "c.product_id = ?";
        $params[] = $product_id;
        $types .= "i";
    }

    if ($batch_id > 0) {
        $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "c.batch_id = ?";
        $params[] = $batch_id;
        $types .= "i";
    }

    if (!empty($start_date)) {
        $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "c.check_date >= ?";
        $params[] = $start_date;
        $types .= "s";
    }

    if (!empty($end_date)) {
        $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "c.check_date <= ?";
        $params[] = $end_date;
        $types .= "s";
    }

    $sql = "SELECT c.*, p.product_name, p.barcode, p.unit, w.warehouse_name, pb.batch_number
            FROM inventory_checks c
            JOIN products p ON c.product_id = p.product_id
            JOIN warehouses w ON c.warehouse_id = w.warehouse_id
            JOIN product_batches pb ON c.batch_id = pb.batch_id
            $whereClause
            ORDER BY c.check_date DESC, c.check_id DESC 
            LIMIT 100";

    $stmt = $conn->prepare($sql);

    if ($stmt) {
        if (!empty($params)) {
            $stmt->bind_param($types, ...$params);
        }

        $stmt->execute();
        $result = $stmt->get_result();
        while ($row = $result->fetch_assoc()) {
            $checks[] = $row;
        }
        $stmt->close();
    } else {
        // 处理prepare失败的情况
        echo '<div class="alert alert-error">数据库查询准备失败: ' . $conn->error . '</div>';
    }
}

// 处理URL中传递的消息参数
if (isset($_GET['message']) && isset($_GET['type'])) {
    $message = $_GET['message'];
    $messageType = $_GET['type'];
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 显示错误信息 -->
<?php if (!empty($error)): ?>
    <div class="alert alert-error"><?php echo $error; ?></div>
<?php endif; ?>

<!-- jQuery库必须在Select2之前引入 -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- 引入Select2库 -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<?php if ($action == 'add'): ?>
    <!-- 盘点表单 -->
    <div class="form-container">
        <h3>库存盘点</h3>
        <form method="post" action="">
            <input type="hidden" name="action" value="stocktaking">

            <div class="form-group">
                <label for="warehouse_id">仓库 <span class="required">*</span></label>
                <select name="warehouse_id" id="warehouse_id" class="select2-warehouse" required>
                    <option value="">请选择仓库</option>
                    <?php foreach ($warehouses as $warehouse): ?>
                        <option value="<?php echo $warehouse['warehouse_id']; ?>"
                            <?php echo $warehouse_id == $warehouse['warehouse_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($warehouse['warehouse_name'] . ' (' . getWarehouseTypeChinese($warehouse['warehouse_type']) . ')'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label for="product_id">商品 <span class="required">*</span></label>
                <select name="product_id" id="product_id" class="select2-product" required>
                    <option value="">请选择商品</option>
                    <?php foreach ($products as $product): ?>
                        <option value="<?php echo $product['product_id']; ?>"
                            <?php echo $product_id == $product['product_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($product['product_name'] . ' (' . $product['barcode'] . ')'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group" id="batch-select-container">
                <label for="batch_id">批次 <span class="required">*</span></label>
                <select name="batch_id" id="batch_id" class="select2-batch" required>
                    <option value="">请先选择仓库和商品</option>
                    <?php if (count($batches) > 0): ?>
                        <?php foreach ($batches as $batch): ?>
                            <option value="<?php echo $batch['batch_id']; ?>"
                                <?php echo $batch_id == $batch['batch_id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($batch['batch_number'] . ' (库存: ' . $batch['quantity'] . ', 有效期: ' . $batch['expiration_date'] . ')'); ?>
                            </option>
                        <?php endforeach; ?>
                    <?php elseif ($warehouse_id > 0 && $product_id > 0): ?>
                        <option value="" disabled>该仓库没有该商品的批次库存</option>
                    <?php endif; ?>
                </select>

                <?php if ($warehouse_id > 0 && $product_id > 0 && count($batches) == 0): ?>
                    <div class="alert alert-warning" style="margin-top: 10px;">
                        该仓库没有该商品的批次库存，请先添加批次
                        <br>
                        <a href="index.php?page=batch&action=add&product_id=<?php echo $product_id; ?>" class="btn btn-primary" style="margin-top: 10px;">添加批次</a>
                    </div>
                <?php endif; ?>
            </div>

            <?php if ($currentInventory): ?>
                <div class="inventory-info">
                    <div class="info-item">
                        <label>当前系统库存:</label>
                        <span><?php echo $currentInventory['quantity']; ?> <?php echo htmlspecialchars($currentInventory['unit']); ?></span>
                    </div>
                </div>
            <?php endif; ?>

            <div class="form-group">
                <label for="actual_quantity">实际数量 <span class="required">*</span></label>
                <input type="number" id="actual_quantity" name="actual_quantity" min="0" required>
            </div>

            <div class="form-group">
                <label for="check_date">盘点日期 <span class="required">*</span></label>
                <input type="date" id="check_date" name="check_date" value="<?php echo date('Y-m-d'); ?>" required>
            </div>

            <div class="form-group">
                <label for="remarks">备注</label>
                <textarea id="remarks" name="remarks" rows="3"></textarea>
            </div>

            <div class="form-actions">
                <button type="submit" class="btn btn-primary">提交盘点</button>
                <a href="index.php?page=stocktaking" class="btn btn-secondary">返回盘点列表</a>
            </div>
        </form>
    </div>
<?php else: ?>
    <!-- 盘点记录列表 -->
    <div class="module-tools">
        <div class="tool-left">
            <a href="index.php?page=stocktaking&action=add" class="btn btn-primary">添加盘点记录</a>
        </div>
        <div class="tool-right">
            <form action="index.php" method="get" class="search-form">
                <input type="hidden" name="page" value="stocktaking">

                <div class="search-group">
                    <select name="warehouse_id" class="search-input select2-warehouse">
                        <option value="">所有仓库</option>
                        <?php foreach ($warehouses as $warehouse): ?>
                            <option value="<?php echo $warehouse['warehouse_id']; ?>" <?php echo $warehouse_id == $warehouse['warehouse_id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($warehouse['warehouse_name']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="search-group">
                    <input type="date" name="start_date" class="search-input" placeholder="开始日期" value="<?php echo htmlspecialchars($start_date); ?>">
                </div>

                <div class="search-group">
                    <input type="date" name="end_date" class="search-input" placeholder="结束日期" value="<?php echo htmlspecialchars($end_date); ?>">
                </div>

                <button type="submit" class="btn btn-secondary">搜索</button>
                <a href="index.php?page=stocktaking" class="btn btn-secondary">重置</a>
            </form>
        </div>
    </div>

    <div class="data-wrapper">
        <table class="data-table">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>仓库</th>
                    <th>商品</th>
                    <th>批次</th>
                    <th>预期数量</th>
                    <th>实际数量</th>
                    <th>差异</th>
                    <th>盘点日期</th>
                    <th>状态</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($checks) > 0): ?>
                    <?php foreach ($checks as $check): ?>
                        <tr>
                            <td><?php echo $check['check_id']; ?></td>
                            <td><?php echo htmlspecialchars($check['warehouse_name']); ?></td>
                            <td><?php echo htmlspecialchars($check['product_name']); ?></td>
                            <td><?php echo htmlspecialchars($check['batch_number']); ?></td>
                            <td><?php echo $check['expected_quantity']; ?></td>
                            <td><?php echo $check['actual_quantity']; ?></td>
                            <td class="<?php echo $check['difference'] < 0 ? 'text-error' : ($check['difference'] > 0 ? 'text-success' : ''); ?>">
                                <?php echo $check['difference']; ?>
                            </td>
                            <td><?php echo $check['check_date']; ?></td>
                            <td>
                                <span class="badge badge-<?php echo $check['status'] == 'completed' ? 'success' : 'warning'; ?>">
                                    <?php echo $check['status'] == 'completed' ? '已完成' : $check['status']; ?>
                                </span>
                            </td>
                            <td class="actions">
                                <a href="index.php?page=stocktaking&action=delete&id=<?php echo $check['check_id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除此盘点记录吗？')">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="10" class="text-center">暂无盘点记录</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
<?php endif; ?>

<style>
    .inventory-info {
        margin-bottom: 15px;
        padding: 10px;
        background-color: #f9f9f9;
        border-radius: 5px;
    }

    .info-item {
        margin-bottom: 5px;
    }

    .info-item label {
        font-weight: bold;
        margin-right: 10px;
    }

    .search-section {
        margin-top: 30px;
    }

    .search-form {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        align-items: flex-end;
    }

    .search-group {
        display: flex;
        flex-direction: column;
    }

    .search-actions {
        display: flex;
        gap: 10px;
    }

    .text-error {
        color: #e74c3c;
    }

    .text-success {
        color: #2ecc71;
    }

    /* Select2样式修正 */
    .select2-container {
        width: 100% !important;
        margin-bottom: 10px;
    }

    .select2-container .select2-selection--single {
        height: 38px;
        padding: 5px;
    }

    .select2-container--default .select2-selection--single .select2-selection__rendered {
        line-height: 28px;
    }

    .select2-container--default .select2-selection--single .select2-selection__arrow {
        height: 36px;
    }
</style>

<script>
    // 页面加载完成后初始化
    $(document).ready(function() {
        // 初始化Select2
        $('.select2-warehouse').select2({
            placeholder: "请选择仓库",
            allowClear: true,
            width: '100%'
        });

        $('.select2-product').select2({
            placeholder: "请选择商品",
            allowClear: true,
            width: '100%'
        });

        $('.select2-batch').select2({
            placeholder: "请选择批次",
            allowClear: true,
            width: '100%'
        });

        // 当仓库或商品变化时，刷新页面来获取批次
        $('#warehouse_id, #product_id').on('change', function() {
            var warehouseId = $('#warehouse_id').val();
            var productId = $('#product_id').val();

            if (warehouseId && productId) {
                // 显示加载中
                $('#batch_id').html('<option value="">加载中...</option>');

                // 通过刷新页面获取批次数据
                window.location.href = 'index.php?page=stocktaking&action=add&warehouse_id=' + warehouseId + '&product_id=' + productId;
            }
        });

        // 批次选择后，更新实际数量字段的默认值
        $('#batch_id').on('change', function() {
            var selectedBatch = $(this).find('option:selected');
            var text = selectedBatch.text();
            var match = text.match(/库存: (\d+)/);

            if (match && match[1]) {
                var currentQuantity = parseInt(match[1]);
                $('#actual_quantity').val(currentQuantity);
                $('#actual_quantity').attr('placeholder', '当前系统库存: ' + currentQuantity);
            } else {
                $('#actual_quantity').val('');
                $('#actual_quantity').attr('placeholder', '请输入实际数量');
            }
        });

        // 如果已有批次选择，触发一次变更事件来更新实际数量
        if ($('#batch_id').val()) {
            $('#batch_id').trigger('change');
        }
    });
</script>
</script>