<?php
// 防止直接访问
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';
$error = '';

// 处理库存调拨表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'transfer') {
    $source_id = isset($_POST['source_id']) ? (int)$_POST['source_id'] : 0;
    $target_id = isset($_POST['target_id']) ? (int)$_POST['target_id'] : 0;
    $product_id = isset($_POST['product_id']) ? (int)$_POST['product_id'] : 0;
    $batch_id = isset($_POST['batch_id']) ? (int)$_POST['batch_id'] : 0;
    $quantity = isset($_POST['quantity']) ? (int)$_POST['quantity'] : 0;
    $transfer_remark = isset($_POST['transfer_remark']) ? trim($_POST['transfer_remark']) : '';

    // 验证表单数据
    if ($source_id <= 0) {
        $error = '请选择源仓库';
    } elseif ($target_id <= 0) {
        $error = '请选择目标仓库';
    } elseif ($source_id == $target_id) {
        $error = '源仓库和目标仓库不能相同';
    } elseif ($product_id <= 0) {
        $error = '请选择商品';
    } elseif ($batch_id <= 0) {
        $error = '请选择批次';
    } elseif ($quantity <= 0) {
        $error = '调拨数量必须大于0';
    } else {
        try {
            // 开始事务
            $conn->begin_transaction();

            // 检查源仓库库存是否足够
            $checkSql = "SELECT quantity FROM inventory WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
            $checkStmt = $conn->prepare($checkSql);
            if (!$checkStmt) {
                throw new Exception("准备查询源仓库库存失败: " . $conn->error);
            }

            $checkStmt->bind_param("iii", $source_id, $product_id, $batch_id);
            $checkStmt->execute();
            $checkResult = $checkStmt->get_result();

            if ($checkResult->num_rows == 0) {
                throw new Exception("源仓库中没有该商品批次的库存记录");
            }

            $sourceStock = $checkResult->fetch_assoc()['quantity'];
            $checkStmt->close();

            if ($sourceStock < $quantity) {
                throw new Exception("源仓库库存不足，当前库存: $sourceStock");
            }

            // 减少源仓库库存
            $updateSourceSql = "UPDATE inventory SET quantity = quantity - ?, updated_at = NOW() WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
            $updateSourceStmt = $conn->prepare($updateSourceSql);
            if (!$updateSourceStmt) {
                throw new Exception("准备更新源仓库库存失败: " . $conn->error);
            }

            $updateSourceStmt->bind_param("iiii", $quantity, $source_id, $product_id, $batch_id);
            if (!$updateSourceStmt->execute()) {
                throw new Exception("减少源仓库库存失败: " . $updateSourceStmt->error);
            }
            $updateSourceStmt->close();

            // 检查目标仓库是否有该商品批次的库存记录
            $checkTargetSql = "SELECT inventory_id FROM inventory WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
            $checkTargetStmt = $conn->prepare($checkTargetSql);
            if (!$checkTargetStmt) {
                throw new Exception("准备查询目标仓库库存失败: " . $conn->error);
            }

            $checkTargetStmt->bind_param("iii", $target_id, $product_id, $batch_id);
            $checkTargetStmt->execute();
            $checkTargetResult = $checkTargetStmt->get_result();

            if ($checkTargetResult->num_rows == 0) {
                // 如果目标仓库没有该商品批次的库存记录，则创建一条新记录
                $createInventorySql = "INSERT INTO inventory (warehouse_id, product_id, batch_id, quantity, min_stock_level, created_at, updated_at) 
                                       VALUES (?, ?, ?, ?, 0, NOW(), NOW())";
                $createInventoryStmt = $conn->prepare($createInventorySql);
                if (!$createInventoryStmt) {
                    throw new Exception("准备创建目标仓库库存记录失败: " . $conn->error);
                }

                $createInventoryStmt->bind_param("iiii", $target_id, $product_id, $batch_id, $quantity);
                if (!$createInventoryStmt->execute()) {
                    throw new Exception("创建目标仓库库存记录失败: " . $createInventoryStmt->error);
                }
                $createInventoryStmt->close();
            } else {
                // 如果目标仓库已有该商品批次的库存记录，则增加库存
                $updateTargetSql = "UPDATE inventory SET quantity = quantity + ?, updated_at = NOW() WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
                $updateTargetStmt = $conn->prepare($updateTargetSql);
                if (!$updateTargetStmt) {
                    throw new Exception("准备更新目标仓库库存失败: " . $conn->error);
                }

                $updateTargetStmt->bind_param("iiii", $quantity, $target_id, $product_id, $batch_id);
                if (!$updateTargetStmt->execute()) {
                    throw new Exception("增加目标仓库库存失败: " . $updateTargetStmt->error);
                }
                $updateTargetStmt->close();
            }
            $checkTargetStmt->close();

            // 创建库存调拨记录
            $transferSql = "INSERT INTO inventory_transfers (from_warehouse_id, to_warehouse_id, product_id, batch_id, quantity, transfer_date, status, created_at, updated_at) 
                           VALUES (?, ?, ?, ?, ?, NOW(), 'completed', NOW(), NOW())";
            $transferStmt = $conn->prepare($transferSql);
            if (!$transferStmt) {
                throw new Exception("准备创建调拨记录失败: " . $conn->error);
            }

            $transferStmt->bind_param("iiiii", $source_id, $target_id, $product_id, $batch_id, $quantity);
            if (!$transferStmt->execute()) {
                throw new Exception("创建调拨记录失败: " . $transferStmt->error);
            }
            $transfer_id = $conn->insert_id;
            $transferStmt->close();

            // 提交事务
            $conn->commit();

            // 记录操作日志
            $operationDetails = "库存调拨: ID[$transfer_id], 从仓库[$source_id]调拨[$quantity]个商品[$product_id]批次[$batch_id]到仓库[$target_id]";
            log_operation($_SESSION['user_id'], '库存调拨', $operationDetails);

            $message = "库存调拨成功，调拨单号: TR" . $transfer_id;
            $messageType = "success";

            // 添加重定向到列表页面
            header("Location: index.php?page=transfer&message=" . urlencode($message) . "&type=" . $messageType);
            exit;
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            $error = '库存调拨失败: ' . $e->getMessage();
        }
    }
}

// 处理调拨记录编辑提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'edit_transfer') {
    $transfer_id = isset($_POST['transfer_id']) ? (int)$_POST['transfer_id'] : 0;
    $new_quantity = isset($_POST['new_quantity']) ? (int)$_POST['new_quantity'] : 0;
    $old_quantity = isset($_POST['old_quantity']) ? (int)$_POST['old_quantity'] : 0;
    $transfer_date = isset($_POST['transfer_date']) ? $_POST['transfer_date'] : '';
    $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

    // 验证表单数据
    if ($transfer_id <= 0) {
        $error = '无效的调拨记录ID';
    } elseif ($new_quantity <= 0) {
        $error = '调拨数量必须大于0';
    } elseif (empty($transfer_date)) {
        $error = '请选择调拨日期';
    } else {
        try {
            // 开始事务
            $conn->begin_transaction();

            // 获取调拨记录详情
            $transferDetailSql = "SELECT * FROM inventory_transfers WHERE transfer_id = ?";
            $transferDetailStmt = $conn->prepare($transferDetailSql);
            $transferDetailStmt->bind_param("i", $transfer_id);
            $transferDetailStmt->execute();
            $transferDetail = $transferDetailStmt->get_result()->fetch_assoc();
            $transferDetailStmt->close();

            if (!$transferDetail) {
                throw new Exception("调拨记录不存在");
            }

            $from_warehouse_id = $transferDetail['from_warehouse_id'];
            $to_warehouse_id = $transferDetail['to_warehouse_id'];
            $product_id = $transferDetail['product_id'];
            $batch_id = $transferDetail['batch_id'];

            $quantity_diff = $new_quantity - $old_quantity;

            if ($quantity_diff != 0) {
                // 如果数量有变化，需要调整库存
                if ($quantity_diff > 0) {
                    // 如果新数量大于旧数量，需要从源仓库多减去差额，并给目标仓库多加上差额

                    // 检查源仓库库存是否足够
                    $checkSql = "SELECT quantity FROM inventory WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
                    $checkStmt = $conn->prepare($checkSql);
                    $checkStmt->bind_param("iii", $from_warehouse_id, $product_id, $batch_id);
                    $checkStmt->execute();
                    $checkResult = $checkStmt->get_result();

                    if ($checkResult->num_rows == 0) {
                        throw new Exception("源仓库中没有该商品批次的库存记录");
                    }

                    $sourceStock = $checkResult->fetch_assoc()['quantity'];
                    $checkStmt->close();

                    if ($sourceStock < $quantity_diff) {
                        throw new Exception("源仓库库存不足，当前库存: $sourceStock，需要增加: $quantity_diff");
                    }

                    // 减少源仓库库存
                    $updateSourceSql = "UPDATE inventory SET quantity = quantity - ?, updated_at = NOW() 
                                        WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
                    $updateSourceStmt = $conn->prepare($updateSourceSql);
                    $updateSourceStmt->bind_param("iiii", $quantity_diff, $from_warehouse_id, $product_id, $batch_id);
                    $updateSourceStmt->execute();
                    $updateSourceStmt->close();

                    // 增加目标仓库库存
                    $updateTargetSql = "UPDATE inventory SET quantity = quantity + ?, updated_at = NOW() 
                                        WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
                    $updateTargetStmt = $conn->prepare($updateTargetSql);
                    $updateTargetStmt->bind_param("iiii", $quantity_diff, $to_warehouse_id, $product_id, $batch_id);
                    $updateTargetStmt->execute();
                    $updateTargetStmt->close();
                } else {
                    // 如果新数量小于旧数量，需要给源仓库加回差额，从目标仓库减去差额
                    $abs_diff = abs($quantity_diff);

                    // 检查目标仓库库存是否足够
                    $checkSql = "SELECT quantity FROM inventory WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
                    $checkStmt = $conn->prepare($checkSql);
                    $checkStmt->bind_param("iii", $to_warehouse_id, $product_id, $batch_id);
                    $checkStmt->execute();
                    $checkResult = $checkStmt->get_result();

                    if ($checkResult->num_rows == 0) {
                        throw new Exception("目标仓库中没有该商品批次的库存记录");
                    }

                    $targetStock = $checkResult->fetch_assoc()['quantity'];
                    $checkStmt->close();

                    if ($targetStock < $abs_diff) {
                        throw new Exception("目标仓库库存不足，当前库存: $targetStock，需要减少: $abs_diff");
                    }

                    // 增加源仓库库存
                    $updateSourceSql = "UPDATE inventory SET quantity = quantity + ?, updated_at = NOW() 
                                        WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
                    $updateSourceStmt = $conn->prepare($updateSourceSql);
                    $updateSourceStmt->bind_param("iiii", $abs_diff, $from_warehouse_id, $product_id, $batch_id);
                    $updateSourceStmt->execute();
                    $updateSourceStmt->close();

                    // 减少目标仓库库存
                    $updateTargetSql = "UPDATE inventory SET quantity = quantity - ?, updated_at = NOW() 
                                        WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
                    $updateTargetStmt = $conn->prepare($updateTargetSql);
                    $updateTargetStmt->bind_param("iiii", $abs_diff, $to_warehouse_id, $product_id, $batch_id);
                    $updateTargetStmt->execute();
                    $updateTargetStmt->close();
                }
            }

            // 更新调拨记录
            $updateTransferSql = "UPDATE inventory_transfers SET 
                                  quantity = ?, 
                                  transfer_date = ?, 
                                  updated_at = NOW() 
                                  WHERE transfer_id = ?";
            $updateTransferStmt = $conn->prepare($updateTransferSql);
            $updateTransferStmt->bind_param("isi", $new_quantity, $transfer_date, $transfer_id);
            $updateTransferStmt->execute();
            $updateTransferStmt->close();

            // 提交事务
            $conn->commit();

            // 记录操作日志
            $operationDetails = "编辑库存调拨: ID[$transfer_id], 调整数量[$old_quantity->$new_quantity], 调整日期[$transfer_date]";
            log_operation($_SESSION['user_id'], '编辑库存调拨', $operationDetails);

            $message = "调拨记录编辑成功";
            $messageType = "success";

            // 重定向到调拨列表页面
            header("Location: index.php?page=transfer&message=" . urlencode($message) . "&type=" . $messageType);
            exit;
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            $error = '编辑调拨记录失败: ' . $e->getMessage();
        }
    }
}

// 获取当前操作
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 处理URL中传递的消息参数
if (isset($_GET['message']) && isset($_GET['type'])) {
    $message = $_GET['message'];
    $messageType = $_GET['type'];
}

// 获取查询参数
$source_id = isset($_GET['source_id']) ? (int)$_GET['source_id'] : 0;
$product_id = isset($_GET['product_id']) ? (int)$_GET['product_id'] : 0;
$batch_id = isset($_GET['batch_id']) ? (int)$_GET['batch_id'] : 0;

// 获取所有仓库
$warehouses = [];
$warehouseSql = "SELECT warehouse_id, warehouse_name, type as warehouse_type, location as warehouse_location FROM warehouses ORDER BY warehouse_name";
$warehouseStmt = $conn->prepare($warehouseSql);
if ($warehouseStmt) {
    $warehouseStmt->execute();
    $warehouseResult = $warehouseStmt->get_result();
    while ($row = $warehouseResult->fetch_assoc()) {
        $warehouses[] = $row;
    }
    $warehouseStmt->close();
} else {
    echo '<div class="alert alert-error">获取仓库列表失败: ' . $conn->error . '</div>';
}

// 获取所有商品
$products = [];
$productSql = "SELECT p.product_id, p.product_name, p.barcode, p.unit FROM products p ORDER BY p.product_name";
$productStmt = $conn->prepare($productSql);
if ($productStmt) {
    $productStmt->execute();
    $productResult = $productStmt->get_result();
    while ($row = $productResult->fetch_assoc()) {
        $products[] = $row;
    }
    $productStmt->close();
} else {
    echo '<div class="alert alert-error">获取商品列表失败: ' . $conn->error . '</div>';
}

// 获取源仓库的商品库存
$sourceInventory = null;
if ($source_id > 0 && $product_id > 0 && $batch_id > 0) {
    $inventorySql = "SELECT i.inventory_id, i.quantity as current_stock, i.batch_id, p.product_name, p.barcode, p.unit, w.warehouse_name, b.batch_number, b.production_date, b.expiration_date
                     FROM inventory i
                     JOIN products p ON i.product_id = p.product_id
                     JOIN warehouses w ON i.warehouse_id = w.warehouse_id
                     JOIN product_batches b ON i.batch_id = b.batch_id
                     WHERE i.warehouse_id = ? AND i.product_id = ? AND i.batch_id = ?";
    $inventoryStmt = $conn->prepare($inventorySql);
    if ($inventoryStmt) {
        $inventoryStmt->bind_param("iii", $source_id, $product_id, $batch_id);
        $inventoryStmt->execute();
        $inventoryResult = $inventoryStmt->get_result();
        if ($inventoryResult->num_rows > 0) {
            $sourceInventory = $inventoryResult->fetch_assoc();
        }
        $inventoryStmt->close();
    } else {
        echo '<div class="alert alert-error">获取商品库存失败: ' . $conn->error . '</div>';
    }
}

// 直接在PHP中获取批次数据，不使用AJAX
$batches = [];
if ($source_id > 0 && $product_id > 0) {
    // 查询该仓库和商品的所有批次
    $batchesSql = "SELECT i.batch_id, b.batch_number, b.production_date, b.expiration_date, i.quantity 
                   FROM inventory i
                   JOIN product_batches b ON i.batch_id = b.batch_id
                   WHERE i.warehouse_id = ? AND i.product_id = ? AND i.quantity > 0
                   ORDER BY b.expiration_date";

    // 记录SQL查询以便调试
    error_log("批次查询SQL: " . $batchesSql . " [warehouse_id=$source_id, product_id=$product_id]");

    $batchesStmt = $conn->prepare($batchesSql);
    if ($batchesStmt) {
        $batchesStmt->bind_param("ii", $source_id, $product_id);
        $batchesStmt->execute();
        $batchesResult = $batchesStmt->get_result();

        // 记录结果数量用于调试
        error_log("批次查询结果数量: " . $batchesResult->num_rows);

        while ($row = $batchesResult->fetch_assoc()) {
            $batches[] = $row;
        }
        $batchesStmt->close();
    } else {
        echo '<div class="alert alert-error">获取批次列表失败: ' . $conn->error . '</div>';
    }
}

// 获取最近的调拨记录
$transfers = [];
$transferSql = "SELECT t.transfer_id, CONCAT('TR', t.transfer_id) as transfer_number, t.from_warehouse_id as source_warehouse_id, t.to_warehouse_id as target_warehouse_id,
                t.product_id, t.batch_id, t.quantity, t.transfer_date, t.status, t.created_at,
                sw.warehouse_name as source_warehouse_name, tw.warehouse_name as target_warehouse_name,
                p.product_name, p.barcode, p.unit, b.batch_number, b.production_date, b.expiration_date
                FROM inventory_transfers t
                JOIN warehouses sw ON t.from_warehouse_id = sw.warehouse_id
                JOIN warehouses tw ON t.to_warehouse_id = tw.warehouse_id
                JOIN products p ON t.product_id = p.product_id
                LEFT JOIN product_batches b ON t.batch_id = b.batch_id
                WHERE 1=1";

// 添加仓库筛选条件
if (isset($_GET['source_warehouse_id']) && !empty($_GET['source_warehouse_id'])) {
    $source_warehouse_id = (int)$_GET['source_warehouse_id'];
    $transferSql .= " AND t.from_warehouse_id = $source_warehouse_id";
}

if (isset($_GET['target_warehouse_id']) && !empty($_GET['target_warehouse_id'])) {
    $target_warehouse_id = (int)$_GET['target_warehouse_id'];
    $transferSql .= " AND t.to_warehouse_id = $target_warehouse_id";
}

$transferSql .= " ORDER BY t.transfer_date DESC, t.created_at DESC LIMIT 100";

$transferStmt = $conn->prepare($transferSql);
if ($transferStmt) {
    $transferStmt->execute();
    $transferResult = $transferStmt->get_result();
    while ($row = $transferResult->fetch_assoc()) {
        $transfers[] = $row;
    }
    $transferStmt->close();
} else {
    echo '<div class="alert alert-error">获取调拨记录失败: ' . $conn->error . '</div>';
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 显示错误信息 -->
<?php if (!empty($error)): ?>
    <div class="alert alert-error"><?php echo $error; ?></div>
<?php endif; ?>

<!-- jQuery库必须在Select2之前引入 -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- 引入Select2库 -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<?php if ($action == 'add'): ?>
    <!-- 库存调拨表单 -->
    <div class="form-container">
        <h3>库存调拨</h3>
        <form method="post" action="">
            <input type="hidden" name="action" value="transfer">

            <div class="form-group">
                <label for="source_id">源仓库 <span class="required">*</span></label>
                <select name="source_id" id="source_id" class="select2-warehouse" required>
                    <option value="">请选择源仓库</option>
                    <?php foreach ($warehouses as $warehouse): ?>
                        <option value="<?php echo $warehouse['warehouse_id']; ?>"
                            <?php echo $source_id == $warehouse['warehouse_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($warehouse['warehouse_name'] . ' (' . getWarehouseTypeChinese($warehouse['warehouse_type']) . ')'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label for="target_id">目标仓库 <span class="required">*</span></label>
                <select name="target_id" id="target_id" class="select2-warehouse" required>
                    <option value="">请选择目标仓库</option>
                    <?php foreach ($warehouses as $warehouse): ?>
                        <?php if ($warehouse['warehouse_id'] != $source_id): ?>
                            <option value="<?php echo $warehouse['warehouse_id']; ?>">
                                <?php echo htmlspecialchars($warehouse['warehouse_name'] . ' (' . getWarehouseTypeChinese($warehouse['warehouse_type']) . ')'); ?>
                            </option>
                        <?php endif; ?>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label for="product_id">商品 <span class="required">*</span></label>
                <select name="product_id" id="product_id" class="select2-product" required>
                    <option value="">请选择商品</option>
                    <?php foreach ($products as $product): ?>
                        <option value="<?php echo $product['product_id']; ?>"
                            <?php echo $product_id == $product['product_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($product['product_name'] . ' (' . $product['barcode'] . ')'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group" id="batch-select-container">
                <label for="batch_id">批次 <span class="required">*</span></label>
                <select name="batch_id" id="batch_id" class="select2-batch" required>
                    <option value="">请先选择仓库和商品</option>
                    <?php if (count($batches) > 0): ?>
                        <?php foreach ($batches as $b): ?>
                            <option value="<?php echo $b['batch_id']; ?>"
                                <?php echo $batch_id == $b['batch_id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($b['batch_number'] . ' (库存: ' . $b['quantity'] . ', 有效期: ' . $b['expiration_date'] . ')'); ?>
                            </option>
                        <?php endforeach; ?>
                    <?php elseif ($source_id > 0 && $product_id > 0): ?>
                        <option value="" disabled>该仓库没有该商品的批次库存</option>
                    <?php endif; ?>
                </select>

                <?php if ($source_id > 0 && $product_id > 0 && count($batches) == 0): ?>
                    <div class="alert alert-warning" style="margin-top: 10px;">
                        该仓库没有该商品的批次库存，请先添加批次
                        <br>
                        <a href="index.php?page=batch&action=add&product_id=<?php echo $product_id; ?>" class="btn btn-primary" style="margin-top: 10px;">添加批次</a>
                    </div>
                <?php endif; ?>
            </div>

            <?php if ($sourceInventory): ?>
                <div class="inventory-info">
                    <div class="info-item">
                        <label>商品:</label>
                        <span><?php echo htmlspecialchars($sourceInventory['product_name'] . ' (' . $sourceInventory['barcode'] . ')'); ?></span>
                    </div>
                    <div class="info-item">
                        <label>批次号:</label>
                        <span><?php echo htmlspecialchars($sourceInventory['batch_number']); ?></span>
                    </div>
                    <div class="info-item">
                        <label>生产日期:</label>
                        <span><?php echo $sourceInventory['production_date']; ?></span>
                    </div>
                    <div class="info-item">
                        <label>有效期至:</label>
                        <span><?php echo $sourceInventory['expiration_date']; ?></span>
                    </div>
                    <div class="info-item">
                        <label>当前库存:</label>
                        <span><?php echo $sourceInventory['current_stock']; ?> <?php echo htmlspecialchars($sourceInventory['unit']); ?></span>
                    </div>
                </div>
            <?php endif; ?>

            <div class="form-group">
                <label for="quantity">调拨数量 <span class="required">*</span></label>
                <input type="number" id="quantity" name="quantity" min="1"
                    max="<?php echo $sourceInventory ? $sourceInventory['current_stock'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="transfer_remark">备注</label>
                <textarea id="transfer_remark" name="transfer_remark" rows="3"></textarea>
            </div>

            <div class="form-actions">
                <button type="submit" class="btn btn-primary">提交调拨</button>
                <a href="index.php?page=transfer" class="btn btn-secondary">返回调拨列表</a>
            </div>
        </form>
    </div>

<?php elseif ($action == 'view' && isset($_GET['id'])): ?>
    <?php
    // 获取调拨详情
    $transfer_id = (int)$_GET['id'];
    $transferDetailSql = "SELECT t.*, 
                          sw.warehouse_name as source_warehouse_name, sw.type as source_warehouse_type,
                          tw.warehouse_name as target_warehouse_name, tw.type as target_warehouse_type,
                          p.product_name, p.barcode, p.unit, 
                          b.batch_number, b.production_date, b.expiration_date
                          FROM inventory_transfers t
                          JOIN warehouses sw ON t.from_warehouse_id = sw.warehouse_id
                          JOIN warehouses tw ON t.to_warehouse_id = tw.warehouse_id
                          JOIN products p ON t.product_id = p.product_id
                          LEFT JOIN product_batches b ON t.batch_id = b.batch_id
                          WHERE t.transfer_id = ?";
    $transferDetailStmt = $conn->prepare($transferDetailSql);
    $transferDetailStmt->bind_param("i", $transfer_id);
    $transferDetailStmt->execute();
    $transferDetail = $transferDetailStmt->get_result()->fetch_assoc();
    $transferDetailStmt->close();

    if (!$transferDetail) {
        echo '<div class="alert alert-error">调拨记录不存在</div>';
        echo '<a href="index.php?page=transfer" class="btn btn-secondary">返回调拨列表</a>';
    } else {
    ?>
        <!-- 调拨详情 -->
        <div class="detail-container">
            <h3>调拨详情</h3>
            <div class="detail-content">
                <div class="detail-group">
                    <label>调拨单号:</label>
                    <span>TR<?php echo $transferDetail['transfer_id']; ?></span>
                </div>
                <div class="detail-group">
                    <label>源仓库:</label>
                    <span><?php echo htmlspecialchars($transferDetail['source_warehouse_name'] . ' (' . getWarehouseTypeChinese($transferDetail['source_warehouse_type']) . ')'); ?></span>
                </div>
                <div class="detail-group">
                    <label>目标仓库:</label>
                    <span><?php echo htmlspecialchars($transferDetail['target_warehouse_name'] . ' (' . getWarehouseTypeChinese($transferDetail['target_warehouse_type']) . ')'); ?></span>
                </div>
                <div class="detail-group">
                    <label>商品:</label>
                    <span><?php echo htmlspecialchars($transferDetail['product_name'] . ' (' . $transferDetail['barcode'] . ')'); ?></span>
                </div>
                <div class="detail-group">
                    <label>批次号:</label>
                    <span><?php echo htmlspecialchars($transferDetail['batch_number']); ?></span>
                </div>
                <div class="detail-group">
                    <label>调拨数量:</label>
                    <span><?php echo $transferDetail['quantity'] . ' ' . htmlspecialchars($transferDetail['unit']); ?></span>
                </div>
                <div class="detail-group">
                    <label>调拨日期:</label>
                    <span><?php echo $transferDetail['transfer_date']; ?></span>
                </div>
                <div class="detail-group">
                    <label>状态:</label>
                    <span class="badge badge-success">
                        <?php echo $transferDetail['status'] == 'completed' ? '已完成' : $transferDetail['status']; ?>
                    </span>
                </div>
                <div class="detail-group">
                    <label>创建时间:</label>
                    <span><?php echo $transferDetail['created_at']; ?></span>
                </div>
                <div class="detail-group">
                    <label>更新时间:</label>
                    <span><?php echo $transferDetail['updated_at']; ?></span>
                </div>
            </div>

            <div class="detail-actions">
                <a href="index.php?page=transfer&action=edit&id=<?php echo $transferDetail['transfer_id']; ?>" class="btn btn-primary">编辑调拨</a>
                <a href="index.php?page=transfer" class="btn btn-secondary">返回调拨列表</a>
            </div>
        </div>
    <?php } ?>
<?php elseif ($action == 'edit' && isset($_GET['id'])): ?>
    <?php
    // 获取调拨详情用于编辑
    $transfer_id = (int)$_GET['id'];
    $transferDetailSql = "SELECT t.*, 
                          sw.warehouse_name as source_warehouse_name, sw.type as source_warehouse_type,
                          tw.warehouse_name as target_warehouse_name, tw.type as target_warehouse_type,
                          p.product_name, p.barcode, p.unit, 
                          b.batch_number, b.production_date, b.expiration_date
                          FROM inventory_transfers t
                          JOIN warehouses sw ON t.from_warehouse_id = sw.warehouse_id
                          JOIN warehouses tw ON t.to_warehouse_id = tw.warehouse_id
                          JOIN products p ON t.product_id = p.product_id
                          LEFT JOIN product_batches b ON t.batch_id = b.batch_id
                          WHERE t.transfer_id = ?";
    $transferDetailStmt = $conn->prepare($transferDetailSql);
    $transferDetailStmt->bind_param("i", $transfer_id);
    $transferDetailStmt->execute();
    $transferDetail = $transferDetailStmt->get_result()->fetch_assoc();
    $transferDetailStmt->close();

    if (!$transferDetail) {
        echo '<div class="alert alert-error">调拨记录不存在</div>';
        echo '<a href="index.php?page=transfer" class="btn btn-secondary">返回调拨列表</a>';
    } else {
        // 检查源仓库和目标仓库当前库存
        $sourceInventorySql = "SELECT quantity FROM inventory 
                              WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
        $sourceInventoryStmt = $conn->prepare($sourceInventorySql);
        $sourceInventoryStmt->bind_param("iii", $transferDetail['from_warehouse_id'], $transferDetail['product_id'], $transferDetail['batch_id']);
        $sourceInventoryStmt->execute();
        $sourceInventoryResult = $sourceInventoryStmt->get_result();
        $sourceQuantity = ($sourceInventoryResult->num_rows > 0) ? $sourceInventoryResult->fetch_assoc()['quantity'] : 0;
        $sourceInventoryStmt->close();

        $targetInventorySql = "SELECT quantity FROM inventory 
                              WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
        $targetInventoryStmt = $conn->prepare($targetInventorySql);
        $targetInventoryStmt->bind_param("iii", $transferDetail['to_warehouse_id'], $transferDetail['product_id'], $transferDetail['batch_id']);
        $targetInventoryStmt->execute();
        $targetInventoryResult = $targetInventoryStmt->get_result();
        $targetQuantity = ($targetInventoryResult->num_rows > 0) ? $targetInventoryResult->fetch_assoc()['quantity'] : 0;
        $targetInventoryStmt->close();

        // 计算可编辑的最大数量
        $maxDecrease = $targetQuantity; // 最大可减少数量（当前目标仓库库存）
        $maxIncrease = $sourceQuantity; // 最大可增加数量（当前源仓库库存）
        $currentQty = $transferDetail['quantity'];
        $minQty = $currentQty - $maxDecrease; // 最小可编辑数量
        $maxQty = $currentQty + $maxIncrease; // 最大可编辑数量
        if ($minQty < 1) $minQty = 1; // 最小数量不能小于1
    ?>
        <div class="form-container">
            <h3>编辑调拨记录</h3>
            <form method="post" action="">
                <input type="hidden" name="action" value="edit_transfer">
                <input type="hidden" name="transfer_id" value="<?php echo $transferDetail['transfer_id']; ?>">
                <input type="hidden" name="old_quantity" value="<?php echo $transferDetail['quantity']; ?>">

                <div class="form-group">
                    <label>调拨单号:</label>
                    <div class="form-control-static">TR<?php echo $transferDetail['transfer_id']; ?></div>
                </div>

                <div class="form-group">
                    <label>调出仓库:</label>
                    <div class="form-control-static"><?php echo htmlspecialchars($transferDetail['source_warehouse_name'] . ' (' . getWarehouseTypeChinese($transferDetail['source_warehouse_type']) . ')'); ?></div>
                </div>

                <div class="form-group">
                    <label>调入仓库:</label>
                    <div class="form-control-static"><?php echo htmlspecialchars($transferDetail['target_warehouse_name'] . ' (' . getWarehouseTypeChinese($transferDetail['target_warehouse_type']) . ')'); ?></div>
                </div>

                <div class="form-group">
                    <label>商品:</label>
                    <div class="form-control-static"><?php echo htmlspecialchars($transferDetail['product_name'] . ' (' . $transferDetail['barcode'] . ')'); ?></div>
                </div>

                <div class="form-group">
                    <label>批次:</label>
                    <div class="form-control-static"><?php echo htmlspecialchars($transferDetail['batch_number']); ?></div>
                </div>

                <div class="form-group">
                    <label for="new_quantity">调拨数量 <span class="required">*</span></label>
                    <input type="number" id="new_quantity" name="new_quantity" min="1" max="<?php echo $maxQty; ?>" value="<?php echo $transferDetail['quantity']; ?>" required>
                    <div class="form-hint">当前源仓库库存: <?php echo $sourceQuantity; ?>, 当前目标仓库库存: <?php echo $targetQuantity; ?></div>
                    <div class="form-hint">调整可能会受到当前库存限制</div>
                </div>

                <div class="form-group">
                    <label for="transfer_date">调拨日期 <span class="required">*</span></label>
                    <input type="date" id="transfer_date" name="transfer_date" value="<?php echo date('Y-m-d', strtotime($transferDetail['transfer_date'])); ?>" required>
                </div>

                <div class="form-group">
                    <label for="remark">备注</label>
                    <textarea id="remark" name="remark" rows="3"><?php echo isset($transferDetail['remark']) ? htmlspecialchars($transferDetail['remark']) : ''; ?></textarea>
                </div>

                <div class="form-actions">
                    <button type="submit" class="btn btn-primary">保存</button>
                    <a href="index.php?page=transfer&action=view&id=<?php echo $transferDetail['transfer_id']; ?>" class="btn btn-secondary">返回详情</a>
                    <a href="index.php?page=transfer" class="btn btn-secondary">返回列表</a>
                </div>
            </form>
        </div>
    <?php } ?>
<?php else: ?>
    <!-- 显示调拨记录列表 -->
    <div class="module-tools">
        <div class="tool-left">
            <a href="index.php?page=transfer&action=add" class="btn btn-primary">新增调拨</a>
        </div>
        <div class="tool-right">
            <form action="index.php" method="get" class="search-form">
                <input type="hidden" name="page" value="transfer">

                <div class="search-group">
                    <label for="source_warehouse_id" style="display:block;margin-bottom:5px;font-weight:bold;">调出仓库:</label>
                    <select name="source_warehouse_id" id="source_warehouse_id" class="search-input select2-warehouse">
                        <option value="">所有调出仓库</option>
                        <?php foreach ($warehouses as $warehouse): ?>
                            <option value="<?php echo $warehouse['warehouse_id']; ?>"
                                <?php echo isset($_GET['source_warehouse_id']) && $_GET['source_warehouse_id'] == $warehouse['warehouse_id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($warehouse['warehouse_name']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="search-group">
                    <label for="target_warehouse_id" style="display:block;margin-bottom:5px;font-weight:bold;">调入仓库:</label>
                    <select name="target_warehouse_id" id="target_warehouse_id" class="search-input select2-warehouse">
                        <option value="">所有调入仓库</option>
                        <?php foreach ($warehouses as $warehouse): ?>
                            <option value="<?php echo $warehouse['warehouse_id']; ?>"
                                <?php echo isset($_GET['target_warehouse_id']) && $_GET['target_warehouse_id'] == $warehouse['warehouse_id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($warehouse['warehouse_name']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="search-group" style="display:flex;align-items:flex-end;">
                    <button type="submit" class="btn btn-secondary">搜索</button>
                    <a href="index.php?page=transfer" class="btn btn-secondary" style="margin-left:10px;">重置</a>
                </div>
            </form>
        </div>
    </div>

    <!-- 最近调拨记录 -->
    <div class="data-wrapper">
        <h3>调拨记录</h3>
        <?php if (count($transfers) > 0): ?>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>调拨单号</th>
                        <th>源仓库</th>
                        <th>目标仓库</th>
                        <th>商品</th>
                        <th>批次</th>
                        <th>数量</th>
                        <th>调拨日期</th>
                        <th>状态</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($transfers as $transfer): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($transfer['transfer_number']); ?></td>
                            <td><?php echo htmlspecialchars($transfer['source_warehouse_name']); ?></td>
                            <td><?php echo htmlspecialchars($transfer['target_warehouse_name']); ?></td>
                            <td><?php echo htmlspecialchars($transfer['product_name']); ?></td>
                            <td><?php echo htmlspecialchars($transfer['batch_number']); ?></td>
                            <td><?php echo $transfer['quantity']; ?></td>
                            <td><?php echo $transfer['transfer_date']; ?></td>
                            <td>
                                <span class="badge badge-success">
                                    <?php echo $transfer['status'] == 'completed' ? '已完成' : $transfer['status']; ?>
                                </span>
                            </td>
                            <td class="actions">
                                <a href="index.php?page=transfer&action=view&id=<?php echo $transfer['transfer_id']; ?>" class="btn btn-secondary btn-sm">查看</a>
                                <a href="index.php?page=transfer&action=edit&id=<?php echo $transfer['transfer_id']; ?>" class="btn btn-primary btn-sm">编辑</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <div class="alert alert-info">暂无调拨记录</div>
        <?php endif; ?>
    </div>
<?php endif; ?>

<style>
    .inventory-info {
        margin-bottom: 15px;
        padding: 10px;
        background-color: #f9f9f9;
        border-radius: 5px;
    }

    .info-item {
        margin-bottom: 5px;
    }

    .info-item label {
        font-weight: bold;
        margin-right: 10px;
    }

    .recent-transfers {
        margin-top: 30px;
    }

    .recent-transfers h3 {
        margin-bottom: 15px;
    }

    /* Select2样式修正 */
    .select2-container {
        width: 100% !important;
        margin-bottom: 10px;
    }

    .select2-container .select2-selection--single {
        height: 38px;
        padding: 5px;
    }

    .select2-container--default .select2-selection--single .select2-selection__rendered {
        line-height: 28px;
    }

    .select2-container--default .select2-selection--single .select2-selection__arrow {
        height: 36px;
    }

    /* 调拨详情页样式 */
    .detail-container {
        background-color: #fff;
        padding: 20px;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    .detail-content {
        margin-bottom: 20px;
    }

    .detail-group {
        margin-bottom: 15px;
        display: flex;
    }

    .detail-group label {
        font-weight: bold;
        width: 120px;
        flex-shrink: 0;
    }

    .detail-actions {
        margin-top: 20px;
        border-top: 1px solid #eee;
        padding-top: 15px;
    }

    /* 编辑表单样式 */
    .form-control-static {
        padding: 8px 0;
        font-size: 14px;
        line-height: 1.5;
    }

    .form-hint {
        margin-top: 5px;
        font-size: 12px;
        color: #777;
    }
</style>

<script>
    // 页面加载完成后初始化
    $(document).ready(function() {
        // 初始化Select2
        $('.select2-warehouse').select2({
            placeholder: "请选择仓库",
            allowClear: true,
            width: '100%'
        });

        $('.select2-product').select2({
            placeholder: "请选择商品",
            allowClear: true,
            width: '100%'
        });

        $('.select2-batch').select2({
            placeholder: "请选择批次",
            allowClear: true,
            width: '100%'
        });

        // 当仓库或商品变化时，刷新页面来获取批次
        $('#source_id, #product_id').on('change', function() {
            var sourceId = $('#source_id').val();
            var productId = $('#product_id').val();

            if (sourceId && productId) {
                // 显示加载中
                $('#batch_id').html('<option value="">加载中...</option>');

                // 通过刷新页面获取批次数据
                window.location.href = 'index.php?page=transfer&action=add&source_id=' + sourceId + '&product_id=' + productId;
            }
        });

        // 当源仓库变化时，更新目标仓库选项
        $('#source_id').on('change', function() {
            updateTargetWarehouses();
        });

        function updateTargetWarehouses() {
            var sourceId = parseInt($('#source_id').val()) || 0;
            var targetSelect = $('#target_id');

            // 清除并重新添加选项
            targetSelect.empty().append('<option value="">请选择目标仓库</option>');

            // 遍历所有仓库，添加不是源仓库的选项
            <?php foreach ($warehouses as $warehouse): ?>
                if (<?php echo $warehouse['warehouse_id']; ?> !== sourceId) {
                    targetSelect.append(
                        $('<option></option>')
                        .val('<?php echo $warehouse['warehouse_id']; ?>')
                        .text('<?php echo htmlspecialchars($warehouse['warehouse_name'] . ' (' . getWarehouseTypeChinese($warehouse['warehouse_type']) . ')'); ?>')
                    );
                }
            <?php endforeach; ?>

            // 触发Select2更新
            targetSelect.trigger('change');
        }

        // 批次选择后，更新数量上限
        $('#batch_id').on('change', function() {
            var selectedBatch = $(this).find('option:selected');
            var text = selectedBatch.text();
            var match = text.match(/库存: (\d+)/);

            if (match && match[1]) {
                var maxQuantity = parseInt(match[1]);
                $('#quantity').attr('max', maxQuantity);
                $('#quantity').attr('placeholder', '最大可调拨数量: ' + maxQuantity);
            } else {
                $('#quantity').removeAttr('max');
                $('#quantity').attr('placeholder', '请输入调拨数量');
            }
        });

        // 如果已有批次选择，触发一次变更事件来更新数量上限
        if ($('#batch_id').val()) {
            $('#batch_id').trigger('change');
        }
    });
</script>