<?php
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    die('禁止直接访问此文件');
}

// 设置标题
$isEdit = isset($logistics['logistics_id']);
$title = $isEdit ? '编辑物流订单' : '创建物流订单';
$submitButtonText = $isEdit ? '保存修改' : '创建订单';
$actionUrl = $isEdit ? "index.php?page=delivery&action=edit&id={$logistics['logistics_id']}" : "index.php?page=delivery&action=add";
?>

<div class="module-tools">
    <div class="tool-left">
        <h3><?php echo $title; ?></h3>
    </div>
    <div class="tool-right">
        <a href="index.php?page=delivery" class="btn btn-secondary">返回列表</a>
    </div>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>">
        <?php echo $message; ?>
    </div>
<?php endif; ?>

<div class="content-section">
    <form action="<?php echo $actionUrl; ?>" method="post" class="form">
        <?php if ($isEdit): ?>
            <input type="hidden" name="logistics_id" value="<?php echo $logistics['logistics_id']; ?>">
        <?php endif; ?>

        <div class="form-section">
            <h4>基本信息</h4>

            <div class="form-row">
                <?php if (!$isEdit): ?>
                    <div class="form-group">
                        <label for="delivery_id">选择出库单*</label>
                        <select name="delivery_id" id="delivery_id" class="form-control" required>
                            <option value="">请选择出库单</option>
                            <?php foreach ($deliveries as $delivery): ?>
                                <option value="<?php echo $delivery['delivery_id']; ?>" <?php echo isset($logistics['delivery_id']) && $logistics['delivery_id'] == $delivery['delivery_id'] ? 'selected' : ''; ?>>
                                    <?php echo $delivery['delivery_number'] . ' - ' . $delivery['customer_name'] . ' (' . date('Y-m-d', strtotime($delivery['delivery_date'])) . ')'; ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                <?php else: ?>
                    <div class="form-group">
                        <label>物流单号</label>
                        <input type="text" class="form-control" value="<?php echo isset($logistics['logistics_number']) ? htmlspecialchars($logistics['logistics_number']) : ''; ?>" readonly>
                    </div>
                <?php endif; ?>

                <div class="form-group">
                    <label for="method_id">配送方式*</label>
                    <select name="method_id" id="method_id" class="form-control" required onchange="toggleCompanyField()">
                        <option value="">请选择配送方式</option>
                        <?php foreach ($methods as $method): ?>
                            <option value="<?php echo $method['method_id']; ?>" data-third-party="<?php echo $method['is_third_party']; ?>" <?php echo isset($logistics['method_id']) && $logistics['method_id'] == $method['method_id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($method['method_name']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </div>

            <div id="third-party-fields" style="display: none;">
                <div class="form-row">
                    <div class="form-group">
                        <label for="company_id">物流公司</label>
                        <select name="company_id" id="company_id" class="form-control">
                            <option value="">请选择物流公司</option>
                            <?php foreach ($companies as $company): ?>
                                <option value="<?php echo $company['company_id']; ?>" <?php echo isset($logistics['company_id']) && $logistics['company_id'] == $company['company_id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($company['company_name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="tracking_number">物流单号</label>
                        <input type="text" name="tracking_number" id="tracking_number" class="form-control" value="<?php echo isset($logistics['tracking_number']) ? htmlspecialchars($logistics['tracking_number']) : ''; ?>" placeholder="第三方物流单号">
                        <div class="form-tip">第三方物流公司的跟踪号码</div>
                    </div>
                </div>
            </div>

            <?php if ($isEdit): ?>
                <div class="form-group">
                    <label for="logistics_status">物流状态*</label>
                    <select name="logistics_status" id="logistics_status" class="form-control" required>
                        <option value="pending" <?php echo $logistics['logistics_status'] === 'pending' ? 'selected' : ''; ?>>待处理</option>
                        <option value="processing" <?php echo $logistics['logistics_status'] === 'processing' ? 'selected' : ''; ?>>处理中</option>
                        <option value="shipping" <?php echo $logistics['logistics_status'] === 'shipping' ? 'selected' : ''; ?>>配送中</option>
                        <option value="delivered" <?php echo $logistics['logistics_status'] === 'delivered' ? 'selected' : ''; ?>>已送达</option>
                        <option value="cancelled" <?php echo $logistics['logistics_status'] === 'cancelled' ? 'selected' : ''; ?>>已取消</option>
                        <option value="exception" <?php echo $logistics['logistics_status'] === 'exception' ? 'selected' : ''; ?>>异常</option>
                    </select>
                </div>
            <?php endif; ?>
        </div>

        <div class="form-section">
            <h4>收件人信息</h4>

            <div class="form-row">
                <div class="form-group">
                    <label for="receiver_name">收件人姓名*</label>
                    <input type="text" name="receiver_name" id="receiver_name" class="form-control" value="<?php echo isset($logistics['receiver_name']) ? htmlspecialchars($logistics['receiver_name']) : ''; ?>" required>
                </div>

                <div class="form-group">
                    <label for="receiver_phone">联系电话*</label>
                    <input type="text" name="receiver_phone" id="receiver_phone" class="form-control" value="<?php echo isset($logistics['receiver_phone']) ? htmlspecialchars($logistics['receiver_phone']) : ''; ?>" required>
                </div>
            </div>

            <div class="form-group">
                <label for="shipping_address">收货地址*</label>
                <textarea name="shipping_address" id="shipping_address" class="form-control" rows="3" required><?php echo isset($logistics['shipping_address']) ? htmlspecialchars($logistics['shipping_address']) : ''; ?></textarea>
            </div>
        </div>

        <div class="form-section">
            <h4>配送信息</h4>

            <div class="form-row">
                <div class="form-group">
                    <label for="estimated_delivery_time">预计送达时间</label>
                    <input type="datetime-local" name="estimated_delivery_time" id="estimated_delivery_time" class="form-control" value="<?php echo isset($logistics['estimated_delivery_time']) ? date('Y-m-d\TH:i', strtotime($logistics['estimated_delivery_time'])) : ''; ?>">
                </div>

                <?php if ($isEdit && $logistics['logistics_status'] === 'delivered'): ?>
                    <div class="form-group">
                        <label for="actual_delivery_time">实际送达时间</label>
                        <input type="datetime-local" name="actual_delivery_time" id="actual_delivery_time" class="form-control" value="<?php echo isset($logistics['actual_delivery_time']) ? date('Y-m-d\TH:i', strtotime($logistics['actual_delivery_time'])) : ''; ?>">
                    </div>
                <?php endif; ?>

                <div class="form-group">
                    <label for="shipping_cost">配送费用（¥）</label>
                    <div class="price-input">
                        <span class="price-symbol"></span>
                        <input type="number" name="shipping_cost" id="shipping_cost" class="form-control" step="0.01" min="0" value="<?php echo isset($logistics['shipping_cost']) ? number_format($logistics['shipping_cost'], 2, '.', '') : '0.00'; ?>">
                    </div>
                </div>
            </div>

            <div class="form-row">
                <div class="form-group">
                    <label for="weight">重量 (kg)</label>
                    <input type="number" name="weight" id="weight" class="form-control" step="0.01" min="0" value="<?php echo isset($logistics['weight']) ? $logistics['weight'] : ''; ?>" placeholder="物品重量">
                </div>

                <div class="form-group">
                    <label for="volume">体积 (m³)</label>
                    <input type="number" name="volume" id="volume" class="form-control" step="0.001" min="0" value="<?php echo isset($logistics['volume']) ? $logistics['volume'] : ''; ?>" placeholder="物品体积">
                </div>
            </div>

            <div class="form-group">
                <label for="remark">备注</label>
                <textarea name="remark" id="remark" class="form-control" rows="3"><?php echo isset($logistics['remark']) ? htmlspecialchars($logistics['remark']) : ''; ?></textarea>
            </div>
        </div>

        <div class="form-actions">
            <button type="submit" class="btn btn-primary"><?php echo $submitButtonText; ?></button>
            <a href="index.php?page=delivery" class="btn btn-secondary">取消</a>
        </div>
    </form>
</div>

<style>
    .content-section {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        padding: 20px;
    }

    .form-section {
        margin-bottom: 25px;
        padding-bottom: 15px;
        border-bottom: 1px solid #e9ecef;
    }

    .form-section h4 {
        color: #0066cc;
        margin-bottom: 15px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        margin-bottom: 15px;
    }

    .form-group {
        flex: 1;
        min-width: 200px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: 500;
    }

    .form-control {
        width: 100%;
        padding: 8px 12px;
        border: 1px solid #ced4da;
        border-radius: 4px;
        font-size: 14px;
    }

    .form-control:focus {
        border-color: #80bdff;
        outline: 0;
        box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
    }

    .form-actions {
        margin-top: 20px;
        display: flex;
        gap: 10px;
    }

    .form-tip {
        font-size: 12px;
        color: #6c757d;
        margin-top: 5px;
    }

    .price-input {
        position: relative;
    }

    .price-symbol {
        position: absolute;
        left: 10px;
        top: 8px;
        color: #6c757d;
    }

    .price-input .form-control {
        padding-left: 25px;
    }
</style>

<script>
    // 初始化页面时检查物流方式是否为第三方
    document.addEventListener('DOMContentLoaded', function() {
        toggleCompanyField();
    });

    // 根据物流方式显示或隐藏第三方字段
    function toggleCompanyField() {
        var methodSelect = document.getElementById('method_id');
        var selectedOption = methodSelect.options[methodSelect.selectedIndex];
        var thirdPartyFields = document.getElementById('third-party-fields');

        if (selectedOption && selectedOption.getAttribute('data-third-party') === '1') {
            thirdPartyFields.style.display = 'block';
        } else {
            thirdPartyFields.style.display = 'none';
        }
    }
</script>