<?php
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    die('禁止直接访问此文件');
}

/**
 * 获取物流状态中文名称
 * @param string $status 状态码
 * @return string 中文名称
 */
function getLogisticsStatusName($status)
{
    $statusMap = [
        'pending' => '待处理',
        'processing' => '处理中',
        'shipping' => '配送中',
        'delivered' => '已送达',
        'cancelled' => '已取消',
        'exception' => '异常'
    ];
    return isset($statusMap[$status]) ? $statusMap[$status] : $status;
}

/**
 * 获取物流状态样式
 * @param string $status 状态码
 * @return string 样式类名
 */
function getLogisticsStatusBadgeClass($status)
{
    $classMap = [
        'pending' => 'warning',
        'processing' => 'info',
        'shipping' => 'primary',
        'delivered' => 'success',
        'cancelled' => 'danger',
        'exception' => 'error'
    ];
    return isset($classMap[$status]) ? $classMap[$status] : 'secondary';
}

// 获取所有物流单号用于下拉选择
$logisticsNumbersSql = "SELECT logistics_id, logistics_number, tracking_number FROM logistics_orders ORDER BY created_at DESC LIMIT 100";
$logisticsNumbersResult = $conn->query($logisticsNumbersSql);
$logisticsNumbers = [];
if ($logisticsNumbersResult && $logisticsNumbersResult->num_rows > 0) {
    while ($row = $logisticsNumbersResult->fetch_assoc()) {
        $logisticsNumbers[] = $row;
    }
}

// 获取搜索参数
$tracking_number = isset($_GET['tracking_number']) ? trim($_GET['tracking_number']) : '';
$logistics_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

// 物流信息
$logistics = null;
$trackingRecords = [];

// 消息提示
$message = '';
$messageType = '';

// 如果有物流单号或ID，查询物流信息
if (!empty($tracking_number) || $logistics_id > 0) {
    $sql = "SELECT lo.*, 
           c.customer_name, 
           lm.method_name, 
           lc.company_name,
           u.full_name as created_by_name,
           sd.delivery_number
           FROM logistics_orders lo
           LEFT JOIN customers c ON lo.customer_id = c.customer_id
           LEFT JOIN logistics_methods lm ON lo.method_id = lm.method_id
           LEFT JOIN logistics_companies lc ON lo.company_id = lc.company_id
           LEFT JOIN users u ON lo.created_by = u.user_id
           LEFT JOIN sales_deliveries sd ON lo.delivery_id = sd.delivery_id
           WHERE 1=1";

    $params = [];
    $types = "";

    if (!empty($tracking_number)) {
        $sql .= " AND (lo.logistics_number = ? OR lo.tracking_number = ?)";
        $params[] = $tracking_number;
        $params[] = $tracking_number;
        $types .= "ss";
    } elseif ($logistics_id > 0) {
        $sql .= " AND lo.logistics_id = ?";
        $params[] = $logistics_id;
        $types .= "i";
    }

    $stmt = $conn->prepare($sql);

    if (!empty($params)) {
        $stmt->bind_param($types, ...$params);
    }

    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $logistics = $result->fetch_assoc();
        $logistics_id = $logistics['logistics_id'];

        // 获取物流跟踪记录
        $trackingSql = "SELECT * FROM logistics_tracking 
                        WHERE logistics_id = ? 
                        ORDER BY tracking_time DESC";
        $trackingStmt = $conn->prepare($trackingSql);
        $trackingStmt->bind_param("i", $logistics_id);
        $trackingStmt->execute();
        $trackingResult = $trackingStmt->get_result();

        while ($trackingRow = $trackingResult->fetch_assoc()) {
            $trackingRecords[] = $trackingRow;
        }
    } else {
        $message = '未找到物流信息';
        $messageType = 'error';
    }
}
?>

<div class="module-tools">
    <div class="tool-left">
        <h3>物流跟踪</h3>
    </div>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>">
        <?php echo $message; ?>
    </div>
<?php endif; ?>

<!-- 物流跟踪搜索表单 -->
<div class="search-section">
    <form method="get" action="index.php" id="tracking-form" class="search-form">
        <input type="hidden" name="page" value="tracking">

        <div class="search-group flex-grow">
            <input type="text" name="tracking_number" id="tracking-input" class="search-input"
                placeholder="请输入物流单号或第三方物流单号"
                value="<?php echo htmlspecialchars($tracking_number); ?>"
                list="logistics-list" autocomplete="off" autofocus>
            <datalist id="logistics-list">
                <?php foreach ($logisticsNumbers as $number): ?>
                    <option value="<?php echo htmlspecialchars($number['logistics_number']); ?>">
                        <?php echo htmlspecialchars($number['logistics_number']); ?>
                        <?php if (!empty($number['tracking_number'])): ?>
                            (第三方单号: <?php echo htmlspecialchars($number['tracking_number']); ?>)
                        <?php endif; ?>
                    </option>
                <?php endforeach; ?>
            </datalist>
        </div>

        <div class="search-group">
            <button type="submit" class="btn btn-primary">查询</button>
            <a href="index.php?page=tracking" class="btn btn-secondary">重置</a>
        </div>
    </form>
</div>

<?php if ($logistics): ?>
    <!-- 物流订单基本信息 -->
    <div class="content-section">
        <div class="section-header">
            <h4>物流订单 #<?php echo htmlspecialchars($logistics['logistics_number']); ?></h4>
            <a href="index.php?page=delivery&action=view&id=<?php echo $logistics['logistics_id']; ?>" class="btn btn-primary">查看详情</a>
        </div>

        <div class="info-section">
            <div class="info-row">
                <div class="info-item">
                    <div class="info-label">物流单号</div>
                    <div class="info-value"><?php echo htmlspecialchars($logistics['logistics_number']); ?></div>
                </div>
                <div class="info-item">
                    <div class="info-label">出库单号</div>
                    <div class="info-value"><?php echo htmlspecialchars($logistics['delivery_number']); ?></div>
                </div>
                <div class="info-item">
                    <div class="info-label">物流状态</div>
                    <div class="info-value">
                        <span class="status-badge status-<?php echo getLogisticsStatusBadgeClass($logistics['logistics_status']); ?>">
                            <?php echo getLogisticsStatusName($logistics['logistics_status']); ?>
                        </span>
                    </div>
                </div>
            </div>

            <div class="info-row">
                <div class="info-item">
                    <div class="info-label">客户名称</div>
                    <div class="info-value"><?php echo htmlspecialchars($logistics['customer_name']); ?></div>
                </div>
                <div class="info-item">
                    <div class="info-label">收件人</div>
                    <div class="info-value"><?php echo htmlspecialchars($logistics['receiver_name']); ?></div>
                </div>
                <div class="info-item">
                    <div class="info-label">联系电话</div>
                    <div class="info-value"><?php echo htmlspecialchars($logistics['receiver_phone']); ?></div>
                </div>
            </div>

            <div class="info-row">
                <div class="info-item">
                    <div class="info-label">配送地址</div>
                    <div class="info-value"><?php echo htmlspecialchars($logistics['shipping_address']); ?></div>
                </div>
                <div class="info-item">
                    <div class="info-label">配送方式</div>
                    <div class="info-value"><?php echo htmlspecialchars($logistics['method_name']); ?></div>
                </div>
                <div class="info-item">
                    <div class="info-label">物流公司</div>
                    <div class="info-value"><?php echo $logistics['company_name'] ? htmlspecialchars($logistics['company_name']) : '-'; ?></div>
                </div>
            </div>

            <?php if (!empty($logistics['tracking_number'])): ?>
                <div class="info-row">
                    <div class="info-item">
                        <div class="info-label">物流单号(第三方)</div>
                        <div class="info-value"><?php echo htmlspecialchars($logistics['tracking_number']); ?></div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">创建时间</div>
                        <div class="info-value"><?php echo date('Y-m-d H:i', strtotime($logistics['created_at'])); ?></div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">预计送达</div>
                        <div class="info-value">
                            <?php if ($logistics['estimated_delivery_time']): ?>
                                <?php echo date('Y-m-d', strtotime($logistics['estimated_delivery_time'])); ?>
                            <?php else: ?>
                                -
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <!-- 物流跟踪记录 -->
    <div class="content-section">
        <div class="section-header">
            <h4>物流跟踪记录</h4>
        </div>

        <?php if (empty($trackingRecords)): ?>
            <div class="alert alert-info">暂无物流跟踪记录</div>
        <?php else: ?>
            <div class="tracking-timeline">
                <?php foreach ($trackingRecords as $record): ?>
                    <div class="tracking-item <?php echo $record['is_exception'] ? 'tracking-exception' : ''; ?>">
                        <div class="tracking-time">
                            <?php echo date('Y-m-d H:i', strtotime($record['tracking_time'])); ?>
                        </div>

                        <div class="tracking-content">
                            <div class="tracking-status">
                                <span class="status-badge status-<?php echo getLogisticsStatusBadgeClass($record['tracking_status']); ?>">
                                    <?php echo getLogisticsStatusName($record['tracking_status']); ?>
                                </span>
                                <?php if ($record['is_exception']): ?>
                                    <span class="status-badge status-error">异常</span>
                                <?php endif; ?>
                            </div>

                            <div class="tracking-description">
                                <?php echo nl2br(htmlspecialchars($record['tracking_description'])); ?>
                            </div>

                            <?php if (!empty($record['tracking_location'])): ?>
                                <div class="tracking-location">
                                    位置: <?php echo htmlspecialchars($record['tracking_location']); ?>
                                </div>
                            <?php endif; ?>

                            <div class="tracking-operator">
                                操作人: <?php echo htmlspecialchars($record['operator']); ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>
    </div>
<?php elseif (!empty($tracking_number)): ?>
    <div class="content-section">
        <div class="alert alert-warning">
            <i class="fa fa-exclamation-triangle"></i>
            未找到单号为 "<?php echo htmlspecialchars($tracking_number); ?>" 的物流订单，请检查输入是否正确。
        </div>
    </div>
<?php else: ?>
    <div class="content-section">
        <div class="tracking-welcome">
            <div class="tracking-icon">
                <i class="fa fa-truck"></i>
            </div>
            <h4>请输入物流单号查询配送状态</h4>
            <p>您可以输入我司物流单号或第三方物流单号进行查询</p>
        </div>
    </div>
<?php endif; ?>

<style>
    /* 搜索区样式 */
    .search-section {
        margin-bottom: 20px;
        padding: 15px;
        background-color: #f8f9fa;
        border-radius: 5px;
        border: 1px solid #e9ecef;
    }

    .search-form {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        align-items: flex-start;
    }

    .search-group {
        margin-bottom: 10px;
    }

    .flex-grow {
        flex-grow: 1;
    }

    .search-input {
        padding: 10px 15px;
        width: 100%;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 4px;
        font-size: 16px;
        margin-bottom: 0px;
    }

    .form-tip {
        margin: 5px 0;
        color: #6c757d;
        font-size: 14px;
    }

    /* 内容区样式 */
    .content-section {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        padding: 20px;
    }

    .section-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 15px;
        padding-bottom: 10px;
        border-bottom: 1px solid #e9ecef;
    }

    .section-header h4 {
        margin: 0;
        color: #0066cc;
    }

    .info-section {
        display: flex;
        flex-direction: column;
        gap: 15px;
    }

    .info-row {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
    }

    .info-item {
        flex: 1;
        min-width: 200px;
    }

    .info-label {
        color: #6c757d;
        font-size: 0.9rem;
        margin-bottom: 5px;
    }

    .info-value {
        font-weight: 500;
    }

    /* 物流跟踪时间线样式 */
    .tracking-timeline {
        position: relative;
        margin: 20px 0;
        padding-left: 30px;
    }

    .tracking-timeline:before {
        content: "";
        position: absolute;
        top: 0;
        bottom: 0;
        left: 10px;
        width: 2px;
        background-color: #e9ecef;
    }

    .tracking-item {
        position: relative;
        margin-bottom: 20px;
        padding-bottom: 20px;
        border-bottom: 1px dashed #e9ecef;
    }

    .tracking-item:last-child {
        margin-bottom: 0;
        border-bottom: none;
    }

    .tracking-item:before {
        content: "";
        position: absolute;
        left: -22px;
        top: 0;
        width: 12px;
        height: 12px;
        border-radius: 50%;
        background-color: #0066cc;
        border: 2px solid #fff;
        box-shadow: 0 0 0 2px #0066cc;
    }

    .tracking-exception:before {
        background-color: #dc3545;
        box-shadow: 0 0 0 2px #dc3545;
    }

    .tracking-time {
        font-size: 0.9rem;
        color: #6c757d;
        margin-bottom: 5px;
    }

    .tracking-content {
        background-color: #f8f9fa;
        padding: 15px;
        border-radius: 5px;
    }

    .tracking-status {
        margin-bottom: 10px;
    }

    .tracking-description {
        margin-bottom: 10px;
        line-height: 1.5;
    }

    .tracking-location,
    .tracking-operator {
        font-size: 0.85rem;
        color: #6c757d;
    }

    .tracking-location {
        margin-bottom: 5px;
    }

    /* 欢迎页样式 */
    .tracking-welcome {
        text-align: center;
        padding: 50px 20px;
    }

    .tracking-icon {
        font-size: 4rem;
        color: #0066cc;
        margin-bottom: 20px;
    }

    .tracking-welcome h4 {
        margin-bottom: 15px;
        color: #343a40;
    }

    .tracking-welcome p {
        color: #6c757d;
        max-width: 500px;
        margin: 0 auto;
    }

    /* 按钮样式 */
    .btn {
        display: inline-block;
        text-decoration: none;
        text-align: center;
        white-space: nowrap;
        cursor: pointer;
        user-select: none;
        padding: 8px 16px;
        font-size: 14px;
        line-height: 1.5;
        border-radius: 4px;
        border: 1px solid transparent;
        transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out;
    }

    .btn-primary {
        color: #fff;
        background-color: #007bff;
        border-color: #007bff;
    }

    .btn-primary:hover {
        color: #fff;
        background-color: #0069d9;
        border-color: #0062cc;
        text-decoration: none;
    }

    .btn-secondary {
        color: #fff;
        background-color: #6c757d;
        border-color: #6c757d;
    }

    .btn-secondary:hover {
        color: #fff;
        background-color: #5a6268;
        border-color: #545b62;
        text-decoration: none;
    }

    /* 警告提示样式 */
    .alert {
        position: relative;
        padding: 12px 20px;
        margin-bottom: 16px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-info {
        color: #0c5460;
        background-color: #d1ecf1;
        border-color: #bee5eb;
    }

    .alert-warning {
        color: #856404;
        background-color: #fff3cd;
        border-color: #ffeeba;
    }

    .alert-error {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }

    /* 状态徽章样式 */
    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 3px;
        font-size: 0.8rem;
        font-weight: 500;
    }

    .status-warning {
        background-color: #fff3cd;
        color: #856404;
    }

    .status-info {
        background-color: #d1ecf1;
        color: #0c5460;
    }

    .status-primary {
        background-color: #cce5ff;
        color: #004085;
    }

    .status-success {
        background-color: #d4edda;
        color: #155724;
    }

    .status-danger {
        background-color: #f8d7da;
        color: #721c24;
    }

    .status-error {
        background-color: #f8d7da;
        color: #721c24;
    }

    /* 响应式调整 */
    @media (max-width: 768px) {
        .info-item {
            min-width: 100%;
        }

        .search-form {
            flex-direction: column;
        }

        .search-group {
            width: 100%;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 不需要特别的JavaScript代码，datalist会自动处理下拉建议功能
    });
</script>