<?php
// 商品档案管理页面
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    define('IN_SYSTEM', true);
}

// 初始化消息变量
$message = '';
$messageType = '';

// 获取商品列表
$products = [];
$search = isset($_GET['keyword']) ? $_GET['keyword'] : '';

// 处理添加/编辑商品
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 获取表单数据
    $product_name = isset($_POST['product_name']) ? trim($_POST['product_name']) : '';
    $barcode = isset($_POST['barcode']) ? trim($_POST['barcode']) : '';
    $unit = isset($_POST['unit']) ? trim($_POST['unit']) : '';
    $unit_price = isset($_POST['unit_price']) ? (float)$_POST['unit_price'] : 0;
    $brand = isset($_POST['brand']) ? trim($_POST['brand']) : '';
    $manufacturer = isset($_POST['manufacturer']) ? trim($_POST['manufacturer']) : '';
    $sku_code = isset($_POST['sku_code']) ? trim($_POST['sku_code']) : '';

    // 上传图片处理
    $image_url = '';
    if (isset($_FILES['product_image']) && $_FILES['product_image']['error'] == 0) {
        // 确保上传目录存在
        $upload_dir = '../../' . UPLOAD_PATH;
        if (!file_exists($upload_dir)) {
            mkdir($upload_dir, 0755, true);
        }

        // 生成唯一文件名
        $file_ext = pathinfo($_FILES['product_image']['name'], PATHINFO_EXTENSION);
        $file_name = 'product_' . time() . '_' . rand(1000, 9999) . '.' . $file_ext;
        $upload_path = $upload_dir . $file_name;

        if (move_uploaded_file($_FILES['product_image']['tmp_name'], $upload_path)) {
            $image_url = UPLOAD_PATH . $file_name;
        } else {
            $message = '图片上传失败！';
            $messageType = 'error';
        }
    } else if (isset($_POST['current_image']) && !empty($_POST['current_image'])) {
        $image_url = $_POST['current_image'];
    }

    // 验证数据
    if (empty($product_name) || empty($barcode) || empty($unit) || $unit_price <= 0) {
        $message = '请填写所有必填字段！';
        $messageType = 'error';
    } else {
        // 添加新商品
        if ($_POST['action'] == 'add') {
            // 检查条码是否已存在
            $checkResult = recordExists($conn, 'products', ['barcode' => $barcode]);
            if ($checkResult) {
                $message = '该条码已存在，请使用其他条码！';
                $messageType = 'error';
            } else {
                // 准备插入数据
                $insertData = [
                    'product_name' => $product_name,
                    'barcode' => $barcode,
                    'unit' => $unit,
                    'unit_price' => $unit_price,
                    'brand' => $brand,
                    'manufacturer' => $manufacturer,
                    'sku_code' => $sku_code,
                    'image_url' => $image_url
                ];

                $result = insertRecord($conn, 'products', $insertData);

                if ($result['success']) {
                    $message = "商品 {$product_name} 添加成功！";
                    $messageType = 'success';

                    // 记录操作日志
                    $operationDetails = "用户 {$_SESSION['username']} 添加了商品: {$product_name}";
                    log_operation($_SESSION['user_id'], '添加商品', $operationDetails);

                    // 重定向到商品列表
                    header("Location: index.php?page=goods&message=" . urlencode($message) . "&type=" . urlencode($messageType));
                    exit;
                } else {
                    $message = "添加商品失败: " . $result['message'];
                    $messageType = 'error';
                }
            }
        }
        // 更新商品
        elseif ($_POST['action'] == 'edit' && isset($_POST['product_id'])) {
            $product_id = (int)$_POST['product_id'];

            // 检查条码是否已被其他商品使用
            $sql = "SELECT product_id FROM products WHERE barcode = ? AND product_id != ?";
            $checkResult = executeQuery($conn, $sql, 'si', [$barcode, $product_id]);

            if ($checkResult['success'] && count($checkResult['data']) > 0) {
                $message = '该条码已被其他商品使用，请使用其他条码！';
                $messageType = 'error';
            } else {
                // 准备更新数据
                $updateData = [
                    'product_name' => $product_name,
                    'barcode' => $barcode,
                    'unit' => $unit,
                    'unit_price' => $unit_price,
                    'brand' => $brand,
                    'manufacturer' => $manufacturer,
                    'sku_code' => $sku_code
                ];

                // 只有当有新图片或原有图片存在时才更新图片字段
                if (!empty($image_url)) {
                    $updateData['image_url'] = $image_url;
                }

                $result = updateRecord($conn, 'products', $updateData, $product_id, 'product_id');

                if ($result['success']) {
                    $message = "商品 {$product_name} 更新成功！";
                    $messageType = 'success';

                    // 记录操作日志
                    $operationDetails = "用户 {$_SESSION['username']} 更新了商品: {$product_name}";
                    log_operation($_SESSION['user_id'], '更新商品', $operationDetails);

                    // 重定向到商品列表
                    header("Location: index.php?page=goods&message=" . urlencode($message) . "&type=" . urlencode($messageType));
                    exit;
                } else {
                    $message = "更新商品失败: " . $result['message'];
                    $messageType = 'error';
                }
            }
        }
    }
}

// 处理删除商品
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $product_id = (int)$_GET['id'];

    // 检查商品是否有关联的批次记录
    $batchResult = recordExists($conn, 'product_batches', ['product_id' => $product_id]);

    if ($batchResult) {
        $message = "无法删除商品：该商品已有关联的批次记录！";
        $messageType = 'error';
    } else {
        // 获取商品信息用于日志记录
        $product = getRecordById($conn, 'products', $product_id, 'product_id');

        if ($product) {
            $result = deleteRecord($conn, 'products', $product_id, 'product_id');

            if ($result['success']) {
                $message = "商品 {$product['product_name']} 删除成功！";
                $messageType = 'success';

                // 记录操作日志
                $operationDetails = "用户 {$_SESSION['username']} 删除了商品: {$product['product_name']}";
                log_operation($_SESSION['user_id'], '删除商品', $operationDetails);
            } else {
                $message = "删除商品失败: " . $result['message'];
                $messageType = 'error';
            }
        } else {
            $message = "找不到指定的商品！";
            $messageType = 'error';
        }
    }

    // 重定向到商品列表
    header("Location: index.php?page=goods&message=" . urlencode($message) . "&type=" . urlencode($messageType));
    exit;
}

// 获取要编辑的商品信息
$editProduct = null;
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $product_id = (int)$_GET['id'];
    $editProduct = getRecordById($conn, 'products', $product_id, 'product_id');

    if (!$editProduct) {
        $message = "找不到指定的商品！";
        $messageType = 'error';
    }
}

// 获取要查看的商品详情
$viewProduct = null;
if (isset($_GET['action']) && $_GET['action'] == 'view' && isset($_GET['id'])) {
    $product_id = (int)$_GET['id'];
    $viewProduct = getRecordById($conn, 'products', $product_id, 'product_id');

    if (!$viewProduct) {
        $message = "找不到指定的商品！";
        $messageType = 'error';
    }
}

// 获取商品列表
try {
    // 分页参数
    $page = isset($_GET['page_num']) ? max(1, intval($_GET['page_num'])) : 1;
    $limit = 20;
    $offset = ($page - 1) * $limit;

    // 处理搜索
    if (!empty($search)) {
        $searchTerm = "%{$search}%";
        // 使用SQL直接搜索
        $sql = "SELECT * FROM products WHERE product_name LIKE ? OR barcode LIKE ? OR brand LIKE ? ORDER BY product_id DESC";
        $result = executeQuery($conn, $sql, 'sss', [$searchTerm, $searchTerm, $searchTerm]);

        if ($result['success']) {
            $products = $result['data'];

            // 计算总数
            $total = count($products);

            // 分页处理
            $products = array_slice($products, $offset, $limit);
        } else {
            $message = "获取商品列表失败: " . $result['message'];
            $messageType = 'error';
        }
    } else {
        // 获取总记录数
        $countSql = "SELECT COUNT(*) as total FROM products";
        $countResult = executeQuery($conn, $countSql);

        if ($countResult['success']) {
            $total = $countResult['data'][0]['total'];
        } else {
            $message = "获取商品总数失败: " . $countResult['message'];
            $messageType = 'error';
            $total = 0;
        }

        // 获取分页数据
        $sql = "SELECT * FROM products ORDER BY product_id DESC LIMIT ? OFFSET ?";
        $result = executeQuery($conn, $sql, 'ii', [$limit, $offset]);

        if ($result['success']) {
            $products = $result['data'];
        } else {
            $message = "获取商品列表失败: " . $result['message'];
            $messageType = 'error';
        }
    }

    // 计算总页数
    $totalPages = ceil($total / $limit);
} catch (Exception $e) {
    $message = "获取商品列表失败: " . $e->getMessage();
    $messageType = 'error';
}

// 处理从URL传来的消息
if (isset($_GET['message']) && isset($_GET['type'])) {
    $message = $_GET['message'];
    $messageType = $_GET['type'];
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <style>
        /* 商品图片容器 */
        .goods-image-container {
            width: 200px;
            height: 200px;
            border: 1px solid #ddd;
            border-radius: 4px;
            padding: 5px;
            margin-bottom: 15px;
            background: #fff;
        }

        /* 当前图片显示 */
        .goods-current-image {
            width: 100%;
            height: 100%;
            object-fit: contain;
            display: block;
        }

        /* 商品表单容器 */
        .goods-form-container {
            max-width: 800px;
            margin: 20px auto;
            padding: 20px;
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }

        /* 商品详情容器 */
        .goods-detail-container {
            max-width: 1000px;
            margin: 20px auto;
            padding: 20px;
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }

        /* 商品详情内容 */
        .goods-detail-content {
            display: grid;
            grid-template-columns: 300px 1fr;
            gap: 30px;
            margin-top: 20px;
        }

        /* 商品信息组 */
        .goods-info-group {
            margin-bottom: 15px;
            padding: 10px 0;
            border-bottom: 1px solid #eee;
        }

        .goods-info-group label {
            display: inline-block;
            width: 100px;
            font-weight: bold;
            color: #666;
        }

        .goods-info-group span {
            color: #333;
        }

        /* 工具栏样式 */
        .module-tools {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
            padding: 10px;
            background: #fff;
            border-radius: 4px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

        /* 搜索框容器 */
        .goods-search-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }

        /* 搜索输入框 */
        .goods-search-input {
            min-width: 300px;
            padding: 8px 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 14px;
            transition: border-color 0.3s;
        }

        .goods-search-input:focus {
            border-color: #4a90e2;
            outline: none;
            box-shadow: 0 0 0 2px rgba(74, 144, 226, 0.1);
        }

        /* 搜索按钮组 */
        .goods-search-buttons {
            display: flex;
            gap: 10px;
        }

        /* 响应式布局 */
        @media (max-width: 768px) {
            .goods-detail-content {
                grid-template-columns: 1fr;
            }

            .goods-image-container {
                width: 100%;
                max-width: 300px;
                margin: 0 auto 20px;
            }

            .module-tools {
                flex-direction: column;
                gap: 15px;
            }

            .goods-search-container {
                width: 100%;
            }

            .goods-search-input {
                min-width: auto;
                flex: 1;
            }
        }
    </style>
</head>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>">
        <?php echo $message; ?>
    </div>
<?php endif; ?>

<!-- 添加或编辑商品表单 -->
<?php if (isset($_GET['action']) && ($_GET['action'] == 'add' || ($_GET['action'] == 'edit' && $editProduct))): ?>
    <div class="goods-form-container">
        <h3><?php echo $_GET['action'] == 'add' ? '添加商品' : '编辑商品'; ?></h3>
        <form action="" method="post" enctype="multipart/form-data">
            <input type="hidden" name="action" value="<?php echo $_GET['action']; ?>">
            <?php if ($_GET['action'] == 'edit'): ?>
                <input type="hidden" name="product_id" value="<?php echo $editProduct['product_id']; ?>">
                <?php if (!empty($editProduct['image_url'])): ?>
                    <input type="hidden" name="current_image" value="<?php echo $editProduct['image_url']; ?>">
                <?php endif; ?>
            <?php endif; ?>

            <div class="form-group">
                <label for="product_name">商品名称 <span class="required">*</span></label>
                <input type="text" id="product_name" name="product_name" value="<?php echo $editProduct ? $editProduct['product_name'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="barcode">条码 <span class="required">*</span></label>
                <input type="text" id="barcode" name="barcode" value="<?php echo $editProduct ? $editProduct['barcode'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="unit">单位 <span class="required">*</span></label>
                <input type="text" id="unit" name="unit" value="<?php echo $editProduct ? $editProduct['unit'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="unit_price">单价 <span class="required">*</span></label>
                <input type="number" id="unit_price" name="unit_price" step="0.01" min="0.01" value="<?php echo $editProduct ? $editProduct['unit_price'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="brand">品牌</label>
                <input type="text" id="brand" name="brand" value="<?php echo $editProduct ? $editProduct['brand'] : ''; ?>">
            </div>

            <div class="form-group">
                <label for="manufacturer">生产商</label>
                <input type="text" id="manufacturer" name="manufacturer" value="<?php echo $editProduct ? $editProduct['manufacturer'] : ''; ?>">
            </div>

            <div class="form-group">
                <label for="sku_code">SKU编码</label>
                <input type="text" id="sku_code" name="sku_code" value="<?php echo $editProduct ? $editProduct['sku_code'] : ''; ?>">
            </div>

            <div class="form-group">
                <label for="product_image">商品图片</label>
                <?php if ($editProduct && !empty($editProduct['image_url'])): ?>
                    <div class="goods-image-container">
                        <img src="../../<?php echo $editProduct['image_url']; ?>" alt="当前图片" class="goods-current-image">
                        <p>当前图片</p>
                    </div>
                <?php endif; ?>
                <input type="file" id="product_image" name="product_image" accept="image/*">
                <small>支持JPG、PNG、GIF格式，文件大小不超过2MB</small>
            </div>

            <div class="form-group">
                <button type="submit" class="btn btn-primary">保存</button>
                <a href="index.php?page=goods" class="btn btn-secondary">取消</a>
            </div>
        </form>
    </div>
    <!-- 查看商品详情 -->
<?php elseif (isset($_GET['action']) && $_GET['action'] == 'view' && $viewProduct): ?>
    <div class="goods-detail-container">
        <h3>商品详情</h3>

        <div class="goods-detail-content">
            <div class="goods-image-container">
                <?php if (!empty($viewProduct['image_url'])): ?>
                    <img src="../../<?php echo $viewProduct['image_url']; ?>" alt="商品图片" class="goods-current-image">
                <?php else: ?>
                    <div class="no-image">暂无图片</div>
                <?php endif; ?>
            </div>

            <div class="goods-info">
                <div class="goods-info-group">
                    <label>商品ID:</label>
                    <span><?php echo $viewProduct['product_id']; ?></span>
                </div>
                <div class="goods-info-group">
                    <label>商品名称:</label>
                    <span><?php echo $viewProduct['product_name']; ?></span>
                </div>
                <div class="goods-info-group">
                    <label>条码:</label>
                    <span><?php echo $viewProduct['barcode']; ?></span>
                </div>
                <div class="goods-info-group">
                    <label>单位:</label>
                    <span><?php echo $viewProduct['unit']; ?></span>
                </div>
                <div class="goods-info-group">
                    <label>单价:</label>
                    <span>￥<?php echo number_format($viewProduct['unit_price'], 2); ?></span>
                </div>
                <div class="goods-info-group">
                    <label>品牌:</label>
                    <span><?php echo !empty($viewProduct['brand']) ? $viewProduct['brand'] : '无'; ?></span>
                </div>
                <div class="goods-info-group">
                    <label>生产商:</label>
                    <span><?php echo !empty($viewProduct['manufacturer']) ? $viewProduct['manufacturer'] : '无'; ?></span>
                </div>
                <div class="goods-info-group">
                    <label>SKU编码:</label>
                    <span><?php echo !empty($viewProduct['sku_code']) ? $viewProduct['sku_code'] : '无'; ?></span>
                </div>
                <div class="goods-info-group">
                    <label>创建时间:</label>
                    <span><?php echo $viewProduct['created_at']; ?></span>
                </div>
                <div class="goods-info-group">
                    <label>最后更新:</label>
                    <span><?php echo $viewProduct['updated_at']; ?></span>
                </div>
            </div>
        </div>

        <div class="detail-actions">
            <a href="index.php?page=goods" class="btn btn-secondary">返回商品列表</a>
            <a href="index.php?page=goods&action=edit&id=<?php echo $viewProduct['product_id']; ?>" class="btn btn-primary">编辑商品</a>
            <a href="index.php?page=batch&product_id=<?php echo $viewProduct['product_id']; ?>" class="btn btn-success btn-sm">查看批次</a>
        </div>
    </div>
    <!-- 商品列表 -->
<?php else: ?>
    <div class="module-tools">
        <div class="tool-left">
            <a href="index.php?page=goods&action=add" class="btn btn-primary">添加商品</a>
        </div>
        <div class="tool-right">
            <form action="index.php" method="get" class="goods-search-container">
                <input type="hidden" name="page" value="goods">
                <input type="text" name="keyword" placeholder="商品名称/条码/品牌" class="goods-search-input" value="<?php echo htmlspecialchars($search); ?>">
                <div class="goods-search-buttons">
                    <button type="submit" class="btn btn-primary">搜索</button>
                    <?php if (!empty($search)): ?>
                        <a href="index.php?page=goods" class="btn btn-secondary">清除</a>
                    <?php endif; ?>
                </div>
            </form>
        </div>
    </div>

    <div class="data-wrapper">
        <table class="data-table">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>商品名称</th>
                    <th>条码</th>
                    <th>单位</th>
                    <th>单价</th>
                    <th>品牌</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($products) > 0): ?>
                    <?php foreach ($products as $product): ?>
                        <tr>
                            <td><?php echo $product['product_id']; ?></td>
                            <td><?php echo $product['product_name']; ?></td>
                            <td><?php echo $product['barcode']; ?></td>
                            <td><?php echo $product['unit']; ?></td>
                            <td>￥<?php echo number_format($product['unit_price'], 2); ?></td>
                            <td><?php echo !empty($product['brand']) ? $product['brand'] : '无'; ?></td>
                            <td class="actions">
                                <a href="index.php?page=goods&action=view&id=<?php echo $product['product_id']; ?>" class="btn btn-secondary btn-sm">查看</a>
                                <a href="index.php?page=goods&action=edit&id=<?php echo $product['product_id']; ?>" class="btn btn-primary btn-sm">编辑</a>
                                <a href="index.php?page=goods&action=delete&id=<?php echo $product['product_id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除此商品吗？')">删除</a>
                                <a href="index.php?page=batch&product_id=<?php echo $product['product_id']; ?>" class="btn btn-success btn-sm">批次</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="7" class="text-center">暂无商品数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>

        <?php if ($totalPages > 1): ?>
            <div class="pagination">
                <?php if ($page > 1): ?>
                    <a href="index.php?page=goods&page_num=1<?php echo !empty($search) ? '&keyword=' . urlencode($search) : ''; ?>" class="btn btn-secondary btn-sm">首页</a>
                    <a href="index.php?page=goods&page_num=<?php echo $page - 1; ?><?php echo !empty($search) ? '&keyword=' . urlencode($search) : ''; ?>" class="btn btn-secondary btn-sm">上一页</a>
                <?php endif; ?>

                <?php
                // 显示页码
                $startPage = max(1, $page - 2);
                $endPage = min($totalPages, $page + 2);

                for ($i = $startPage; $i <= $endPage; $i++):
                ?>
                    <a href="index.php?page=goods&page_num=<?php echo $i; ?><?php echo !empty($search) ? '&keyword=' . urlencode($search) : ''; ?>"
                        class="btn btn-sm <?php echo $i == $page ? 'btn-primary' : 'btn-secondary'; ?>">
                        <?php echo $i; ?>
                    </a>
                <?php endfor; ?>

                <?php if ($page < $totalPages): ?>
                    <a href="index.php?page=goods&page_num=<?php echo $page + 1; ?><?php echo !empty($search) ? '&keyword=' . urlencode($search) : ''; ?>" class="btn btn-secondary btn-sm">下一页</a>
                    <a href="index.php?page=goods&page_num=<?php echo $totalPages; ?><?php echo !empty($search) ? '&keyword=' . urlencode($search) : ''; ?>" class="btn btn-secondary btn-sm">末页</a>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>
<?php endif; ?>