<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 获取会员ID
$member_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($member_id <= 0) {
    echo '<div class="alert alert-error">无效的会员ID</div>';
    echo '<div class="form-actions"><a href="index.php?page=member" class="btn btn-primary">返回会员列表</a></div>';
    exit;
}

// 获取会员详细信息
$sql = "SELECT m.*, c.customer_name, c.contact_person, c.phone, c.email, c.address, c.customer_type, 
               ml.level_name, ml.discount_rate, ml.min_points, ml.description AS level_description
        FROM members m 
        INNER JOIN customers c ON m.customer_id = c.customer_id 
        INNER JOIN member_levels ml ON m.level_id = ml.level_id 
        WHERE m.member_id = ?";
$stmt = $conn->prepare($sql);
if (!$stmt) {
    echo '<div class="alert alert-error">查询准备失败: ' . $conn->error . '</div>';
    echo '<div class="form-actions"><a href="index.php?page=member" class="btn btn-primary">返回会员列表</a></div>';
    exit;
}

$stmt->bind_param("i", $member_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    echo '<div class="alert alert-error">未找到会员记录</div>';
    echo '<div class="form-actions"><a href="index.php?page=member" class="btn btn-primary">返回会员列表</a></div>';
    exit;
}

$member = $result->fetch_assoc();
$stmt->close();

// 获取客户类型中文名称
if (!function_exists('getCustomerTypeName')) {
    function getCustomerTypeName($type)
    {
        switch ($type) {
            case 'retail':
                return '零售客户';
            case 'wholesale':
                return '批发客户';
            default:
                return '未知';
        }
    }
}

// 获取会员状态中文名称
if (!function_exists('getMemberStatusName')) {
    function getMemberStatusName($status)
    {
        switch ($status) {
            case 'active':
                return '激活';
            case 'inactive':
                return '停用';
            default:
                return '未知';
        }
    }
}

// 使用在member.php中已经定义的getMemberStatusName函数
// 确保getStatusClass函数已定义
if (!function_exists('getStatusClass')) {
    function getStatusClass($status)
    {
        return $status == 'active' ? 'success' : 'secondary';
    }
}
?>

<div class="page-header">
    <h3>会员详情</h3>
</div>

<div class="view-wrapper">
    <div class="view-section">
        <h4>会员基本信息</h4>
        <div class="view-row">
            <div class="view-item">
                <label>会员ID</label>
                <div class="view-value"><?php echo $member['member_id']; ?></div>
            </div>
            <div class="view-item">
                <label>会员卡号</label>
                <div class="view-value"><?php echo htmlspecialchars($member['member_no']); ?></div>
            </div>
            <div class="view-item">
                <label>会员等级</label>
                <div class="view-value"><?php echo htmlspecialchars($member['level_name']); ?></div>
            </div>
        </div>
        <div class="view-row">
            <div class="view-item">
                <label>当前积分</label>
                <div class="view-value"><?php echo number_format($member['points']); ?></div>
            </div>
            <div class="view-item">
                <label>累计消费金额</label>
                <div class="view-value"><?php echo number_format($member['total_amount'], 2); ?> 元</div>
            </div>
            <div class="view-item">
                <label>会员状态</label>
                <div class="view-value">
                    <span class="badge badge-<?php echo getStatusClass($member['status']); ?>">
                        <?php echo getMemberStatusName($member['status']); ?>
                    </span>
                </div>
            </div>
        </div>
        <div class="view-row">
            <div class="view-item">
                <label>入会日期</label>
                <div class="view-value"><?php echo $member['join_date']; ?></div>
            </div>
            <div class="view-item">
                <label>创建时间</label>
                <div class="view-value"><?php echo $member['created_at']; ?></div>
            </div>
            <div class="view-item">
                <label>上次更新</label>
                <div class="view-value"><?php echo $member['updated_at']; ?></div>
            </div>
        </div>
    </div>

    <div class="view-section">
        <h4>等级信息</h4>
        <div class="view-row">
            <div class="view-item">
                <label>等级名称</label>
                <div class="view-value"><?php echo htmlspecialchars($member['level_name']); ?></div>
            </div>
            <div class="view-item">
                <label>折扣率</label>
                <div class="view-value"><?php echo number_format($member['discount_rate'] * 100, 0); ?>%</div>
            </div>
            <div class="view-item">
                <label>最低积分要求</label>
                <div class="view-value"><?php echo number_format($member['min_points']); ?></div>
            </div>
        </div>
        <div class="view-row full-width">
            <div class="view-item">
                <label>等级描述</label>
                <div class="view-value"><?php echo htmlspecialchars($member['level_description'] ?: '无'); ?></div>
            </div>
        </div>
    </div>

    <div class="view-section">
        <h4>客户信息</h4>
        <div class="view-row">
            <div class="view-item">
                <label>客户ID</label>
                <div class="view-value"><?php echo $member['customer_id']; ?></div>
            </div>
            <div class="view-item">
                <label>客户名称</label>
                <div class="view-value"><?php echo htmlspecialchars($member['customer_name']); ?></div>
            </div>
            <div class="view-item">
                <label>客户类型</label>
                <div class="view-value"><?php echo getCustomerTypeName($member['customer_type']); ?></div>
            </div>
        </div>
        <div class="view-row">
            <div class="view-item">
                <label>联系人</label>
                <div class="view-value"><?php echo htmlspecialchars($member['contact_person'] ?: '无'); ?></div>
            </div>
            <div class="view-item">
                <label>联系电话</label>
                <div class="view-value"><?php echo htmlspecialchars($member['phone'] ?: '无'); ?></div>
            </div>
            <div class="view-item">
                <label>电子邮箱</label>
                <div class="view-value"><?php echo htmlspecialchars($member['email'] ?: '无'); ?></div>
            </div>
        </div>
        <div class="view-row full-width">
            <div class="view-item">
                <label>地址</label>
                <div class="view-value"><?php echo htmlspecialchars($member['address'] ?: '无'); ?></div>
            </div>
        </div>
    </div>

    <?php if (!empty($member['remark'])): ?>
        <div class="view-section">
            <h4>备注</h4>
            <div class="view-row full-width">
                <div class="view-item">
                    <div class="view-value"><?php echo nl2br(htmlspecialchars($member['remark'])); ?></div>
                </div>
            </div>
        </div>
    <?php endif; ?>

    <div class="view-actions">
        <a href="index.php?page=member" class="btn btn-secondary">返回会员列表</a>
        <a href="index.php?page=member&action=edit&id=<?php echo $member_id; ?>" class="btn btn-primary">编辑会员</a>
    </div>
</div>

<style>
    .view-wrapper {
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .view-section {
        margin-bottom: 25px;
        padding-bottom: 15px;
        border-bottom: 1px solid #e9ecef;
    }

    .view-section:last-child {
        border-bottom: none;
        padding-bottom: 0;
    }

    .view-section h4 {
        margin-top: 0;
        margin-bottom: 15px;
        color: #495057;
        font-size: 18px;
    }

    .view-row {
        display: flex;
        flex-wrap: wrap;
        margin-bottom: 15px;
    }

    .view-row:last-child {
        margin-bottom: 0;
    }

    .view-item {
        flex: 0 0 33.333333%;
        max-width: 33.333333%;
        padding-right: 15px;
        box-sizing: border-box;
        margin-bottom: 10px;
    }

    .view-row.full-width .view-item {
        flex: 0 0 100%;
        max-width: 100%;
    }

    .view-item label {
        display: block;
        font-weight: bold;
        margin-bottom: 5px;
        color: #6c757d;
        font-size: 14px;
    }

    .view-value {
        color: #212529;
        word-break: break-word;
    }

    .view-actions {
        margin-top: 20px;
        display: flex;
        gap: 10px;
    }

    .badge {
        display: inline-block;
        padding: 3px 8px;
        font-size: 12px;
        font-weight: 600;
        border-radius: 3px;
        color: white;
    }

    .badge-success {
        background-color: #28a745;
    }

    .badge-secondary {
        background-color: #6c757d;
    }

    @media (max-width: 767.98px) {
        .view-item {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>