<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';

// 检查会话中是否有消息
if (isset($_SESSION['message']) && !empty($_SESSION['message'])) {
    $message = $_SESSION['message'];
    $messageType = isset($_SESSION['message_type']) ? $_SESSION['message_type'] : 'info';

    // 清除会话消息，防止刷新页面后重复显示
    unset($_SESSION['message']);
    unset($_SESSION['message_type']);
}

// 子页面处理
$action = isset($_GET['action']) ? $_GET['action'] : '';

// 如果是子页面，直接包含对应文件并退出
if ($action && file_exists("points_{$action}.php")) {
    include_once "points_{$action}.php";
    exit;
}

// 删除积分商品
if (isset($_GET['delete']) && is_numeric($_GET['delete'])) {
    $product_id = intval($_GET['delete']);

    // 检查该商品是否已被兑换
    $checkSql = "SELECT COUNT(*) as count FROM point_redemptions WHERE product_id = ? AND status != 'cancelled'";
    $checkResult = executeQuery($conn, $checkSql, 'i', [$product_id]);

    if ($checkResult['success'] && $checkResult['data'][0]['count'] > 0) {
        $message = '该积分商品已被兑换，无法删除！';
        $messageType = 'error';
    } else {
        // 删除积分商品
        $deleteSql = "DELETE FROM point_products WHERE product_id = ?";
        $deleteResult = executeQuery($conn, $deleteSql, 'i', [$product_id]);

        if ($deleteResult['success']) {
            $message = '积分商品删除成功！';
            $messageType = 'success';

            // 记录操作日志
            $operationDetails = "用户 {$_SESSION['username']} 删除了积分商品ID: {$product_id}";
            log_operation($_SESSION['user_id'], '删除', $operationDetails);
        } else {
            $message = '积分商品删除失败：' . $deleteResult['error'];
            $messageType = 'error';
        }
    }
}

// 处理批量操作
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['batch_action']) && isset($_POST['selected_ids'])) {
    $action = $_POST['batch_action'];
    $ids = explode(',', $_POST['selected_ids']);
    $validIds = array_filter($ids, 'is_numeric');

    if (!empty($validIds)) {
        $idList = implode(',', $validIds);

        if ($action == 'activate' || $action == 'deactivate') {
            $status = ($action == 'activate') ? 1 : 0;
            $updateSql = "UPDATE point_products SET is_active = ? WHERE product_id IN ($idList)";
            $updateResult = executeQuery($conn, $updateSql, 'i', [$status]);

            if ($updateResult['success']) {
                $actionText = ($action == 'activate') ? '激活' : '停用';
                $message = "已成功{$actionText}所选积分商品！";
                $messageType = 'success';

                // 记录操作日志
                $operationDetails = "用户 {$_SESSION['username']} 批量{$actionText}了积分商品ID: {$idList}";
                log_operation($_SESSION['user_id'], '更新', $operationDetails);
            } else {
                $message = '批量操作失败：' . $updateResult['error'];
                $messageType = 'error';
            }
        } elseif ($action == 'delete') {
            // 检查是否有关联的兑换记录
            $checkSql = "SELECT COUNT(*) as count FROM point_redemptions WHERE product_id IN ($idList) AND status != 'cancelled'";
            $checkResult = $conn->query($checkSql);

            if ($checkResult && $row = $checkResult->fetch_assoc()) {
                if ($row['count'] > 0) {
                    $message = '选中的商品中有已被兑换的记录，无法删除！';
                    $messageType = 'error';
                } else {
                    $deleteSql = "DELETE FROM point_products WHERE product_id IN ($idList)";
                    $deleteResult = $conn->query($deleteSql);

                    if ($deleteResult) {
                        $affectedRows = $conn->affected_rows;
                        $message = "已成功删除{$affectedRows}个积分商品！";
                        $messageType = 'success';

                        // 记录操作日志
                        $operationDetails = "用户 {$_SESSION['username']} 批量删除了积分商品ID: {$idList}";
                        log_operation($_SESSION['user_id'], '删除', $operationDetails);
                    } else {
                        $message = '批量删除失败：' . $conn->error;
                        $messageType = 'error';
                    }
                }
            } else {
                $message = '批量删除检查失败：' . $conn->error;
                $messageType = 'error';
            }
        }
    } else {
        $message = '未选择有效的积分商品！';
        $messageType = 'error';
    }
}

// 获取筛选和分页参数
$page = isset($_GET['p']) ? intval($_GET['p']) : 1;
$limit = 10; // 每页显示数量
$offset = ($page - 1) * $limit;

$search = isset($_GET['search']) ? sanitize($_GET['search']) : '';
$productType = isset($_GET['product_type']) ? sanitize($_GET['product_type']) : '';
$isActive = isset($_GET['is_active']) ? (int)$_GET['is_active'] : -1; // -1表示全部

// 构建查询条件
$conditions = [];
$params = [];
$types = '';

if (!empty($search)) {
    $conditions[] = '(p.product_name LIKE ? OR p.description LIKE ?)';
    $searchParam = "%{$search}%";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= 'ss';
}

if (!empty($productType)) {
    $conditions[] = 'p.product_type = ?';
    $params[] = $productType;
    $types .= 's';
}

if ($isActive != -1) {
    $conditions[] = 'p.is_active = ?';
    $params[] = $isActive;
    $types .= 'i';
}

// 构建WHERE子句
$where = '';
if (!empty($conditions)) {
    $where = 'WHERE ' . implode(' AND ', $conditions);
}

// 获取记录总数
$countSql = "SELECT COUNT(*) as total FROM point_products p {$where}";
$countResult = executeQuery($conn, $countSql, $types, $params);
$total = $countResult['success'] ? $countResult['data'][0]['total'] : 0;

// 获取分页数据
$sql = "SELECT p.*, u.username as creator_name 
        FROM point_products p 
        LEFT JOIN users u ON p.created_by = u.user_id 
        {$where} 
        ORDER BY p.created_at DESC 
        LIMIT ?, ?";

$params[] = $offset;
$params[] = $limit;
$types .= 'ii';

$result = executeQuery($conn, $sql, $types, $params);
$products = $result['success'] ? $result['data'] : [];

// 获取商品类型中文名称
function getProductTypeName($type)
{
    switch ($type) {
        case 'physical':
            return '实物商品';
        case 'voucher':
            return '代金券';
        case 'coupon':
            return '优惠券';
        default:
            return '未知';
    }
}

// 获取状态中文名称
function getStatusName($status)
{
    return $status ? '上架中' : '已下架';
}

// 获取状态样式类
function getStatusClass($status)
{
    return $status ? 'success' : 'secondary';
}

// 生成分页HTML
$pagination = generate_pagination($total, $page, $limit, 'index.php?page=points&' . http_build_query(array_filter([
    'search' => $search,
    'product_type' => $productType,
    'is_active' => $isActive != -1 ? $isActive : null
])));

// 根据action显示相应的页面或执行相应的操作
switch ($action) {
    case 'add':
        // 添加积分产品页面
        include 'modules/promotion/points_add.php';
        break;

    case 'edit':
        // 编辑积分产品页面
        include 'modules/promotion/points_edit.php';
        break;

    case 'view':
        // 查看积分产品详情页面
        include 'modules/promotion/points_view.php';
        break;

    case 'delete':
        // 删除积分产品
        // ... existing code ...
        break;

    case 'transactions':
        // 积分交易记录页面
        include 'modules/promotion/points_transactions.php';
        break;

    case 'redemptions':
        // 积分兑换记录页面
        include 'modules/promotion/points_redemptions.php';
        break;

    case 'redemption_detail':
        // 积分兑换详情页面
        include 'modules/promotion/redemption_detail.php';
        break;

    case 'redeem':
        // 积分兑换页面
        include 'modules/promotion/points_redeem.php';
        break;

    default:
        // 默认显示积分产品列表
        // ... existing code ...

        // 查询积分产品数据
        // ... existing code ...

        // 显示积分产品列表
        // ... existing code ...
        break;
}
?>

<div class="page-header">
    <h3>积分商品管理</h3>
    <div class="page-header-actions">
        <a href="index.php?page=points&action=add" class="btn btn-primary">添加积分商品</a>
        <a href="index.php?page=points&action=redeem" class="btn btn-primary">积分兑换</a>
        <a href="index.php?page=points&action=transactions" class="btn btn-info">积分交易记录</a>
        <a href="index.php?page=points&action=redemptions" class="btn btn-info">积分兑换记录</a>
    </div>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="filter-box">
    <form method="get" action="index.php" class="filter-form">
        <input type="hidden" name="page" value="points">

        <div class="form-group">
            <input type="text" name="search" class="form-control" placeholder="商品名称" value="<?php echo htmlspecialchars($search); ?>">
        </div>

        <div class="form-group">
            <select name="product_type" class="form-control">
                <option value="">全部类型</option>
                <option value="physical" <?php echo $productType == 'physical' ? 'selected' : ''; ?>>实物商品</option>
                <option value="voucher" <?php echo $productType == 'voucher' ? 'selected' : ''; ?>>代金券</option>
                <option value="coupon" <?php echo $productType == 'coupon' ? 'selected' : ''; ?>>优惠券</option>
            </select>
        </div>

        <div class="form-group">
            <select name="is_active" class="form-control">
                <option value="-1">全部状态</option>
                <option value="1" <?php echo $isActive === 1 ? 'selected' : ''; ?>>上架中</option>
                <option value="0" <?php echo $isActive === 0 ? 'selected' : ''; ?>>已下架</option>
            </select>
        </div>

        <div class="form-group">
            <button type="submit" class="btn btn-primary">筛选</button>
            <a href="index.php?page=points" class="btn btn-secondary">重置</a>
        </div>
    </form>
</div>

<div class="batch-actions">
    <form id="batch-form" method="post" action="index.php?page=points">
        <input type="hidden" name="batch_action" id="batch_action" value="">
        <input type="hidden" name="selected_ids" id="selected_ids" value="">

        <div class="btn-group">
            <button type="button" class="btn btn-secondary" onclick="executeBatchAction('activate')">批量上架</button>
            <button type="button" class="btn btn-secondary" onclick="executeBatchAction('deactivate')">批量下架</button>
            <button type="button" class="btn btn-danger" onclick="confirmBatchDelete()">批量删除</button>
        </div>
    </form>
</div>

<div class="data-table-wrapper">
    <?php if (count($products) > 0): ?>
        <table class="data-table">
            <thead>
                <tr>
                    <th width="40"><input type="checkbox" id="select-all" onchange="toggleSelectAll()"></th>
                    <th width="60">ID</th>
                    <th>商品名称</th>
                    <th width="100">商品类型</th>
                    <th width="100">所需积分</th>
                    <th width="100">库存</th>
                    <th width="100">状态</th>
                    <th width="120">截止日期</th>
                    <th width="120">创建人</th>
                    <th width="150">操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($products as $product): ?>
                    <tr>
                        <td><input type="checkbox" class="item-checkbox" value="<?php echo $product['product_id']; ?>"></td>
                        <td><?php echo $product['product_id']; ?></td>
                        <td class="product-name"><?php echo htmlspecialchars($product['product_name']); ?></td>
                        <td><?php echo getProductTypeName($product['product_type']); ?></td>
                        <td><?php echo number_format($product['points_required']); ?></td>
                        <td><?php echo number_format($product['stock_quantity']); ?></td>
                        <td>
                            <span class="badge badge-<?php echo getStatusClass($product['is_active']); ?>">
                                <?php echo getStatusName($product['is_active']); ?>
                            </span>
                        </td>
                        <td><?php echo $product['end_date'] ?: '无限期'; ?></td>
                        <td><?php echo htmlspecialchars($product['creator_name']); ?></td>
                        <td>
                            <div class="action-buttons">
                                <a href="index.php?page=points&action=view&id=<?php echo $product['product_id']; ?>" class="btn btn-sm btn-info">查看</a>
                                <a href="index.php?page=points&action=edit&id=<?php echo $product['product_id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                <button type="button" class="btn btn-sm btn-danger" onclick="confirmDelete(<?php echo $product['product_id']; ?>, '<?php echo addslashes(htmlspecialchars($product['product_name'])); ?>')">删除</button>
                            </div>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <?php echo $pagination; ?>
    <?php else: ?>
        <div class="alert alert-info">没有找到匹配的积分商品记录</div>
    <?php endif; ?>
</div>

<style>
    .page-header {
        margin-bottom: 20px;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .page-header-actions {
        display: flex;
        gap: 10px;
    }

    .filter-box {
        background-color: #f8f9fa;
        padding: 15px;
        border-radius: 5px;
        margin-bottom: 20px;
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        align-items: flex-end;
    }

    .filter-form .form-group {
        margin-bottom: 0;
        min-width: 150px;
    }

    .batch-actions {
        margin-bottom: 20px;
    }

    .btn-group {
        display: flex;
        gap: 5px;
    }

    .data-table-wrapper {
        overflow-x: auto;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
        margin-bottom: 20px;
    }

    .data-table th,
    .data-table td {
        padding: 12px 10px;
        text-align: left;
        vertical-align: middle;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .data-table tr:hover {
        background-color: #f2f2f2;
    }

    .action-buttons {
        display: flex;
        gap: 5px;
        flex-direction: row;
        justify-content: flex-start;
        align-items: center;
        flex-wrap: nowrap;
        width: 100%;
    }

    .action-buttons .btn {
        margin-bottom: 0;
        white-space: nowrap;
        display: inline-flex;
        align-items: center;
        justify-content: center;
        padding: 4px 8px;
        font-size: 12px;
    }

    .btn-sm {
        padding: 4px 8px;
        font-size: 12px;
        line-height: 1.5;
        border-radius: 3px;
    }

    .btn-info {
        color: #fff;
        background-color: #17a2b8;
        border-color: #17a2b8;
    }

    .btn-primary {
        color: #fff;
        background-color: #007bff;
        border-color: #007bff;
    }

    .btn-danger {
        color: #fff;
        background-color: #dc3545;
        border-color: #dc3545;
    }

    .badge {
        display: inline-block;
        padding: 3px 8px;
        font-size: 12px;
        font-weight: 600;
        border-radius: 3px;
        color: white;
    }

    .badge-success {
        background-color: #28a745;
    }

    .badge-secondary {
        background-color: #6c757d;
    }

    .product-name {
        max-width: 200px;
        overflow: hidden;
        text-overflow: ellipsis;
        white-space: nowrap;
    }

    .pagination {
        display: flex;
        list-style: none;
        padding: 0;
        margin: 20px 0;
        justify-content: center;
    }

    .pagination li {
        margin: 0 2px;
    }

    .pagination li a,
    .pagination li span {
        padding: 6px 12px;
        border: 1px solid #dee2e6;
        color: #007bff;
        text-decoration: none;
        border-radius: 4px;
    }

    .pagination li.active span {
        background-color: #007bff;
        color: white;
        border-color: #007bff;
    }

    .pagination li a:hover {
        background-color: #e9ecef;
        border-color: #dee2e6;
    }

    .pagination li.disabled span {
        color: #6c757d;
        pointer-events: none;
        cursor: not-allowed;
        background-color: #fff;
    }
</style>

<script>
    // 全选/取消全选
    function toggleSelectAll() {
        const selectAll = document.getElementById('select-all');
        const checkboxes = document.getElementsByClassName('item-checkbox');

        for (let i = 0; i < checkboxes.length; i++) {
            checkboxes[i].checked = selectAll.checked;
        }
    }

    // 确认删除
    function confirmDelete(id, name) {
        if (confirm(`确定要删除积分商品"${name}"吗？`)) {
            window.location.href = `index.php?page=points&delete=${id}`;
        }
    }

    // 确认批量删除
    function confirmBatchDelete() {
        const checkboxes = document.querySelectorAll('.item-checkbox:checked');
        if (checkboxes.length === 0) {
            alert('请至少选择一个积分商品');
            return;
        }

        if (confirm(`确定要删除选中的${checkboxes.length}个积分商品吗？`)) {
            executeBatchAction('delete');
        }
    }

    // 批量操作处理函数
    function executeBatchAction(action) {
        const checkboxes = document.querySelectorAll('.item-checkbox:checked');
        if (checkboxes.length === 0) {
            alert('请至少选择一个积分商品');
            return;
        }

        const ids = Array.from(checkboxes).map(cb => cb.value);

        // 设置隐藏字段的值
        document.getElementById('batch_action').value = action;
        document.getElementById('selected_ids').value = ids.join(',');

        // 提交表单
        document.getElementById('batch-form').submit();
    }
</script>