<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 获取商品ID
$product_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($product_id <= 0) {
    echo '<div class="alert alert-error">无效的商品ID</div>';
    echo '<div class="form-actions"><a href="index.php?page=points" class="btn btn-primary">返回商品列表</a></div>';
    exit;
}

// 获取商品信息
$sql = "SELECT p.*, u.username as creator_name 
        FROM point_products p 
        LEFT JOIN users u ON p.created_by = u.user_id 
        WHERE p.product_id = ?";
$stmt = $conn->prepare($sql);
if (!$stmt) {
    echo '<div class="alert alert-error">查询准备失败: ' . $conn->error . '</div>';
    echo '<div class="form-actions"><a href="index.php?page=points" class="btn btn-primary">返回商品列表</a></div>';
    exit;
}

$stmt->bind_param("i", $product_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    echo '<div class="alert alert-error">未找到该积分商品</div>';
    echo '<div class="form-actions"><a href="index.php?page=points" class="btn btn-primary">返回商品列表</a></div>';
    exit;
}

$product = $result->fetch_assoc();
$stmt->close();

// 获取兑换记录
$redemptionSql = "SELECT r.*, m.member_no, c.customer_name 
                 FROM point_redemptions r 
                 JOIN members m ON r.member_id = m.member_id 
                 JOIN customers c ON m.customer_id = c.customer_id 
                 WHERE r.product_id = ? 
                 ORDER BY r.redemption_date DESC 
                 LIMIT 10";
$redemptionStmt = $conn->prepare($redemptionSql);
$redemptions = [];

if ($redemptionStmt) {
    $redemptionStmt->bind_param("i", $product_id);
    $redemptionStmt->execute();
    $redemptionResult = $redemptionStmt->get_result();

    while ($row = $redemptionResult->fetch_assoc()) {
        $redemptions[] = $row;
    }

    $redemptionStmt->close();
}

// 获取商品类型中文名称
if (!function_exists('getProductTypeName')) {
    function getProductTypeName($type)
    {
        switch ($type) {
            case 'physical':
                return '实物商品';
            case 'voucher':
                return '代金券';
            case 'coupon':
                return '优惠券';
            default:
                return '未知';
        }
    }
}

// 获取状态中文名称
if (!function_exists('getStatusName')) {
    function getStatusName($status)
    {
        return $status ? '上架中' : '已下架';
    }
}

// 获取状态样式类
if (!function_exists('getStatusClass')) {
    function getStatusClass($status)
    {
        return $status ? 'success' : 'secondary';
    }
}

// 获取兑换状态中文名称
if (!function_exists('getRedemptionStatusName')) {
    function getRedemptionStatusName($status)
    {
        switch ($status) {
            case 'pending':
                return '待处理';
            case 'completed':
                return '已完成';
            case 'cancelled':
                return '已取消';
            default:
                return '未知';
        }
    }
}

// 获取兑换状态样式类
if (!function_exists('getRedemptionStatusClass')) {
    function getRedemptionStatusClass($status)
    {
        switch ($status) {
            case 'pending':
                return 'warning';
            case 'completed':
                return 'success';
            case 'cancelled':
                return 'secondary';
            default:
                return 'info';
        }
    }
}
?>

<div class="page-header">
    <h3>积分商品详情</h3>
</div>

<div class="view-wrapper">
    <div class="view-section">
        <h4>基本信息</h4>
        <div class="view-row">
            <div class="view-item">
                <label>商品ID</label>
                <div class="view-value"><?php echo $product['product_id']; ?></div>
            </div>
            <div class="view-item">
                <label>商品名称</label>
                <div class="view-value"><?php echo htmlspecialchars($product['product_name']); ?></div>
            </div>
            <div class="view-item">
                <label>商品类型</label>
                <div class="view-value"><?php echo getProductTypeName($product['product_type']); ?></div>
            </div>
        </div>

        <div class="view-row">
            <div class="view-item">
                <label>所需积分</label>
                <div class="view-value"><?php echo number_format($product['points_required']); ?> 积分</div>
            </div>
            <div class="view-item">
                <label>库存数量</label>
                <div class="view-value"><?php echo number_format($product['stock_quantity']); ?></div>
            </div>
            <div class="view-item">
                <label>兑换截止日期</label>
                <div class="view-value"><?php echo $product['end_date'] ?: '无限期'; ?></div>
            </div>
        </div>

        <div class="view-row">
            <div class="view-item">
                <label>商品状态</label>
                <div class="view-value">
                    <span class="badge badge-<?php echo getStatusClass($product['is_active']); ?>">
                        <?php echo getStatusName($product['is_active']); ?>
                    </span>
                </div>
            </div>
            <div class="view-item">
                <label>创建人</label>
                <div class="view-value"><?php echo htmlspecialchars($product['creator_name']); ?></div>
            </div>
            <div class="view-item">
                <label>创建时间</label>
                <div class="view-value"><?php echo $product['created_at']; ?></div>
            </div>
        </div>

        <div class="view-row">
            <div class="view-item">
                <label>最后更新</label>
                <div class="view-value"><?php echo $product['updated_at']; ?></div>
            </div>
        </div>
    </div>

    <div class="view-section">
        <h4>商品描述</h4>
        <div class="view-row full-width">
            <div class="view-item">
                <div class="view-value description-box">
                    <?php echo !empty($product['description']) ? nl2br(htmlspecialchars($product['description'])) : '暂无商品描述'; ?>
                </div>
            </div>
        </div>
    </div>

    <div class="view-section">
        <h4>最近兑换记录</h4>
        <?php if (count($redemptions) > 0): ?>
            <table class="redemption-table">
                <thead>
                    <tr>
                        <th>兑换ID</th>
                        <th>会员</th>
                        <th>兑换数量</th>
                        <th>消耗积分</th>
                        <th>兑换日期</th>
                        <th>状态</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($redemptions as $redemption): ?>
                        <tr>
                            <td><?php echo $redemption['redemption_id']; ?></td>
                            <td>
                                <?php echo htmlspecialchars($redemption['customer_name']); ?>
                                (<?php echo htmlspecialchars($redemption['member_no']); ?>)
                            </td>
                            <td><?php echo $redemption['quantity']; ?></td>
                            <td><?php echo number_format($redemption['points_used']); ?></td>
                            <td><?php echo $redemption['redemption_date']; ?></td>
                            <td>
                                <span class="badge badge-<?php echo getRedemptionStatusClass($redemption['status']); ?>">
                                    <?php echo getRedemptionStatusName($redemption['status']); ?>
                                </span>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <div class="empty-message">暂无兑换记录</div>
        <?php endif; ?>
    </div>

    <div class="view-actions">
        <a href="index.php?page=points" class="btn btn-secondary">返回商品列表</a>
        <a href="index.php?page=points&action=edit&id=<?php echo $product_id; ?>" class="btn btn-primary">编辑商品</a>
    </div>
</div>

<style>
    .view-wrapper {
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .view-section {
        margin-bottom: 25px;
        padding-bottom: 15px;
        border-bottom: 1px solid #e9ecef;
    }

    .view-section:last-child {
        border-bottom: none;
        padding-bottom: 0;
    }

    .view-section h4 {
        margin-top: 0;
        margin-bottom: 15px;
        color: #495057;
        font-size: 18px;
    }

    .view-row {
        display: flex;
        flex-wrap: wrap;
        margin-bottom: 15px;
    }

    .view-row:last-child {
        margin-bottom: 0;
    }

    .view-item {
        flex: 0 0 33.333333%;
        max-width: 33.333333%;
        padding-right: 15px;
        box-sizing: border-box;
        margin-bottom: 10px;
    }

    .view-row.full-width .view-item {
        flex: 0 0 100%;
        max-width: 100%;
    }

    .view-item label {
        display: block;
        font-weight: bold;
        margin-bottom: 5px;
        color: #6c757d;
        font-size: 14px;
    }

    .view-value {
        color: #212529;
        word-break: break-word;
    }

    .description-box {
        background-color: #fff;
        padding: 10px;
        border-radius: 4px;
        border: 1px solid #e9ecef;
        min-height: 100px;
    }

    .redemption-table {
        width: 100%;
        border-collapse: collapse;
        margin-top: 10px;
    }

    .redemption-table th,
    .redemption-table td {
        padding: 8px 10px;
        text-align: left;
        border-bottom: 1px solid #e9ecef;
    }

    .redemption-table th {
        background-color: #f2f2f2;
        font-weight: bold;
    }

    .view-actions {
        margin-top: 20px;
        display: flex;
        gap: 10px;
    }

    .badge {
        display: inline-block;
        padding: 3px 8px;
        font-size: 12px;
        font-weight: 600;
        border-radius: 3px;
        color: white;
    }

    .badge-success {
        background-color: #28a745;
    }

    .badge-secondary {
        background-color: #6c757d;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-info {
        background-color: #17a2b8;
    }

    .empty-message {
        padding: 15px;
        text-align: center;
        background-color: #fff;
        border-radius: 4px;
        border: 1px solid #e9ecef;
        color: #6c757d;
    }

    @media (max-width: 767.98px) {
        .view-item {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>