<?php
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    define('IN_SYSTEM', true);
}

// 获取操作类型
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 获取分页参数
$page = isset($_GET['listpage']) ? intval($_GET['listpage']) : 1;
$limit = 20;
$offset = ($page - 1) * $limit;

// 获取搜索参数
$search = isset($_GET['search']) ? sanitize($_GET['search']) : '';
$bill_type = isset($_GET['bill_type']) ? sanitize($_GET['bill_type']) : '';
$category = isset($_GET['category']) ? sanitize($_GET['category']) : '';
$customer_id = isset($_GET['customer_id']) ? intval($_GET['customer_id']) : 0;
$start_date = isset($_GET['start_date']) ? sanitize($_GET['start_date']) : '';
$end_date = isset($_GET['end_date']) ? sanitize($_GET['end_date']) : '';

// 生成自定义账单编号
function generateBillNumber()
{
    global $conn;

    // 获取下一个整数ID
    $sql = "SELECT MAX(bill_id) AS max_id FROM custom_bills";
    $result = $conn->query($sql);

    if ($result && $row = $result->fetch_assoc()) {
        $maxId = $row['max_id'] ? intval($row['max_id']) : 0;
        $maxId++;

        // 格式化为8位数字的账单编号，前缀CB表示Custom Bill
        return 'CB' . str_pad($maxId, 6, '0', STR_PAD_LEFT);
    } else {
        return 'CB000001'; // 第一条记录
    }
}

// 获取账单类型名称
function getBillTypeName($type)
{
    switch ($type) {
        case 'income':
            return '收入';
        case 'expense':
            return '支出';
        default:
            return '未知类型';
    }
}

// 获取账单类型展示样式类
function getBillTypeBadgeClass($type)
{
    switch ($type) {
        case 'income':
            return 'success';
        case 'expense':
            return 'danger';
        default:
            return 'secondary';
    }
}

// 根据操作类型包含不同页面
switch ($action) {
    case 'add':
        include 'custom_bill_form.php';
        break;
    case 'edit':
        include 'custom_bill_form.php';
        break;
    case 'view':
        include 'custom_bill_view.php';
        break;
    case 'delete':
        // 获取要删除的账单ID
        $bill_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

        if ($bill_id > 0) {
            // 执行删除操作
            $sql = "DELETE FROM custom_bills WHERE bill_id = ?";
            $stmt = $conn->prepare($sql);

            if ($stmt) {
                $stmt->bind_param("i", $bill_id);

                if ($stmt->execute()) {
                    // 记录操作日志
                    $operationDetails = "用户 {$_SESSION['username']} 删除了自定义账单 (ID: {$bill_id})";
                    log_operation($_SESSION['user_id'], '删除', $operationDetails);

                    // 使用重定向而不是直接包含，避免变量未定义错误
                    header("Location: index.php?page=custom_bill&message=自定义账单删除成功&messageType=success");
                    exit;
                } else {
                    header("Location: index.php?page=custom_bill&message=删除失败: " . urlencode($stmt->error) . "&messageType=error");
                    exit;
                }

                $stmt->close();
            } else {
                header("Location: index.php?page=custom_bill&message=系统错误: " . urlencode($conn->error) . "&messageType=error");
                exit;
            }
        } else {
            header("Location: index.php?page=custom_bill&message=无效的账单ID&messageType=error");
            exit;
        }
        break;
    default:
        // 查询所有客户（用于搜索筛选）
        $customerSql = "SELECT customer_id, customer_name FROM customers ORDER BY customer_name";
        $customerResult = $conn->query($customerSql);
        $customers = [];
        while ($customerResult && $row = $customerResult->fetch_assoc()) {
            $customers[] = $row;
        }

        // 查询账单分类（用于搜索筛选）
        $categorySql = "SELECT DISTINCT category FROM custom_bills WHERE category IS NOT NULL AND category != '' ORDER BY category";
        $categoryResult = $conn->query($categorySql);
        $categories = [];
        while ($categoryResult && $row = $categoryResult->fetch_assoc()) {
            $categories[] = $row['category'];
        }

        // 构建WHERE条件
        $conditions = [];
        $params = [];
        $types = "";

        if (!empty($search)) {
            $conditions[] = "(description LIKE ? OR payment_method LIKE ? OR remark LIKE ?)";
            $searchParam = "%{$search}%";
            $params[] = $searchParam;
            $params[] = $searchParam;
            $params[] = $searchParam;
            $types .= "sss";
        }

        if (!empty($bill_type)) {
            $conditions[] = "bill_type = ?";
            $params[] = $bill_type;
            $types .= "s";
        }

        if (!empty($category)) {
            $conditions[] = "category = ?";
            $params[] = $category;
            $types .= "s";
        }

        if ($customer_id > 0) {
            $conditions[] = "related_customer_id = ?";
            $params[] = $customer_id;
            $types .= "i";
        }

        if (!empty($start_date)) {
            $conditions[] = "transaction_date >= ?";
            $params[] = $start_date;
            $types .= "s";
        }

        if (!empty($end_date)) {
            $conditions[] = "transaction_date <= ?";
            $params[] = $end_date;
            $types .= "s";
        }

        // 构建SQL查询
        $whereClause = !empty($conditions) ? "WHERE " . implode(" AND ", $conditions) : "";

        // 获取总记录数
        $countSql = "SELECT COUNT(*) as total FROM custom_bills $whereClause";

        if (!empty($params)) {
            $countStmt = $conn->prepare($countSql);
            $countStmt->bind_param($types, ...$params);
            $countStmt->execute();
            $countResult = $countStmt->get_result();
            $totalRecords = $countResult->fetch_assoc()['total'];
            $countStmt->close();
        } else {
            $countResult = $conn->query($countSql);
            $totalRecords = $countResult->fetch_assoc()['total'];
        }

        // 计算总页数
        $totalPages = ceil($totalRecords / $limit);

        // 查询账单列表
        $sql = "SELECT cb.*, c.customer_name 
                FROM custom_bills cb
                LEFT JOIN customers c ON cb.related_customer_id = c.customer_id
                $whereClause
                ORDER BY cb.transaction_date DESC, cb.bill_id DESC
                LIMIT ?, ?";

        $stmt = $conn->prepare($sql);

        if (!empty($params)) {
            $params[] = $offset;
            $params[] = $limit;
            $types .= "ii";
            $stmt->bind_param($types, ...$params);
        } else {
            $stmt->bind_param("ii", $offset, $limit);
        }

        $stmt->execute();
        $result = $stmt->get_result();

        $bills = [];
        while ($row = $result->fetch_assoc()) {
            $bills[] = $row;
        }

        $stmt->close();

        // 显示账单列表
        include 'custom_bill_list.php';
        break;
}
