<?php
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    define('IN_SYSTEM', true);
}

// 获取账单ID
$bill_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

// 获取消息参数（如果有）
if (isset($_GET['message']) && isset($_GET['messageType'])) {
    $message = $_GET['message'];
    $messageType = $_GET['messageType'];
}

// 检查ID是否有效
if ($bill_id <= 0) {
    $message = "无效的账单ID";
    $messageType = "error";
    include 'custom_bill_list.php';
    exit();
}

// 查询账单详情
$sql = "SELECT cb.*, c.customer_name, u.username as created_by_username
        FROM custom_bills cb
        LEFT JOIN customers c ON cb.related_customer_id = c.customer_id
        LEFT JOIN users u ON cb.created_by = u.user_id
        WHERE cb.bill_id = ?";

$stmt = $conn->prepare($sql);

if ($stmt) {
    $stmt->bind_param("i", $bill_id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($row = $result->fetch_assoc()) {
        $bill = $row;
    } else {
        // 账单不存在，显示错误
        $message = "未找到指定的账单记录";
        $messageType = "error";
        include 'custom_bill_list.php';
        exit();
    }

    $stmt->close();
} else {
    // 数据库错误
    $message = "系统错误: " . $conn->error;
    $messageType = "error";
    include 'custom_bill_list.php';
    exit();
}

// 格式化日期时间
$createdDate = new DateTime($bill['created_at']);
$updatedDate = new DateTime($bill['updated_at']);
?>

<div class="page-header">
    <h3>账单详情</h3>
</div>

<!-- 消息提示 -->
<?php if (isset($message) && isset($messageType)): ?>
    <div class="alert alert-<?php echo $messageType == 'error' ? 'danger' : $messageType; ?> alert-dismissible fade show" role="alert">
        <?php echo $message; ?>
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
            <span aria-hidden="true">&times;</span>
        </button>
    </div>
<?php endif; ?>

<div class="bill-success-msg">
    <p><i class="fas fa-check-circle"></i> 账单创建成功</p>
</div>

<div class="bill-info-header">
    <div class="bill-amount <?php echo $bill['bill_type'] == 'income' ? 'income' : 'expense'; ?>">
        <?php echo $bill['bill_type'] == 'income' ? '收入' : '支出'; ?>：¥ <?php echo number_format($bill['amount'], 2); ?>
    </div>
    <div class="bill-date">
        交易日期：<?php echo htmlspecialchars($bill['transaction_date']); ?>
    </div>
</div>

<div class="data-wrapper">
    <h4><?php echo htmlspecialchars($bill['description']); ?></h4>

    <div class="detail-section">
        <div class="row">
            <div class="col-label">账单编号：</div>
            <div class="col-value"><?php echo htmlspecialchars($bill['bill_id']); ?></div>
        </div>
        <div class="row">
            <div class="col-label">支付方式：</div>
            <div class="col-value"><?php echo htmlspecialchars($bill['payment_method']); ?></div>
        </div>
        <?php if (!empty($bill['category'])): ?>
            <div class="row">
                <div class="col-label">分类：</div>
                <div class="col-value"><?php echo htmlspecialchars($bill['category']); ?></div>
            </div>
        <?php endif; ?>
        <?php if (!empty($bill['related_customer_id']) && !empty($bill['customer_name'])): ?>
            <div class="row">
                <div class="col-label">关联客户：</div>
                <div class="col-value">
                    <a href="index.php?page=customer&action=view&id=<?php echo $bill['related_customer_id']; ?>">
                        <?php echo htmlspecialchars($bill['customer_name']); ?>
                    </a>
                </div>
            </div>
        <?php endif; ?>
        <?php if (!empty($bill['remark'])): ?>
            <div class="row">
                <div class="col-label">备注：</div>
                <div class="col-value"><?php echo nl2br(htmlspecialchars($bill['remark'])); ?></div>
            </div>
        <?php endif; ?>
        <div class="row">
            <div class="col-label">创建者：</div>
            <div class="col-value"><?php echo htmlspecialchars($bill['created_by_username']); ?></div>
        </div>
        <div class="row">
            <div class="col-label">创建时间：</div>
            <div class="col-value"><?php echo $createdDate->format('Y-m-d H:i:s'); ?></div>
        </div>
        <?php if ($createdDate->format('Y-m-d H:i:s') != $updatedDate->format('Y-m-d H:i:s')): ?>
            <div class="row">
                <div class="col-label">最后更新：</div>
                <div class="col-value"><?php echo $updatedDate->format('Y-m-d H:i:s'); ?></div>
            </div>
        <?php endif; ?>
    </div>
</div>

<!-- 相关账单 -->
<?php
// 查询与同一客户相关的其他账单
if (!empty($bill['related_customer_id'])) {
    $relatedBillsSql = "SELECT * FROM custom_bills 
                         WHERE related_customer_id = ? AND bill_id != ? 
                         ORDER BY transaction_date DESC 
                         LIMIT 5";
    $relatedBillsStmt = $conn->prepare($relatedBillsSql);
    $relatedBillsStmt->bind_param("ii", $bill['related_customer_id'], $bill_id);
    $relatedBillsStmt->execute();
    $relatedBillsResult = $relatedBillsStmt->get_result();

    if ($relatedBillsResult->num_rows > 0) {
?>
        <div class="data-wrapper">
            <h4><i class="fas fa-link"></i> 同客户的相关账单</h4>
            <div class="table-responsive">
                <table class="data-table" width="100%" cellspacing="0">
                    <thead>
                        <tr>
                            <th>账单ID</th>
                            <th>类型</th>
                            <th>日期</th>
                            <th>描述</th>
                            <th>金额</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php while ($relatedBill = $relatedBillsResult->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($relatedBill['bill_id']); ?></td>
                                <td>
                                    <span class="badge badge-<?php echo getBillTypeBadgeClass($relatedBill['bill_type']); ?>">
                                        <?php echo getBillTypeName($relatedBill['bill_type']); ?>
                                    </span>
                                </td>
                                <td><?php echo htmlspecialchars($relatedBill['transaction_date']); ?></td>
                                <td><?php echo htmlspecialchars($relatedBill['description']); ?></td>
                                <td class="text-right"><?php echo number_format($relatedBill['amount'], 2); ?></td>
                                <td>
                                    <a href="index.php?page=custom_bill&action=view&id=<?php echo $relatedBill['bill_id']; ?>"
                                        class="btn btn-info btn-sm">
                                        查看
                                    </a>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    </tbody>
                </table>
            </div>
        </div>
<?php
    }
    $relatedBillsStmt->close();
}
?>

<div class="form-actions">
    <a href="index.php?page=custom_bill&action=edit&id=<?php echo $bill_id; ?>" class="btn btn-primary">编辑账单</a>
    <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $bill_id; ?>, '<?php echo htmlspecialchars($bill['description']); ?>')" class="btn btn-danger">删除账单</a>
    <a href="index.php?page=custom_bill" class="btn btn-secondary">返回列表</a>
</div>

<style>
    .bill-success-msg {
        background-color: #effaf0;
        border-left: 3px solid #28a745;
        padding: 15px;
        margin-bottom: 20px;
        display: none;
    }

    .bill-success-msg i {
        color: #28a745;
        margin-right: 5px;
    }

    .bill-info-header {
        display: flex;
        justify-content: space-between;
        margin-bottom: 20px;
        padding: 10px 15px;
        background-color: #f8f9fa;
        border-radius: 5px;
    }

    .bill-amount {
        font-size: 20px;
        font-weight: bold;
    }

    .bill-amount.income {
        color: #28a745;
    }

    .bill-amount.expense {
        color: #dc3545;
    }

    .bill-date {
        align-self: center;
    }

    .data-wrapper {
        border: 1px solid #ddd;
        border-radius: 5px;
        margin-bottom: 20px;
        background-color: #fff;
        padding: 15px;
    }

    .data-wrapper h4 {
        margin-bottom: 15px;
        padding-bottom: 10px;
        border-bottom: 1px solid #eee;
    }

    .detail-section {
        display: table;
        width: 100%;
    }

    .detail-section .row {
        display: table-row;
    }

    .detail-section .col-label,
    .detail-section .col-value {
        display: table-cell;
        padding: 8px 0;
        border-bottom: 1px solid #eee;
    }

    .detail-section .col-label {
        width: 150px;
        font-weight: bold;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        border: 1px solid #ddd;
    }

    .data-table th {
        background-color: #f8f9fa;
        text-align: left;
    }

    .form-actions {
        margin-top: 20px;
        padding-top: 20px;
        border-top: 1px solid #eee;
    }

    .badge {
        padding: 5px 8px;
        border-radius: 4px;
        font-size: 12px;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }
</style>

<script type="text/javascript">
    function confirmDelete(billId, description) {
        if (confirm("确定要删除这条账单记录吗？此操作不可逆。\n账单描述：" + description)) {
            var deleteLink = 'index.php?page=custom_bill&action=delete&id=' + billId;
            window.location.href = deleteLink;
        }
    }

    // 如果URL中有success参数，显示成功消息
    document.addEventListener('DOMContentLoaded', function() {
        const urlParams = new URLSearchParams(window.location.search);
        if (urlParams.get('success') === 'true') {
            document.querySelector('.bill-success-msg').style.display = 'block';
        }
    });
</script>