<?php
// 定义系统内访问标志
define('IN_SYSTEM', true);

// 获取操作
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 消息提示
$message = '';
$messageType = 'info'; // success, info, warning, error

// 检查会话中是否有消息
if (isset($_SESSION['message']) && isset($_SESSION['message_type'])) {
    $message = $_SESSION['message'];
    $messageType = $_SESSION['message_type'];

    // 清除会话消息（只显示一次）
    unset($_SESSION['message']);
    unset($_SESSION['message_type']);
}

// 从URL获取消息（向后兼容）
if (empty($message) && isset($_GET['message'])) {
    $message = $_GET['message'];
    $messageType = isset($_GET['type']) ? $_GET['type'] : 'info';
}

// 设置页码、搜索条件等参数
$page = isset($_GET['listpage']) ? max(1, intval($_GET['listpage'])) : 1;
$limit = 10;
$offset = ($page - 1) * $limit;
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$status = isset($_GET['status']) ? trim($_GET['status']) : '';
$start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : '';
$end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : '';
$warehouse_id = isset($_GET['warehouse_id']) ? intval($_GET['warehouse_id']) : 0;

// 辅助函数：生成出库单号
function generateDeliveryNumber()
{
    $prefix = 'DO'; // 出库单前缀
    $date = date('Ymd');
    $random = mt_rand(1000, 9999);
    return $prefix . $date . $random;
}

// 在文件顶部添加全局字段检查函数

/**
 * 检查并添加discount_rate字段
 * 
 * @param mysqli $conn 数据库连接
 * @return bool 字段是否已存在或添加成功
 */
function ensureDiscountRateField($conn)
{
    static $fieldChecked = false;
    static $fieldExists = false;

    // 如果已经检查过，直接返回结果
    if ($fieldChecked) {
        return $fieldExists;
    }

    $fieldChecked = true;

    // 检查字段是否存在
    $checkFieldSql = "SHOW COLUMNS FROM sales_delivery_items LIKE 'discount_rate'";
    $checkResult = $conn->query($checkFieldSql);

    if ($checkResult && $checkResult->num_rows > 0) {
        // 字段已存在
        $fieldExists = true;
        return true;
    }

    // 字段不存在，尝试添加
    error_log("sales_delivery_items表缺少discount_rate字段，尝试添加...");
    $addFieldSql = "ALTER TABLE sales_delivery_items ADD COLUMN discount_rate DECIMAL(5,2) NOT NULL DEFAULT 0 COMMENT '折扣率' AFTER unit_price";

    if ($conn->query($addFieldSql)) {
        error_log("discount_rate字段添加成功");
        $fieldExists = true;
        return true;
    } else {
        error_log("添加discount_rate字段失败: " . $conn->error);
        return false;
    }
}

/**
 * 检查并添加total_amount字段
 * 
 * @param mysqli $conn 数据库连接
 * @return bool 字段是否已存在或添加成功
 */
function ensureTotalAmountField($conn)
{
    static $fieldChecked = false;
    static $fieldExists = false;

    // 如果已经检查过，直接返回结果
    if ($fieldChecked) {
        return $fieldExists;
    }

    $fieldChecked = true;

    // 检查字段是否存在
    $checkFieldSql = "SHOW COLUMNS FROM sales_deliveries LIKE 'total_amount'";
    $checkResult = $conn->query($checkFieldSql);

    if ($checkResult && $checkResult->num_rows > 0) {
        // 字段已存在
        $fieldExists = true;
        return true;
    }

    // 字段不存在，尝试添加
    error_log("sales_deliveries表缺少total_amount字段，尝试添加...");
    $addFieldSql = "ALTER TABLE sales_deliveries ADD COLUMN total_amount DECIMAL(12,2) NOT NULL DEFAULT 0 COMMENT '订单总金额' AFTER remark";

    if ($conn->query($addFieldSql)) {
        error_log("total_amount字段添加成功");
        $fieldExists = true;
        return true;
    } else {
        error_log("添加total_amount字段失败: " . $conn->error);
        return false;
    }
}

// 处理不同操作
switch ($action) {
    case 'add':
        // 添加出库单
        if ($_SERVER['REQUEST_METHOD'] == 'POST') {
            // 记录表单提交数据用于调试
            error_log("销售出库表单提交数据: " . print_r($_POST, true));

            // 验证数据
            $errors = validateDeliveryData($_POST);

            if (empty($errors)) {
                // 创建出库单
                $result = createDelivery($conn, $_POST);

                if ($result['success']) {
                    $_SESSION['message'] = '销售出库单创建成功';
                    $_SESSION['message_type'] = 'success';
                    // 重定向到列表页
                    header('Location: index.php?page=delivery');
                    exit;
                } else {
                    $message = '创建失败: ' . $result['message'];
                    $messageType = 'error';
                }
            } else {
                $message = '表单验证失败: ' . implode(', ', $errors);
                $messageType = 'error';
            }
        }

        // 显示添加表单
        include 'delivery_form.php';
        break;

    case 'edit':
        // 编辑出库单
        if (!isset($_GET['id'])) {
            $message = '缺少出库单ID';
            $messageType = 'error';
            include 'delivery_list.php';
            break;
        }

        $delivery_id = (int)$_GET['id'];

        // 获取出库单信息
        $sql = "SELECT * FROM sales_deliveries WHERE delivery_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $delivery_id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows === 0) {
            $message = '出库单不存在';
            $messageType = 'error';
            include 'delivery_list.php';
            break;
        }

        $delivery = $result->fetch_assoc();

        // 获取出库单明细
        $sql = "SELECT * FROM sales_delivery_items WHERE delivery_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $delivery_id);
        $stmt->execute();
        $result = $stmt->get_result();

        $deliveryItems = [];
        while ($row = $result->fetch_assoc()) {
            $deliveryItems[] = $row;
        }

        // 处理表单提交
        if ($_SERVER['REQUEST_METHOD'] == 'POST') {
            // 记录表单提交数据用于调试
            error_log("编辑销售出库表单提交数据: " . print_r($_POST, true));

            // 验证数据
            $errors = validateDeliveryData($_POST);

            if (empty($errors)) {
                // 更新出库单
                $result = updateDelivery($conn, $_POST);

                if ($result['success']) {
                    $_SESSION['message'] = '销售出库单更新成功';
                    $_SESSION['message_type'] = 'success';
                    // 重定向到列表页
                    header('Location: index.php?page=delivery');
                    exit;
                } else {
                    $message = '更新失败: ' . $result['message'];
                    $messageType = 'error';
                }
            } else {
                $message = '表单验证失败: ' . implode(', ', $errors);
                $messageType = 'error';
            }
        }

        // 显示编辑表单
        include 'delivery_form.php';
        break;

    case 'delete':
        // 删除出库单
        if (!isset($_GET['id'])) {
            $_SESSION['message'] = '缺少出库单ID';
            $_SESSION['message_type'] = 'error';
            header('Location: index.php?page=delivery');
            exit;
        }

        $delivery_id = (int)$_GET['id'];

        // 检查出库单状态，只有pending状态的出库单可以删除
        $sql = "SELECT delivery_status FROM sales_deliveries WHERE delivery_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $delivery_id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows === 0) {
            $_SESSION['message'] = '出库单不存在';
            $_SESSION['message_type'] = 'error';
            header('Location: index.php?page=delivery');
            exit;
        }

        $deliveryStatus = $result->fetch_assoc()['delivery_status'];

        if ($deliveryStatus !== 'pending') {
            $_SESSION['message'] = '只能删除待处理状态的出库单';
            $_SESSION['message_type'] = 'error';
            header('Location: index.php?page=delivery');
            exit;
        }

        // 开始事务
        $conn->begin_transaction();

        try {
            // 删除出库单明细
            $sql = "DELETE FROM sales_delivery_items WHERE delivery_id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("i", $delivery_id);
            $stmt->execute();

            // 删除出库单
            $sql = "DELETE FROM sales_deliveries WHERE delivery_id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("i", $delivery_id);
            $stmt->execute();

            // 提交事务
            if (!$conn->commit()) {
                error_log("事务提交失败: " . $conn->error);
                throw new Exception("事务提交失败: " . $conn->error);
            }
            error_log("事务提交成功，出库单ID: " . $delivery_id);

            $_SESSION['message'] = '出库单删除成功';
            $_SESSION['message_type'] = 'success';
        } catch (Exception $e) {
            // 回滚事务
            if ($conn->rollback()) {
                error_log("事务已回滚");
            } else {
                error_log("事务回滚失败: " . $conn->error);
            }

            $_SESSION['message'] = '删除失败: ' . $e->getMessage();
            $_SESSION['message_type'] = 'error';
        }

        // 重定向到列表页
        header('Location: index.php?page=delivery');
        exit;
        break;

    case 'view':
        // 查看出库单详情
        if (!isset($_GET['id'])) {
            $message = '缺少出库单ID';
            $messageType = 'error';
            include 'delivery_list.php';
            break;
        }

        $delivery_id = (int)$_GET['id'];

        // 获取出库单信息（包括客户和仓库信息）
        $sql = "SELECT d.*, c.customer_name, w.warehouse_name 
                FROM sales_deliveries d 
                LEFT JOIN customers c ON d.customer_id = c.customer_id 
                LEFT JOIN warehouses w ON d.warehouse_id = w.warehouse_id 
                WHERE d.delivery_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $delivery_id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows === 0) {
            $message = '出库单不存在';
            $messageType = 'error';
            include 'delivery_list.php';
            break;
        }

        $viewData = $result->fetch_assoc();

        // 获取出库单明细
        $sql = "SELECT di.*, p.product_name, p.barcode, p.unit, pb.batch_number 
                FROM sales_delivery_items di 
                JOIN products p ON di.product_id = p.product_id 
                LEFT JOIN product_batches pb ON di.batch_id = pb.batch_id 
                WHERE di.delivery_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $delivery_id);
        $stmt->execute();
        $result = $stmt->get_result();

        $viewItems = [];
        while ($item = $result->fetch_assoc()) {
            $viewItems[] = $item;
        }

        // 显示详情页
        include 'delivery_view.php';
        break;

    case 'list':
    default:
        // 构建查询条件
        $whereClause = " WHERE 1=1 ";
        $params = [];
        $types = "";

        if (!empty($search)) {
            $whereClause .= " AND (d.delivery_number LIKE ? OR c.customer_name LIKE ?) ";
            $searchParam = "%{$search}%";
            $params[] = $searchParam;
            $params[] = $searchParam;
            $types .= "ss";
        }

        if (!empty($status)) {
            $whereClause .= " AND d.delivery_status = ? ";
            $params[] = $status;
            $types .= "s";
        }

        if (!empty($start_date)) {
            $whereClause .= " AND d.delivery_date >= ? ";
            $params[] = $start_date;
            $types .= "s";
        }

        if (!empty($end_date)) {
            $whereClause .= " AND d.delivery_date <= ? ";
            $params[] = $end_date;
            $types .= "s";
        }

        if ($warehouse_id > 0) {
            $whereClause .= " AND d.warehouse_id = ? ";
            $params[] = $warehouse_id;
            $types .= "i";
        }

        // 获取总记录数
        $countSql = "SELECT COUNT(*) as total 
                     FROM sales_deliveries d 
                     LEFT JOIN customers c ON d.customer_id = c.customer_id 
                     {$whereClause}";

        $countStmt = $conn->prepare($countSql);

        if (!empty($params)) {
            $countStmt->bind_param($types, ...$params);
        }

        $countStmt->execute();
        $countResult = $countStmt->get_result();
        $totalRecords = $countResult->fetch_assoc()['total'];
        $totalPages = ceil($totalRecords / $limit);

        // 获取出库单列表
        $sql = "SELECT d.*, c.customer_name, w.warehouse_name 
                FROM sales_deliveries d 
                LEFT JOIN customers c ON d.customer_id = c.customer_id 
                LEFT JOIN warehouses w ON d.warehouse_id = w.warehouse_id 
                {$whereClause} 
                ORDER BY d.delivery_id DESC 
                LIMIT ?, ?";

        // 添加分页参数
        $params[] = $offset;
        $params[] = $limit;
        $types .= "ii";

        $stmt = $conn->prepare($sql);
        $stmt->bind_param($types, ...$params);
        $stmt->execute();
        $result = $stmt->get_result();

        $deliveries = [];
        while ($row = $result->fetch_assoc()) {
            $deliveries[] = $row;
        }

        // 显示列表页
        include 'delivery_list.php';
        break;
}

/**
 * 验证销售出库数据
 * @param array $data 表单数据
 * @return array 错误信息
 */
function validateDeliveryData($data)
{
    $errors = [];

    // 验证客户ID
    if (empty($data['customer_id'])) {
        $errors[] = '请选择客户';
    }

    // 验证仓库ID
    if (empty($data['warehouse_id'])) {
        $errors[] = '请选择仓库';
    }

    // 验证出库日期
    if (empty($data['delivery_date'])) {
        $errors[] = '请选择出库日期';
    }

    // 验证出库状态
    if (empty($data['delivery_status'])) {
        $errors[] = '请选择出库状态';
    } else {
        $validStatuses = ['pending', 'in_progress', 'completed', 'cancelled'];
        if (!in_array($data['delivery_status'], $validStatuses)) {
            $errors[] = '无效的出库状态';
        }
    }

    // 验证出库明细
    $hasItems = false;

    // 检查是否有商品行
    if (isset($data['items']) && is_array($data['items'])) {
        foreach ($data['items'] as $item) {
            if (!empty($item['product_id'])) {
                $hasItems = true;
                break;
            }
        }
    } elseif (isset($data['product_id']) && is_array($data['product_id'])) {
        foreach ($data['product_id'] as $productId) {
            if (!empty($productId)) {
                $hasItems = true;
                break;
            }
        }
    }

    if (!$hasItems) {
        $errors[] = '请至少添加一个商品';
    }

    return $errors;
}

/**
 * 创建销售出库单
 * @param mysqli $conn 数据库连接
 * @param array $params 表单数据
 * @return array 操作结果
 */
function createDelivery($conn, $params)
{
    error_log("开始创建销售出库单");

    try {
        $conn->begin_transaction();

        // 检查discount_rate字段是否存在
        ensureDiscountRateField($conn);

        // 检查total_amount字段是否存在
        $hasTotalAmount = ensureTotalAmountField($conn);

        // 获取参数
        $deliveryNumber = isset($params['delivery_number']) ? sanitize($params['delivery_number']) : generateDeliveryNumber();
        $orderId = !empty($params['order_id']) ? intval($params['order_id']) : null;
        $invoiceId = !empty($params['invoice_id']) ? intval($params['invoice_id']) : null;
        $customerId = intval($params['customer_id']);
        $warehouseId = intval($params['warehouse_id']);
        $deliveryDate = sanitize($params['delivery_date']);
        $deliveryStatus = sanitize($params['delivery_status']);
        $shippingAddress = !empty($params['shipping_address']) ? sanitize($params['shipping_address']) : '';
        $contactPerson = !empty($params['contact_person']) ? sanitize($params['contact_person']) : '';
        $contactPhone = !empty($params['contact_phone']) ? sanitize($params['contact_phone']) : '';
        $remark = !empty($params['remark']) ? sanitize($params['remark']) : '';
        $createdBy = isset($_SESSION['user_id']) ? intval($_SESSION['user_id']) : 1;
        $totalAmount = isset($params['total_amount']) ? floatval($params['total_amount']) : 0.00;

        // 检查是否有明细项
        if (isset($params['items']) && is_array($params['items'])) {
            $items = $params['items'];
        } else {
            // 旧格式支持
            $items = [];
        }

        // 确保total_amount字段检查成功
        if ($hasTotalAmount === false) {
            throw new Exception("无法确保total_amount字段存在，请联系系统管理员");
        }

        // 修改bind_param中的类型字符串，处理nullable字段
        $types = "s";
        $params = [$deliveryNumber];

        // 处理可能为NULL的字段
        if ($orderId === null) {
            $types .= "i"; // 实际上会绑定0，并在SQL中使用NULL
            $params[] = 0;
            $sql = "INSERT INTO sales_deliveries (
                    delivery_number, 
                    order_id, 
                    invoice_id, 
                    customer_id, 
                    warehouse_id, 
                    delivery_date, 
                    delivery_status, 
                    shipping_address, 
                    contact_person, 
                    contact_phone, 
                    remark, 
                    total_amount,
                    created_by
                ) VALUES (?, NULL, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
        } else {
            $types .= "i";
            $params[] = $orderId;
            $sql = "INSERT INTO sales_deliveries (
                    delivery_number, 
                    order_id, 
                    invoice_id, 
                    customer_id, 
                    warehouse_id, 
                    delivery_date, 
                    delivery_status, 
                    shipping_address, 
                    contact_person, 
                    contact_phone, 
                    remark, 
                    total_amount,
                    created_by
                ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
        }

        // 继续处理其他参数
        if ($invoiceId === null) {
            $sql = str_replace("?, ?, ?, ?", "?, ?, NULL, ?", $sql);
        } else {
            $types .= "i";
            $params[] = $invoiceId;
        }

        // 检查total_amount字段是否存在
        $hasTotalAmount = ensureTotalAmountField($conn);

        // 如果total_amount字段不存在，从SQL中去掉该字段
        if (!$hasTotalAmount) {
            error_log("尝试在SQL中移除total_amount字段");
            $sql = str_replace(
                "delivery_number, 
                    order_id, 
                    invoice_id, 
                    customer_id, 
                    warehouse_id, 
                    delivery_date, 
                    delivery_status, 
                    shipping_address, 
                    contact_person, 
                    contact_phone, 
                    remark, 
                    total_amount,
                    created_by",
                "delivery_number, 
                    order_id, 
                    invoice_id, 
                    customer_id, 
                    warehouse_id, 
                    delivery_date, 
                    delivery_status, 
                    shipping_address, 
                    contact_person, 
                    contact_phone, 
                    remark, 
                    created_by",
                $sql
            );

            $sql = str_replace(
                "?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?",
                "?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?",
                $sql
            );

            // 添加其余参数（不包括total_amount）
            $types .= "iisssssi";
            $params[] = $customerId;
            $params[] = $warehouseId;
            $params[] = $deliveryDate;
            $params[] = $deliveryStatus;
            $params[] = $shippingAddress;
            $params[] = $contactPerson;
            $params[] = $contactPhone;
            $params[] = $remark;
            $params[] = $createdBy;
        } else {
            // 添加其余参数（包括total_amount）
            $types .= "iissssssdi";
            $params[] = $customerId;
            $params[] = $warehouseId;
            $params[] = $deliveryDate;
            $params[] = $deliveryStatus;
            $params[] = $shippingAddress;
            $params[] = $contactPerson;
            $params[] = $contactPhone;
            $params[] = $remark;
            $params[] = $totalAmount;
            $params[] = $createdBy;
        }

        error_log("准备执行SQL: " . $sql);
        error_log("绑定参数类型: " . $types);
        error_log("参数数量: " . count($params));

        $stmt = $conn->prepare($sql);
        if (!$stmt) {
            // 记录详细的错误信息
            error_log("SQL准备失败，错误代码: " . $conn->errno . ", 错误信息: " . $conn->error);

            // 检查表结构
            error_log("检查sales_deliveries表结构...");
            $checkTableSql = "DESCRIBE sales_deliveries";
            $checkTableResult = $conn->query($checkTableSql);
            if ($checkTableResult) {
                error_log("sales_deliveries表结构如下:");
                while ($row = $checkTableResult->fetch_assoc()) {
                    error_log("字段: " . $row['Field'] . ", 类型: " . $row['Type'] . ", 允许NULL: " . $row['Null']);
                }
            } else {
                error_log("无法检查sales_deliveries表结构: " . $conn->error);
            }

            // 检查连接状态
            if ($conn->ping()) {
                error_log("数据库连接正常");
            } else {
                error_log("数据库连接已断开，尝试重新连接");
                $conn->close();
                $conn = new mysqli(DB_HOST, DB_USER, DB_PASS, DB_NAME);
                if ($conn->connect_error) {
                    throw new Exception("数据库重连失败: " . $conn->connect_error);
                }

                // 重新尝试准备语句
                $stmt = $conn->prepare($sql);
                if (!$stmt) {
                    throw new Exception("重连后SQL准备仍然失败: " . $conn->error);
                }
            }
        }

        // 记录绑定参数信息
        error_log("绑定参数类型: " . $types);

        try {
            $stmt->bind_param($types, ...$params);
        } catch (Exception $e) {
            error_log("绑定参数失败: " . $e->getMessage());
            error_log("参数详情: " . print_r($params, true));
            throw new Exception("绑定参数失败: " . $e->getMessage());
        }

        if (!$stmt->execute()) {
            error_log("执行SQL失败: " . $stmt->error);
            throw new Exception("创建销售出库单失败: " . $stmt->error);
        }

        error_log("销售出库单创建成功");
        $deliveryId = $stmt->insert_id;

        // 插入出库明细
        if (isset($items) && is_array($items)) {
            // 新格式：使用items数组
            error_log("创建出库单：使用items数组格式处理出库明细，items数量: " . count($items));
            foreach ($items as $item) {
                if (empty($item['product_id'])) continue;

                error_log("创建出库单：处理商品ID: " . $item['product_id'] . ", 批次ID: " . $item['batch_id']);
                $productId = intval($item['product_id']);
                $batchId = intval($item['batch_id']);
                $quantity = intval($item['quantity']);
                $unitPrice = floatval($item['unit_price']);
                $discountRate = isset($item['discount_rate']) ? floatval($item['discount_rate']) : 0;
                $itemAmount = isset($item['item_amount']) ? floatval($item['item_amount']) : ($quantity * $unitPrice * (1 - $discountRate / 100));
                $itemRemark = isset($item['remark']) ? sanitize($item['remark']) : '';

                $sql = "INSERT INTO sales_delivery_items (
                            delivery_id, 
                            product_id, 
                            batch_id, 
                            quantity, 
                            unit_price,
                            discount_rate,
                            item_amount, 
                            remark
                        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?)";

                $stmt = $conn->prepare($sql);
                if (!$stmt) {
                    error_log("创建出库单：SQL准备失败，错误: " . $conn->error);
                    throw new Exception("SQL准备失败: " . $conn->error);
                }

                $stmt->bind_param(
                    "iiidddds",
                    $deliveryId,
                    $productId,
                    $batchId,
                    $quantity,
                    $unitPrice,
                    $discountRate,
                    $itemAmount,
                    $itemRemark
                );

                if (!$stmt->execute()) {
                    error_log("创建出库单：插入出库明细失败: " . $stmt->error . ", SQL: " . $sql);
                    throw new Exception("插入出库明细失败: " . $stmt->error);
                } else {
                    error_log("创建出库单：插入出库明细成功: delivery_id={$deliveryId}, product_id={$productId}, batch_id={$batchId}");
                }

                // 更新库存
                updateInventory($warehouseId, $productId, $batchId, $quantity, 'decrease');
            }
        } else {
            // 旧格式：使用平行数组
            error_log("创建出库单：使用旧格式平行数组处理出库明细");
            $productIds = isset($params['product_id']) ? $params['product_id'] : [];
            $batchIds = isset($params['batch_id']) ? $params['batch_id'] : [];
            $quantities = isset($params['quantity']) ? $params['quantity'] : [];
            $unitPrices = isset($params['unit_price']) ? $params['unit_price'] : [];
            $discountRates = isset($params['discount_rate']) ? $params['discount_rate'] : [];
            $itemRemarks = isset($params['item_remark']) ? $params['item_remark'] : [];

            $originalParams = $params; // 保存原始参数用于访问平行数组

            for ($i = 0; $i < count($productIds); $i++) {
                if (empty($productIds[$i])) continue;

                error_log("创建出库单：处理旧格式商品 索引{$i}, 商品ID: {$productIds[$i]}, 批次ID: {$batchIds[$i]}");
                $productId = intval($productIds[$i]);
                $batchId = intval($batchIds[$i]);
                $quantity = intval($quantities[$i]);
                $unitPrice = floatval($unitPrices[$i]);
                $discountRate = isset($discountRates[$i]) ? floatval($discountRates[$i]) : 0;
                $itemAmount = $quantity * $unitPrice * (1 - $discountRate / 100);
                $itemRemark = isset($itemRemarks[$i]) ? sanitize($itemRemarks[$i]) : '';

                $sql = "INSERT INTO sales_delivery_items (
                            delivery_id, 
                            product_id, 
                            batch_id, 
                            quantity, 
                            unit_price,
                            discount_rate,
                            item_amount, 
                            remark
                        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?)";

                $stmt = $conn->prepare($sql);
                if (!$stmt) {
                    error_log("创建出库单：SQL准备失败，错误: " . $conn->error);
                    throw new Exception("SQL准备失败: " . $conn->error);
                }

                $stmt->bind_param(
                    "iiidddds",
                    $deliveryId,
                    $productId,
                    $batchId,
                    $quantity,
                    $unitPrice,
                    $discountRate,
                    $itemAmount,
                    $itemRemark
                );

                if (!$stmt->execute()) {
                    error_log("创建出库单：插入出库明细失败: " . $stmt->error . ", SQL: " . $sql);
                    throw new Exception("插入出库明细失败: " . $stmt->error);
                } else {
                    error_log("创建出库单：插入出库明细成功: delivery_id={$deliveryId}, product_id={$productId}, batch_id={$batchId}");
                }

                // 更新库存
                updateInventory($warehouseId, $productId, $batchId, $quantity, 'decrease');
            }
        }

        // 提交事务
        if (!$conn->commit()) {
            error_log("事务提交失败: " . $conn->error);
            throw new Exception("事务提交失败: " . $conn->error);
        }
        error_log("事务提交成功，出库单ID: " . $deliveryId);

        return [
            'success' => true,
            'message' => '销售出库单创建成功',
            'delivery_id' => $deliveryId
        ];
    } catch (Exception $e) {
        // 回滚事务
        if ($conn->rollback()) {
            error_log("事务已回滚");
        } else {
            error_log("事务回滚失败: " . $conn->error);
        }

        error_log("创建销售出库单失败: " . $e->getMessage());

        return [
            'success' => false,
            'message' => $e->getMessage()
        ];
    }
}

/**
 * 更新销售出库单
 * @param mysqli $conn 数据库连接
 * @param array $params 表单数据
 * @return array 操作结果
 */
function updateDelivery($conn, $params)
{
    try {
        // 开始事务
        $conn->begin_transaction();

        // 检查discount_rate字段是否存在
        ensureDiscountRateField($conn);

        // 检查total_amount字段是否存在
        $hasTotalAmount = ensureTotalAmountField($conn);

        // 确保total_amount字段检查成功
        if ($hasTotalAmount === false) {
            throw new Exception("无法确保total_amount字段存在，请联系系统管理员");
        }

        // 获取参数
        $deliveryId = intval($params['delivery_id']);
        $orderId = !empty($params['order_id']) ? intval($params['order_id']) : null;
        $invoiceId = !empty($params['invoice_id']) ? intval($params['invoice_id']) : null;
        $customerId = intval($params['customer_id']);
        $warehouseId = intval($params['warehouse_id']);
        $deliveryDate = sanitize($params['delivery_date']);
        $deliveryStatus = sanitize($params['delivery_status']);
        $shippingAddress = !empty($params['shipping_address']) ? sanitize($params['shipping_address']) : '';
        $contactPerson = !empty($params['contact_person']) ? sanitize($params['contact_person']) : '';
        $contactPhone = !empty($params['contact_phone']) ? sanitize($params['contact_phone']) : '';
        $remark = !empty($params['remark']) ? sanitize($params['remark']) : '';
        $totalAmount = !empty($params['total_amount']) ? floatval($params['total_amount']) : 0;

        // 处理items参数
        $items = isset($params['items']) ? $params['items'] : [];
        if (!is_array($items)) {
            $items = [];
            error_log("更新出库单：items参数不是数组，将使用空数组");
        } else {
            error_log("更新出库单：接收到items参数，数量: " . count($items));
        }

        // 确保有效的出库单ID
        $sql = "SELECT delivery_status FROM sales_deliveries WHERE delivery_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $deliveryId);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows === 0) {
            throw new Exception("出库单不存在");
        }

        $currentStatus = $result->fetch_assoc()['delivery_status'];

        if ($currentStatus !== 'pending') {
            throw new Exception("只能更新待处理状态的出库单");
        }

        // 获取原有出库单信息（用于恢复库存）
        $sql = "SELECT warehouse_id FROM sales_deliveries WHERE delivery_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $deliveryId);
        $stmt->execute();
        $result = $stmt->get_result();
        $oldDelivery = $result->fetch_assoc();

        // 获取原有出库明细（用于恢复库存）
        $sql = "SELECT product_id, batch_id, quantity FROM sales_delivery_items WHERE delivery_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $deliveryId);
        $stmt->execute();
        $result = $stmt->get_result();
        $oldItems = [];
        while ($item = $result->fetch_assoc()) {
            $oldItems[] = $item;
        }

        // 先恢复原有出库明细的库存
        foreach ($oldItems as $item) {
            updateInventory($oldDelivery['warehouse_id'], $item['product_id'], $item['batch_id'], $item['quantity'], 'increase');
        }

        // 删除原有出库明细
        $sql = "DELETE FROM sales_delivery_items WHERE delivery_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $deliveryId);

        if (!$stmt->execute()) {
            throw new Exception("删除原有出库明细失败: " . $stmt->error);
        }

        // 更新出库单
        $sql = "UPDATE sales_deliveries SET ";

        // 构建动态SQL
        $updates = array();
        $types = "";
        $params = array();

        // 处理nullable字段
        if ($orderId === null) {
            $updates[] = "order_id = NULL";
        } else {
            $updates[] = "order_id = ?";
            $types .= "i";
            $params[] = $orderId;
        }

        if ($invoiceId === null) {
            $updates[] = "invoice_id = NULL";
        } else {
            $updates[] = "invoice_id = ?";
            $types .= "i";
            $params[] = $invoiceId;
        }

        // 添加其他更新字段
        $updates[] = "customer_id = ?";
        $updates[] = "warehouse_id = ?";
        $updates[] = "delivery_date = ?";
        $updates[] = "delivery_status = ?";
        $updates[] = "shipping_address = ?";
        $updates[] = "contact_person = ?";
        $updates[] = "contact_phone = ?";
        $updates[] = "remark = ?";

        // 根据total_amount字段是否存在决定是否更新该字段
        if ($hasTotalAmount) {
            $updates[] = "total_amount = ?";
        }

        $types .= "iissssss";
        $params[] = $customerId;
        $params[] = $warehouseId;
        $params[] = $deliveryDate;
        $params[] = $deliveryStatus;
        $params[] = $shippingAddress;
        $params[] = $contactPerson;
        $params[] = $contactPhone;
        $params[] = $remark;

        // 如果total_amount字段存在，添加对应的参数
        if ($hasTotalAmount) {
            $types .= "d";
            $params[] = $totalAmount;
        }

        // 添加WHERE条件参数
        $types .= "i";
        $params[] = $deliveryId;

        // 完成SQL语句
        $sql .= implode(", ", $updates);
        $sql .= " WHERE delivery_id = ?";

        error_log("更新出库单SQL: " . $sql);
        error_log("参数类型: " . $types);
        error_log("参数数量: " . count($params));

        $stmt = $conn->prepare($sql);

        if (!$stmt) {
            error_log("SQL准备失败，错误代码: " . $conn->errno . ", 错误信息: " . $conn->error);
            throw new Exception("更新销售出库单SQL准备失败: " . $conn->error);
        }

        // 绑定参数并执行
        $stmt->bind_param($types, ...$params);

        if (!$stmt->execute()) {
            throw new Exception("更新销售出库单失败: " . $stmt->error);
        }

        // 插入新的出库明细
        if (isset($items) && is_array($items)) {
            // 新格式：使用items数组
            error_log("更新出库单：使用items数组格式处理出库明细，items数量: " . count($items));
            foreach ($items as $item) {
                if (empty($item['product_id'])) continue;

                error_log("更新出库单：处理商品ID: " . $item['product_id'] . ", 批次ID: " . $item['batch_id']);
                $productId = intval($item['product_id']);
                $batchId = intval($item['batch_id']);
                $quantity = intval($item['quantity']);
                $unitPrice = floatval($item['unit_price']);
                $discountRate = isset($item['discount_rate']) ? floatval($item['discount_rate']) : 0;
                $itemAmount = isset($item['item_amount']) ? floatval($item['item_amount']) : ($quantity * $unitPrice * (1 - $discountRate / 100));
                $itemRemark = isset($item['remark']) ? sanitize($item['remark']) : '';

                $sql = "INSERT INTO sales_delivery_items (
                            delivery_id, 
                            product_id, 
                            batch_id, 
                            quantity, 
                            unit_price,
                            discount_rate,
                            item_amount, 
                            remark
                        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?)";

                $stmt = $conn->prepare($sql);
                if (!$stmt) {
                    error_log("更新出库单：SQL准备失败，错误: " . $conn->error);
                    throw new Exception("SQL准备失败: " . $conn->error);
                }

                $stmt->bind_param(
                    "iiidddds",
                    $deliveryId,
                    $productId,
                    $batchId,
                    $quantity,
                    $unitPrice,
                    $discountRate,
                    $itemAmount,
                    $itemRemark
                );

                if (!$stmt->execute()) {
                    error_log("更新出库单：插入出库明细失败: " . $stmt->error . ", SQL: " . $sql);
                    throw new Exception("插入出库明细失败: " . $stmt->error);
                } else {
                    error_log("更新出库单：插入出库明细成功: delivery_id={$deliveryId}, product_id={$productId}, batch_id={$batchId}");
                }

                // 更新库存
                updateInventory($warehouseId, $productId, $batchId, $quantity, 'decrease');
            }
        } else {
            // 旧格式：使用平行数组
            error_log("更新出库单：使用旧格式平行数组处理出库明细");
            $productIds = isset($params['product_id']) ? $params['product_id'] : [];
            $batchIds = isset($params['batch_id']) ? $params['batch_id'] : [];
            $quantities = isset($params['quantity']) ? $params['quantity'] : [];
            $unitPrices = isset($params['unit_price']) ? $params['unit_price'] : [];
            $discountRates = isset($params['discount_rate']) ? $params['discount_rate'] : [];
            $itemRemarks = isset($params['item_remark']) ? $params['item_remark'] : [];

            $originalParams = $params; // 保存原始参数用于访问平行数组

            for ($i = 0; $i < count($productIds); $i++) {
                if (empty($productIds[$i])) continue;

                error_log("更新出库单：处理旧格式商品 索引{$i}, 商品ID: {$productIds[$i]}, 批次ID: {$batchIds[$i]}");
                $productId = intval($productIds[$i]);
                $batchId = intval($batchIds[$i]);
                $quantity = intval($quantities[$i]);
                $unitPrice = floatval($unitPrices[$i]);
                $discountRate = isset($discountRates[$i]) ? floatval($discountRates[$i]) : 0;
                $itemAmount = $quantity * $unitPrice * (1 - $discountRate / 100);
                $itemRemark = isset($itemRemarks[$i]) ? sanitize($itemRemarks[$i]) : '';

                $sql = "INSERT INTO sales_delivery_items (
                            delivery_id, 
                            product_id, 
                            batch_id, 
                            quantity, 
                            unit_price,
                            discount_rate,
                            item_amount, 
                            remark
                        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?)";

                $stmt = $conn->prepare($sql);
                if (!$stmt) {
                    error_log("更新出库单：SQL准备失败，错误: " . $conn->error);
                    throw new Exception("SQL准备失败: " . $conn->error);
                }

                $stmt->bind_param(
                    "iiidddds",
                    $deliveryId,
                    $productId,
                    $batchId,
                    $quantity,
                    $unitPrice,
                    $discountRate,
                    $itemAmount,
                    $itemRemark
                );

                if (!$stmt->execute()) {
                    error_log("更新出库单：插入出库明细失败: " . $stmt->error . ", SQL: " . $sql);
                    throw new Exception("插入出库明细失败: " . $stmt->error);
                } else {
                    error_log("更新出库单：插入出库明细成功: delivery_id={$deliveryId}, product_id={$productId}, batch_id={$batchId}");
                }

                // 更新库存
                updateInventory($warehouseId, $productId, $batchId, $quantity, 'decrease');
            }
        }

        // 提交事务
        if (!$conn->commit()) {
            error_log("事务提交失败: " . $conn->error);
            throw new Exception("事务提交失败: " . $conn->error);
        }
        error_log("事务提交成功，出库单ID: " . $deliveryId);

        return [
            'success' => true,
            'message' => '销售出库单更新成功'
        ];
    } catch (Exception $e) {
        // 回滚事务
        if ($conn->rollback()) {
            error_log("事务已回滚");
        } else {
            error_log("事务回滚失败: " . $conn->error);
        }

        error_log("更新销售出库单失败: " . $e->getMessage());

        return [
            'success' => false,
            'message' => $e->getMessage()
        ];
    }
}

/**
 * 更新库存
 * @param int $warehouseId 仓库ID
 * @param int $productId 商品ID
 * @param int $batchId 批次ID
 * @param int $quantity 数量
 * @param string $action 操作类型（increase或decrease）
 * @return bool 操作结果
 */
function updateInventory($warehouseId, $productId, $batchId, $quantity, $action = 'decrease')
{
    global $conn;

    try {
        // 检查库存是否存在
        $sql = "SELECT inventory_id, quantity FROM inventory 
                WHERE warehouse_id = ? AND product_id = ? AND batch_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("iii", $warehouseId, $productId, $batchId);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            // 存在库存记录，更新
            $inventory = $result->fetch_assoc();
            $inventoryId = $inventory['inventory_id'];
            $currentQuantity = $inventory['quantity'];

            // 计算新数量
            $newQuantity = ($action === 'decrease')
                ? $currentQuantity - $quantity
                : $currentQuantity + $quantity;

            // 确保库存不会为负
            if ($newQuantity < 0) {
                throw new Exception("库存不足，无法出库");
            }

            // 更新库存
            $sql = "UPDATE inventory SET quantity = ? WHERE inventory_id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("ii", $newQuantity, $inventoryId);

            return $stmt->execute();
        } else {
            // 不存在库存记录，如果是增加操作则创建新记录
            if ($action === 'increase') {
                $sql = "INSERT INTO inventory (warehouse_id, product_id, batch_id, quantity, min_stock_level) 
                        VALUES (?, ?, ?, ?, 0)";
                $stmt = $conn->prepare($sql);
                $stmt->bind_param("iiii", $warehouseId, $productId, $batchId, $quantity);

                return $stmt->execute();
            } else {
                // 如果是减少操作但不存在库存记录，抛出异常
                throw new Exception("库存不存在，无法出库");
            }
        }
    } catch (Exception $e) {
        error_log("更新库存失败: " . $e->getMessage());
        throw $e;
    }
}

/**
 * 获取出库状态中文名称
 * @param string $status 状态码
 * @return string 中文名称
 */
function getDeliveryStatusName($status)
{
    $statusMap = [
        'pending' => '待处理',
        'in_progress' => '进行中',
        'completed' => '已完成',
        'cancelled' => '已取消'
    ];
    return isset($statusMap[$status]) ? $statusMap[$status] : $status;
}

/**
 * 获取出库状态对应的样式类
 * @param string $status 状态码
 * @return string 样式类名
 */
function getDeliveryStatusBadgeClass($status)
{
    $classMap = [
        'pending' => 'warning',
        'in_progress' => 'info',
        'completed' => 'success',
        'cancelled' => 'danger'
    ];
    return isset($classMap[$status]) ? $classMap[$status] : 'secondary';
}
